@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -35,16 +35,17 @@ import javafx.collections.ListChangeListener;
 import test.javafx.collections.MockListObserver;
 import javafx.collections.ObservableList;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.util.BitSet;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 public class ListListenerHelperTest {
 
@@ -57,7 +58,7 @@ public class ListListenerHelperTest {
     private ObservableList<Object> list;
     private ListChangeListener.Change<Object> change;
 
-    @Before
+    @BeforeEach
     public void setUp() {
         invalidationListenerMock = new InvalidationListenerMock[] {
                 new InvalidationListenerMock(),
@@ -85,24 +86,32 @@ public class ListListenerHelperTest {
         }
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testAddInvalidationListener_Null() {
-        ListListenerHelper.addListener(helper, (InvalidationListener)null);
+        assertThrows(NullPointerException.class, () -> {
+            ListListenerHelper.addListener(helper, (InvalidationListener)null);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testRemoveInvalidationListener_Null() {
-        ListListenerHelper.removeListener(helper, (InvalidationListener) null);
+        assertThrows(NullPointerException.class, () -> {
+            ListListenerHelper.removeListener(helper, (InvalidationListener) null);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testRemoveListChangeListener_Null() {
-        ListListenerHelper.removeListener(helper, (ListChangeListener<Object>) null);
+        assertThrows(NullPointerException.class, () -> {
+            ListListenerHelper.removeListener(helper, (ListChangeListener<Object>) null);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testAddListChangeListener_Null() {
-        ListListenerHelper.addListener(helper, (ListChangeListener<Object>) null);
+        assertThrows(NullPointerException.class, () -> {
+            ListListenerHelper.addListener(helper, (ListChangeListener<Object>) null);
+        });
     }
 
     @Test
