@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -28,17 +28,18 @@ package test.javafx.beans.property;
 import javafx.beans.property.FloatProperty;
 import javafx.beans.property.FloatPropertyBase;
 import javafx.beans.property.SimpleFloatProperty;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import test.javafx.beans.InvalidationListenerMock;
 import test.javafx.beans.value.ChangeListenerMock;
 import javafx.beans.value.ObservableFloatValueStub;
 import javafx.beans.value.ObservableValueStub;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 public class FloatPropertyBaseTest {
 
@@ -54,7 +55,7 @@ public class FloatPropertyBaseTest {
     private InvalidationListenerMock invalidationListener;
     private ChangeListenerMock<Number> changeListener;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         property = new FloatPropertyMock();
         invalidationListener = new InvalidationListenerMock();
@@ -204,13 +205,16 @@ public class FloatPropertyBaseTest {
         changeListener.check(property, PI, -PI, 2);
     }
 
-    @Test(expected=RuntimeException.class)
+    @Test
     public void testSetBoundValue() {
-        final FloatProperty v = new SimpleFloatProperty(PI);
-        property.bind(v);
-        property.set(PI);
+        assertThrows(RuntimeException.class, () -> {
+            final FloatProperty v = new SimpleFloatProperty(PI);
+            property.bind(v);
+            property.set(PI);
+        });
     }
 
+
     @Test
     public void testLazyBind() {
         attachInvalidationListener();
@@ -357,11 +361,14 @@ public class FloatPropertyBaseTest {
         changeListener.check(property, value1, 0.0f, 1);
     }
 
-    @Test(expected=NullPointerException.class)
+    @Test
     public void testBindToNull() {
-        property.bind(null);
+        assertThrows(NullPointerException.class, () -> {
+            property.bind(null);
+        });
     }
 
+
     @Test
     public void testRebind() {
         attachInvalidationListener();
