@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -33,12 +33,12 @@ import test.javafx.beans.InvalidationListenerMock;
 import test.javafx.beans.value.ChangeListenerMock;
 import javafx.beans.value.ObservableObjectValueStub;
 import javafx.collections.*;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import static test.javafx.collections.MockSetObserver.Call;
 import test.javafx.collections.MockSetObserver.Tuple;
-import static org.junit.Assert.*;
+import static org.junit.jupiter.api.Assertions.*;
 
 public class SetPropertyBaseTest {
 
@@ -61,7 +61,7 @@ public class SetPropertyBaseTest {
     private ChangeListenerMock<ObservableSet<Object>> changeListener;
     private MockSetObserver<Object> setChangeListener;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         property = new SetPropertyMock();
         invalidationListener = new InvalidationListenerMock();
@@ -435,13 +435,16 @@ public class SetPropertyBaseTest {
         setChangeListener.assertAdded(MockSetObserver.Tuple.tup(OBJECT_1b));
     }
 
-    @Test(expected = RuntimeException.class)
+    @Test
     public void testSetBoundValue() {
-        final SetProperty<Object> v = new SimpleSetProperty<>(VALUE_1a);
-        property.bind(v);
-        property.set(VALUE_1a);
+        assertThrows(RuntimeException.class, () -> {
+            final SetProperty<Object> v = new SimpleSetProperty<>(VALUE_1a);
+            property.bind(v);
+            property.set(VALUE_1a);
+        });
     }
 
+
     @Test
     public void testBind_Invalidation() {
         attachInvalidationListener();
@@ -541,11 +544,14 @@ public class SetPropertyBaseTest {
         assertEquals(0, setChangeListener.getCallsNumber());
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testBindToNull() {
-        property.bind(null);
+        assertThrows(NullPointerException.class, () -> {
+            property.bind(null);
+        });
     }
 
+
     @Test
     public void testRebind() {
         attachInvalidationListener();
