@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -35,11 +35,11 @@ import javafx.collections.ObservableList;
 import test.com.sun.javafx.binding.ErrorLoggingUtiltity;
 import javafx.collections.ObservableFloatArray;
 import javafx.collections.ObservableIntegerArray;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 
-import static org.junit.Assert.*;
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
  */
@@ -56,12 +56,12 @@ public class BindingsArrayTest {
     private ObservableList<Object> list2;
     private IntegerProperty index;
 
-    @BeforeClass
+    @BeforeAll
     public static void setUpClass() {
         ErrorLoggingUtiltity.reset();
     }
 
-    @Before
+    @BeforeEach
     public void setUp() {
         property = new SimpleListProperty<>();
         list1 = FXCollections.<Object>observableArrayList(data1, data2);
@@ -87,11 +87,14 @@ public class BindingsArrayTest {
         assertEquals(0, size.get());
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testSize_Null() {
-        Bindings.size((ObservableList<Object>) null);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.size((ObservableList<Object>) null);
+        });
     }
 
+
     @Test
     public void testIsEmpty() {
         final BooleanBinding empty = Bindings.isEmpty(property);
@@ -110,11 +113,14 @@ public class BindingsArrayTest {
         assertTrue(empty.get());
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testIsEmpty_Null() {
-        Bindings.isEmpty((ObservableList<Object>) null);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.isEmpty((ObservableList<Object>) null);
+        });
     }
 
+
     @Test
     public void testIsNotEmpty() {
         final BooleanBinding notEmpty = Bindings.isNotEmpty(property);
@@ -133,11 +139,14 @@ public class BindingsArrayTest {
         assertFalse(notEmpty.get());
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testIsNotEmpty_Null() {
-        Bindings.isNotEmpty((ObservableList<Object>) null);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.isNotEmpty((ObservableList<Object>) null);
+        });
     }
 
+
     @Test
     public void testValueAt_Constant() {
         final ObjectBinding<Object> binding0 = Bindings.valueAt(property, 0);
@@ -189,16 +198,22 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testValueAt_Constant_Null() {
-        Bindings.valueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.valueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testValueAt_Constant_NegativeIndex() {
-        Bindings.valueAt(property, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            Bindings.valueAt(property, -1);
+        });
     }
 
+
     @Test
     public void testValueAt_Variable() {
         final ObjectBinding<Object> binding = Bindings.valueAt(property, index);
@@ -262,16 +277,22 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testValueAt_Variable_Null() {
-        Bindings.valueAt((ObservableList<Object>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.valueAt((ObservableList<Object>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testValueAt_Variable_NullIndex() {
-        Bindings.valueAt(property, null);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.valueAt(property, null);
+        });
     }
 
+
     @Test
     public void testBooleanValueAt_Constant() {
         final boolean defaultData = false;
@@ -330,17 +351,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testBooleanValueAt_Constant_Null() {
-        Bindings.booleanValueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.booleanValueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testBooleanValueAt_Constant_NegativeIndex() {
-        final ListProperty<Boolean> localProperty = new SimpleListProperty<>();
-        Bindings.booleanValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Boolean> localProperty = new SimpleListProperty<>();
+            Bindings.booleanValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testBooleanValueAt_Variable() {
         final boolean defaultData = false;
@@ -422,17 +449,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testBooleanValueAt_Variable_Null() {
-        Bindings.booleanValueAt((ObservableList<Boolean>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.booleanValueAt((ObservableList<Boolean>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testBooleanValueAt_Variable_NullIndex() {
-        final ListProperty<Boolean> localProperty = new SimpleListProperty<>();
-        Bindings.booleanValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Boolean> localProperty = new SimpleListProperty<>();
+            Bindings.booleanValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testDoubleValueAt_Constant() {
         final double defaultData = 0.0;
@@ -491,17 +524,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testDoubleValueAt_Constant_Null() {
-        Bindings.doubleValueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.doubleValueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testDoubleValueAt_Constant_NegativeIndex() {
-        final ListProperty<Double> localProperty = new SimpleListProperty<>();
-        Bindings.doubleValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Double> localProperty = new SimpleListProperty<>();
+            Bindings.doubleValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testDoubleValueAt_Variable() {
         final double defaultData = 0.0;
@@ -583,17 +622,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testDoubleValueAt_Variable_Null() {
-        Bindings.doubleValueAt((ObservableList<Double>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.doubleValueAt((ObservableList<Double>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testDoubleValueAt_Variable_NullIndex() {
-        final ListProperty<Double> localProperty = new SimpleListProperty<>();
-        Bindings.doubleValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Double> localProperty = new SimpleListProperty<>();
+            Bindings.doubleValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testFloatValueAt_Constant() {
         final float defaultData = 0.0f;
@@ -652,17 +697,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testFloatValueAt_Constant_Null() {
-        Bindings.floatValueAt((ObservableFloatArray) null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.floatValueAt((ObservableFloatArray) null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testFloatValueAt_Constant_NegativeIndex() {
-        final ListProperty<Float> localProperty = new SimpleListProperty<>();
-        Bindings.floatValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Float> localProperty = new SimpleListProperty<>();
+            Bindings.floatValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testFloatValueAt_Variable() {
         final float defaultData = 0.0f;
@@ -744,17 +795,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testFloatValueAt_Variable_Null() {
-        Bindings.floatValueAt((ObservableList<Float>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.floatValueAt((ObservableList<Float>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testFloatValueAt_Variable_NullIndex() {
-        final ListProperty<Float> localProperty = new SimpleListProperty<>();
-        Bindings.floatValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Float> localProperty = new SimpleListProperty<>();
+            Bindings.floatValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testIntegerValueAt_Constant() {
         final int defaultData = 0;
@@ -813,17 +870,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testIntegerValueAt_Constant_Null() {
-        Bindings.integerValueAt((ObservableIntegerArray) null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.integerValueAt((ObservableIntegerArray) null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testIntegerValueAt_Constant_NegativeIndex() {
-        final ListProperty<Integer> localProperty = new SimpleListProperty<>();
-        Bindings.integerValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Integer> localProperty = new SimpleListProperty<>();
+            Bindings.integerValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testIntegerValueAt_Variable() {
         final int defaultData = 0;
@@ -905,17 +968,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testIntegerValueAt_Variable_Null() {
-        Bindings.integerValueAt((ObservableList<Integer>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.integerValueAt((ObservableList<Integer>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testIntegerValueAt_Variable_NullIndex() {
-        final ListProperty<Integer> localProperty = new SimpleListProperty<>();
-        Bindings.integerValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Integer> localProperty = new SimpleListProperty<>();
+            Bindings.integerValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testLongValueAt_Constant() {
         final long defaultData = 0L;
@@ -974,17 +1043,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testLongValueAt_Constant_Null() {
-        Bindings.longValueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.longValueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testLongValueAt_Constant_NegativeIndex() {
-        final ListProperty<Long> localProperty = new SimpleListProperty<>();
-        Bindings.longValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Long> localProperty = new SimpleListProperty<>();
+            Bindings.longValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testLongValueAt_Variable() {
         final long defaultData = 0;
@@ -1066,17 +1141,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testLongValueAt_Variable_Null() {
-        Bindings.longValueAt((ObservableList<Long>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.longValueAt((ObservableList<Long>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testLongValueAt_Variable_NullIndex() {
-        final ListProperty<Long> localProperty = new SimpleListProperty<>();
-        Bindings.longValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Long> localProperty = new SimpleListProperty<>();
+            Bindings.longValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testStringValueAt_Constant() {
         final String defaultData = null;
@@ -1135,17 +1216,23 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testStringValueAt_Constant_Null() {
-        Bindings.stringValueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.stringValueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testStringValueAt_Constant_NegativeIndex() {
-        final ListProperty<String> localProperty = new SimpleListProperty<>();
-        Bindings.stringValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<String> localProperty = new SimpleListProperty<>();
+            Bindings.stringValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testStringValueAt_Variable() {
         final String defaultData = null;
@@ -1216,16 +1303,19 @@ public class BindingsArrayTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testStringValueAt_Variable_Null() {
-        Bindings.stringValueAt((ObservableList<String>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.stringValueAt((ObservableList<String>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testStringValueAt_Variable_NullIndex() {
-        final ListProperty<String> localProperty = new SimpleListProperty<>();
-        Bindings.stringValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<String> localProperty = new SimpleListProperty<>();
+            Bindings.stringValueAt(localProperty, null);
+        });
     }
-
-
 }
