@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,25 +25,27 @@
 
 package test.javafx.scene.chart;
 
-import javafx.css.CssMetaData;
-
-import static test.com.sun.javafx.scene.control.infrastructure.ControlTestUtils.*;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static test.com.sun.javafx.scene.control.infrastructure.ControlTestUtils.assertPseudoClassDoesNotExist;
+import static test.com.sun.javafx.scene.control.infrastructure.ControlTestUtils.assertPseudoClassExists;
 import javafx.beans.property.BooleanProperty;
 import javafx.beans.property.DoubleProperty;
 import javafx.beans.property.ObjectProperty;
 import javafx.beans.property.SimpleBooleanProperty;
 import javafx.beans.property.SimpleDoubleProperty;
 import javafx.beans.property.SimpleObjectProperty;
+import javafx.css.CssMetaData;
 import javafx.css.StyleableProperty;
 import javafx.geometry.Side;
 import javafx.scene.chart.Axis;
 import javafx.scene.paint.Color;
 import javafx.scene.text.Font;
-import static org.junit.Assert.*;
-
-
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * All public members of Axis are tested here .
@@ -56,7 +58,8 @@ public class AxisTest {
         helper = new AxisHelper();
     }
 
-    @Before public void setup() {
+    @BeforeEach
+    public void setup() {
         if (axis == null) {
             axis = helper.getDummyAxis();
         }
@@ -69,45 +72,54 @@ public class AxisTest {
      * Tests for default values                                         *
      ********************************************************************/
 
-    @Test public void defaultSideNull() {
+    @Test
+    public void defaultSideNull() {
         assertNull(axis.getSide());
     }
 
-    @Test public void defaultTickMarkVisibleIsTrue() {
+    @Test
+    public void defaultTickMarkVisibleIsTrue() {
         assertTrue(axis.isTickMarkVisible());
     }
 
-    @Test public void defaultTickLabelsVisibleIsTrue() {
+    @Test
+    public void defaultTickLabelsVisibleIsTrue() {
         assertTrue(axis.isTickLabelsVisible());
     }
 
-
-    @Test public void defaultTickLength() {
-        assertEquals(axis.getTickLength(), 8.0 , 0.0);
+    @Test
+    public void defaultTickLength() {
+        assertEquals(axis.getTickLength(), 8.0, 0.0);
     }
 
-    @Test public void defaultAutoRangingIsTrue() {
+    @Test
+    public void defaultAutoRangingIsTrue() {
         assertTrue(axis.isAutoRanging());
     }
 
-    @Test public void defaultTickLabelFont() {
+    @Test
+    public void defaultTickLabelFont() {
         assertEquals(axis.getTickLabelFont(), Font.font("System", 8));
     }
 
-    @Test public void defaultTickLabelFill() {
-        assertSame(axis.getTickLabelFill(), Color.BLACK );
+    @Test
+    public void defaultTickLabelFill() {
+        assertSame(axis.getTickLabelFill(), Color.BLACK);
     }
 
-    @Test public void defaultTickLabelGap() {
-        assertEquals(axis.getTickLabelGap(), 3.0 , 0.0);
+    @Test
+    public void defaultTickLabelGap() {
+        assertEquals(axis.getTickLabelGap(), 3.0, 0.0);
     }
 
-    @Test public void defaultAnimatedIsTrue() {
+    @Test
+    public void defaultAnimatedIsTrue() {
         assertTrue(axis.getAnimated());
     }
 
-    @Test public void defaultTickLabelRotation() {
-        assertEquals(axis.getTickLabelRotation(), 0.0 , 0.0);
+    @Test
+    public void defaultTickLabelRotation() {
+        assertEquals(axis.getTickLabelRotation(), 0.0, 0.0);
     }
 
 
@@ -115,165 +127,193 @@ public class AxisTest {
      * Tests for property binding                                        *
      ********************************************************************/
 
-    @Test public void checkSidePropertyBind() {
+    @Test
+    public void checkSidePropertyBind() {
         ObjectProperty objPr = new SimpleObjectProperty<>(Side.TOP);
         axis.sideProperty().bind(objPr);
-        assertSame("side cannot be bound", axis.sideProperty().getValue(), Side.TOP);
+        assertSame(axis.sideProperty().getValue(), Side.TOP, "side cannot be bound");
         objPr.setValue(Side.BOTTOM);
-        assertSame("side cannot be bound", axis.sideProperty().getValue(), Side.BOTTOM);
+        assertSame(axis.sideProperty().getValue(), Side.BOTTOM, "side cannot be bound");
     }
 
-    @Test public void checkTickMarkVisiblePropertyBind() {
+    @Test
+    public void checkTickMarkVisiblePropertyBind() {
         BooleanProperty objPr = new SimpleBooleanProperty(true);
         axis.tickMarkVisibleProperty().bind(objPr);
-        assertTrue("tickMarkVisibleProperty cannot be bound", axis.tickMarkVisibleProperty().getValue());
+        assertTrue(axis.tickMarkVisibleProperty().getValue(), "tickMarkVisibleProperty cannot be bound");
         objPr.setValue(false);
-        assertFalse("tickMarkVisibleProperty cannot be bound", axis.tickMarkVisibleProperty().getValue());
+        assertFalse(axis.tickMarkVisibleProperty().getValue(), "tickMarkVisibleProperty cannot be bound");
     }
 
-    @Test public void checkTickLabelsVisiblePropertyBind() {
+    @Test
+    public void checkTickLabelsVisiblePropertyBind() {
         BooleanProperty objPr = new SimpleBooleanProperty(true);
         axis.tickLabelsVisibleProperty().bind(objPr);
-        assertTrue("tickLabelsVisibleProperty cannot be bound", axis.tickLabelsVisibleProperty().getValue());
+        assertTrue(axis.tickLabelsVisibleProperty().getValue(), "tickLabelsVisibleProperty cannot be bound");
         objPr.setValue(false);
-        assertFalse("tickLabelsVisibleProperty cannot be bound", axis.tickLabelsVisibleProperty().getValue());
+        assertFalse(axis.tickLabelsVisibleProperty().getValue(), "tickLabelsVisibleProperty cannot be bound");
     }
 
-    @Test public void checkTickLengthPropertyBind() {
+    @Test
+    public void checkTickLengthPropertyBind() {
         DoubleProperty objPr = new SimpleDoubleProperty(56.0);
         axis.tickLengthProperty().bind(objPr);
-        assertEquals("tickLengthProperty cannot be bound", axis.tickLengthProperty().getValue(),56.0,0.0);
+        assertEquals(axis.tickLengthProperty().getValue(),56.0,0.0, "tickLengthProperty cannot be bound");
         objPr.setValue(23.0);
-        assertEquals("tickLengthProperty cannot be bound", axis.tickLengthProperty().getValue(),23.0,0.0);
+        assertEquals(axis.tickLengthProperty().getValue(),23.0,0.0, "tickLengthProperty cannot be bound");
     }
 
-    @Test public void checkAutoRangingPropertyBind() {
+    @Test
+    public void checkAutoRangingPropertyBind() {
         BooleanProperty objPr = new SimpleBooleanProperty(true);
         axis.autoRangingProperty().bind(objPr);
-        assertTrue("autoRangingProperty cannot be bound", axis.autoRangingProperty().getValue());
+        assertTrue(axis.autoRangingProperty().getValue(), "autoRangingProperty cannot be bound");
         objPr.setValue(false);
-        assertFalse("autoRangingProperty cannot be bound", axis.autoRangingProperty().getValue());
+        assertFalse(axis.autoRangingProperty().getValue(), "autoRangingProperty cannot be bound");
     }
 
-    @Test public void checkTickLabelFontPropertyBind() {
+    @Test
+    public void checkTickLabelFontPropertyBind() {
         ObjectProperty objPr = new SimpleObjectProperty<Font>(null);
         axis.tickLabelFontProperty().bind(objPr);
-        assertNull("tickLabelFontProperty cannot be bound", axis.tickLabelFontProperty().getValue());
+        assertNull(axis.tickLabelFontProperty().getValue(), "tickLabelFontProperty cannot be bound");
         objPr.setValue(Font.getDefault());
-        assertSame("tickLabelFontProperty cannot be bound", axis.tickLabelFontProperty().getValue(), Font.getDefault());
+        assertSame(axis.tickLabelFontProperty().getValue(), Font.getDefault(), "tickLabelFontProperty cannot be bound");
     }
 
-    @Test public void checkTickLabelFillPropertyBind() {
+    @Test
+    public void checkTickLabelFillPropertyBind() {
         ObjectProperty objPr = new SimpleObjectProperty<>(Color.WHEAT);
         axis.tickLabelFillProperty().bind(objPr);
-        assertSame("tickLabelFillProperty cannot be bound", axis.tickLabelFillProperty().getValue(), Color.WHEAT);
+        assertSame(axis.tickLabelFillProperty().getValue(), Color.WHEAT, "tickLabelFillProperty cannot be bound");
         objPr.setValue(Color.BLUE);
-        assertSame("tickLabelFillProperty cannot be bound", axis.tickLabelFillProperty().getValue(), Color.BLUE);
+        assertSame(axis.tickLabelFillProperty().getValue(), Color.BLUE, "tickLabelFillProperty cannot be bound");
     }
 
-    @Test public void checkTickLabelGapPropertyBind() {
+    @Test
+    public void checkTickLabelGapPropertyBind() {
         DoubleProperty objPr = new SimpleDoubleProperty(56.0);
         axis.tickLabelGapProperty().bind(objPr);
-        assertEquals("tickLabelGapProperty cannot be bound", axis.tickLabelGapProperty().getValue(),56.0,0.0);
+        assertEquals(axis.tickLabelGapProperty().getValue(),56.0,0.0, "tickLabelGapProperty cannot be bound");
         objPr.setValue(23.0);
-        assertEquals("tickLabelGapProperty cannot be bound", axis.tickLabelGapProperty().getValue(),23.0,0.0);
+        assertEquals(axis.tickLabelGapProperty().getValue(),23.0,0.0, "tickLabelGapProperty cannot be bound");
     }
 
-    @Test public void checkAnimatedPropertyBind() {
+    @Test
+    public void checkAnimatedPropertyBind() {
         BooleanProperty objPr = new SimpleBooleanProperty(true);
         axis.animatedProperty().bind(objPr);
-        assertTrue("animatedProperty cannot be bound", axis.animatedProperty().getValue());
+        assertTrue(axis.animatedProperty().getValue(), "animatedProperty cannot be bound");
         objPr.setValue(false);
-        assertFalse("animatedProperty cannot be bound", axis.animatedProperty().getValue());
+        assertFalse(axis.animatedProperty().getValue(), "animatedProperty cannot be bound");
     }
 
-    @Test public void checkTickLabelRotationPropertyBind() {
+    @Test
+    public void checkTickLabelRotationPropertyBind() {
         DoubleProperty objPr = new SimpleDoubleProperty(56.0);
         axis.tickLabelRotationProperty().bind(objPr);
-        assertEquals("tickLabelRotationProperty cannot be bound", axis.tickLabelRotationProperty().getValue(),56.0,0.0);
+        assertEquals(axis.tickLabelRotationProperty().getValue(),56.0,0.0, "tickLabelRotationProperty cannot be bound");
         objPr.setValue(23.0);
-        assertEquals("tickLabelRotationProperty cannot be bound", axis.tickLabelRotationProperty().getValue(),23.0,0.0);
+        assertEquals(axis.tickLabelRotationProperty().getValue(),23.0,0.0, "tickLabelRotationProperty cannot be bound");
     }
 
-
-
-    @Test public void sidePropertyHasBeanReference() {
+    @Test
+    public void sidePropertyHasBeanReference() {
         assertSame(axis, axis.sideProperty().getBean());
     }
 
-    @Test public void sidePropertyHasName() {
+    @Test
+    public void sidePropertyHasName() {
         assertEquals("side", axis.sideProperty().getName());
     }
 
-    @Test public void tickMarkVisiblePropertyHasBeanReference() {
+    @Test
+    public void tickMarkVisiblePropertyHasBeanReference() {
         assertSame(axis, axis.tickMarkVisibleProperty().getBean());
     }
 
-    @Test public void tickMarkVisiblePropertyHasName() {
+    @Test
+    public void tickMarkVisiblePropertyHasName() {
         assertEquals("tickMarkVisible", axis.tickMarkVisibleProperty().getName());
     }
 
-    @Test public void tickLabelsVisiblePropertyHasBeanReference() {
+    @Test
+    public void tickLabelsVisiblePropertyHasBeanReference() {
         assertSame(axis, axis.tickLabelsVisibleProperty().getBean());
     }
 
-    @Test public void tickLabelsVisiblePropertyHasName() {
+    @Test
+    public void tickLabelsVisiblePropertyHasName() {
         assertEquals("tickLabelsVisible", axis.tickLabelsVisibleProperty().getName());
     }
 
-    @Test public void tickLengthPropertyHasBeanReference() {
+    @Test
+    public void tickLengthPropertyHasBeanReference() {
         assertSame(axis, axis.tickLengthProperty().getBean());
     }
 
-    @Test public void tickLengthPropertyHasName() {
+    @Test
+    public void tickLengthPropertyHasName() {
         assertEquals("tickLength", axis.tickLengthProperty().getName());
     }
 
-    @Test public void autoRangingPropertyHasBeanReference() {
+    @Test
+    public void autoRangingPropertyHasBeanReference() {
         assertSame(axis, axis.autoRangingProperty().getBean());
     }
 
-    @Test public void autoRangingPropertyHasName() {
+    @Test
+    public void autoRangingPropertyHasName() {
         assertEquals("autoRanging", axis.autoRangingProperty().getName());
     }
 
-    @Test public void tickLabelFontPropertyHasBeanReference() {
+    @Test
+    public void tickLabelFontPropertyHasBeanReference() {
         assertSame(axis, axis.tickLabelFontProperty().getBean());
     }
 
-    @Test public void tickLabelFontPropertyHasName() {
+    @Test
+    public void tickLabelFontPropertyHasName() {
         assertEquals("tickLabelFont", axis.tickLabelFontProperty().getName());
     }
 
-    @Test public void tickLabelFillPropertyHasBeanReference() {
+    @Test
+    public void tickLabelFillPropertyHasBeanReference() {
         assertSame(axis, axis.tickLabelFillProperty().getBean());
     }
 
-    @Test public void tickLabelFillPropertyHasName() {
+    @Test
+    public void tickLabelFillPropertyHasName() {
         assertEquals("tickLabelFill", axis.tickLabelFillProperty().getName());
     }
 
-    @Test public void tickLabelGapPropertyHasBeanReference() {
+    @Test
+    public void tickLabelGapPropertyHasBeanReference() {
         assertSame(axis, axis.tickLabelGapProperty().getBean());
     }
 
-    @Test public void tickLabelGapPropertyHasName() {
+    @Test
+    public void tickLabelGapPropertyHasName() {
         assertEquals("tickLabelGap", axis.tickLabelGapProperty().getName());
     }
 
-    @Test public void animatedPropertyHasBeanReference() {
+    @Test
+    public void animatedPropertyHasBeanReference() {
         assertSame(axis, axis.animatedProperty().getBean());
     }
 
-    @Test public void animatedPropertyHasName() {
+    @Test
+    public void animatedPropertyHasName() {
         assertEquals("animated", axis.animatedProperty().getName());
     }
 
-    @Test public void tickLabelRotationPropertyHasBeanReference() {
+    @Test
+    public void tickLabelRotationPropertyHasBeanReference() {
         assertSame(axis, axis.tickLabelRotationProperty().getBean());
     }
 
-    @Test public void tickLabelRotationPropertyHasName() {
+    @Test
+    public void tickLabelRotationPropertyHasName() {
         assertEquals("tickLabelRotation", axis.tickLabelRotationProperty().getName());
     }
 
@@ -282,7 +322,8 @@ public class AxisTest {
     /*********************************************************************
      * Check for Pseudo classes                                          *
      ********************************************************************/
-    @Test public void settingSideTopSetsTopAndClearsOther3SidesPseudoClass() {
+    @Test
+    public void settingSideTopSetsTopAndClearsOther3SidesPseudoClass() {
         axis.setSide(Side.TOP);
         assertPseudoClassExists(axis, "top");
         assertPseudoClassDoesNotExist(axis, "left");
@@ -290,7 +331,8 @@ public class AxisTest {
         assertPseudoClassDoesNotExist(axis, "bottom");
     }
 
-    @Test public void settingSideLeftSetsLeftAndClearsOther3SidesPseudoClass() {
+    @Test
+    public void settingSideLeftSetsLeftAndClearsOther3SidesPseudoClass() {
         axis.setSide(Side.LEFT);
         assertPseudoClassExists(axis, "left");
         assertPseudoClassDoesNotExist(axis, "top");
@@ -298,7 +340,8 @@ public class AxisTest {
         assertPseudoClassDoesNotExist(axis, "bottom");
     }
 
-    @Test public void settingSideRightSetsRightAndClearsOther3SidesPseudoClass() {
+    @Test
+    public void settingSideRightSetsRightAndClearsOther3SidesPseudoClass() {
         axis.setSide(Side.RIGHT);
         assertPseudoClassExists(axis, "right");
         assertPseudoClassDoesNotExist(axis, "left");
@@ -306,7 +349,8 @@ public class AxisTest {
         assertPseudoClassDoesNotExist(axis, "bottom");
     }
 
-    @Test public void settingSideBottomSetsBottomAndClearsOther3SidesPseudoClass() {
+    @Test
+    public void settingSideBottomSetsBottomAndClearsOther3SidesPseudoClass() {
         axis.setSide(Side.BOTTOM);
         assertPseudoClassExists(axis, "bottom");
         assertPseudoClassDoesNotExist(axis, "left");
@@ -319,7 +363,8 @@ public class AxisTest {
     /*********************************************************************
      * CSS related Tests                                                 *
      ********************************************************************/
-    @Test public void whenSideIsBound_CssMetaData_isSettable_ReturnsFalse() {
+    @Test
+    public void whenSideIsBound_CssMetaData_isSettable_ReturnsFalse() {
         CssMetaData styleable = ((StyleableProperty)axis.sideProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
         ObjectProperty<Side> other = new SimpleObjectProperty<>(Side.LEFT);
@@ -327,17 +372,20 @@ public class AxisTest {
         assertFalse(styleable.isSettable(axis));
     }
 
-    @Test public void whenSideIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
+    @Test
+    public void whenSideIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
         CssMetaData styleable = ((StyleableProperty)axis.sideProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
     }
 
-    @Test public void canSpecifySideViaCSS() {
+    @Test
+    public void canSpecifySideViaCSS() {
         ((StyleableProperty)axis.sideProperty()).applyStyle(null, Side.BOTTOM);
         assertSame(Side.BOTTOM, axis.getSide());
     }
 
-    @Test public void whenTickMarkVisibleIsBound_CssMetaData_isSettable_ReturnsFalse() {
+    @Test
+    public void whenTickMarkVisibleIsBound_CssMetaData_isSettable_ReturnsFalse() {
         CssMetaData styleable = ((StyleableProperty)axis.tickMarkVisibleProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
         BooleanProperty other = new SimpleBooleanProperty();
@@ -345,17 +393,20 @@ public class AxisTest {
         assertFalse(styleable.isSettable(axis));
     }
 
-    @Test public void whenTickMarkVisibleIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
+    @Test
+    public void whenTickMarkVisibleIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
         CssMetaData styleable = ((StyleableProperty)axis.tickMarkVisibleProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
     }
 
-    @Test public void canSpecifyTickMarkVisibleViaCSS() {
+    @Test
+    public void canSpecifyTickMarkVisibleViaCSS() {
         ((StyleableProperty)axis.tickMarkVisibleProperty()).applyStyle(null, Boolean.TRUE);
         assertSame(true, axis.isTickMarkVisible());
     }
 
-    @Test public void whenTickLabelsVisibleIsBound_CssMetaData_isSettable_ReturnsFalse() {
+    @Test
+    public void whenTickLabelsVisibleIsBound_CssMetaData_isSettable_ReturnsFalse() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLabelsVisibleProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
         BooleanProperty other = new SimpleBooleanProperty();
@@ -363,17 +414,20 @@ public class AxisTest {
         assertFalse(styleable.isSettable(axis));
     }
 
-    @Test public void whenTickLabelsVisibleIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
+    @Test
+    public void whenTickLabelsVisibleIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLabelsVisibleProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
     }
 
-    @Test public void canSpecifyTickLabelsVisibleViaCSS() {
+    @Test
+    public void canSpecifyTickLabelsVisibleViaCSS() {
         ((StyleableProperty)axis.tickLabelsVisibleProperty()).applyStyle(null, Boolean.TRUE);
         assertSame(true, axis.isTickMarkVisible());
     }
 
-    @Test public void whenTickLengthIsBound_CssMetaData_isSettable_ReturnsFalse() {
+    @Test
+    public void whenTickLengthIsBound_CssMetaData_isSettable_ReturnsFalse() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLengthProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
         DoubleProperty other = new SimpleDoubleProperty();
@@ -381,17 +435,20 @@ public class AxisTest {
         assertFalse(styleable.isSettable(axis));
     }
 
-    @Test public void whenTickLengthIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
+    @Test
+    public void whenTickLengthIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLengthProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
     }
 
-    @Test public void canSpecifyTickLengthViaCSS() {
+    @Test
+    public void canSpecifyTickLengthViaCSS() {
         ((StyleableProperty)axis.tickLengthProperty()).applyStyle(null, 10.34);
         assertEquals(10.34, axis.tickLengthProperty().get(), 0.000001);
     }
 
-    @Test public void whenTickLabelFontIsBound_CssMetaData_isSettable_ReturnsFalse() {
+    @Test
+    public void whenTickLabelFontIsBound_CssMetaData_isSettable_ReturnsFalse() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLabelFontProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
         ObjectProperty<Font> other = new SimpleObjectProperty<>(Font.getDefault());
@@ -399,17 +456,20 @@ public class AxisTest {
         assertFalse(styleable.isSettable(axis));
     }
 
-    @Test public void whenTickLabelFontIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
+    @Test
+    public void whenTickLabelFontIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLabelFontProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
     }
 
-    @Test public void canSpecifyTickLabelFontViaCSS() {
+    @Test
+    public void canSpecifyTickLabelFontViaCSS() {
         ((StyleableProperty)axis.tickLabelFontProperty()).applyStyle(null, Font.getDefault());
         assertSame(Font.getDefault(), axis.getTickLabelFont());
     }
 
-    @Test public void whenTickLabelFillIsBound_CssMetaData_isSettable_ReturnsFalse() {
+    @Test
+    public void whenTickLabelFillIsBound_CssMetaData_isSettable_ReturnsFalse() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLabelFillProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
         ObjectProperty<Color> other = new SimpleObjectProperty<>(Color.BROWN);
@@ -417,17 +477,20 @@ public class AxisTest {
         assertFalse(styleable.isSettable(axis));
     }
 
-    @Test public void whenTickLabelFillIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
+    @Test
+    public void whenTickLabelFillIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLabelFillProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
     }
 
-    @Test public void canSpecifyTickLabelFillViaCSS() {
+    @Test
+    public void canSpecifyTickLabelFillViaCSS() {
         ((StyleableProperty)axis.tickLabelFillProperty()).applyStyle(null, Color.BROWN);
         assertSame(Color.BROWN, axis.getTickLabelFill());
     }
 
-    @Test public void whenTickLabelGapIsBound_CssMetaData_isSettable_ReturnsFalse() {
+    @Test
+    public void whenTickLabelGapIsBound_CssMetaData_isSettable_ReturnsFalse() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLabelGapProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
         DoubleProperty other = new SimpleDoubleProperty();
@@ -435,12 +498,14 @@ public class AxisTest {
         assertFalse(styleable.isSettable(axis));
     }
 
-    @Test public void whenTickLabelGapIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
+    @Test
+    public void whenTickLabelGapIsSpecifiedViaCSSAndIsNotBound_CssMetaData_isSettable_ReturnsTrue() {
         CssMetaData styleable = ((StyleableProperty)axis.tickLabelGapProperty()).getCssMetaData();
         assertTrue(styleable.isSettable(axis));
     }
 
-    @Test public void canSpecifyTickLabelGapViaCSS() {
+    @Test
+    public void canSpecifyTickLabelGapViaCSS() {
         ((StyleableProperty)axis.tickLabelGapProperty()).applyStyle(null, 10.34);
         assertEquals(10.34, axis.getTickLabelGap(), 0.0);
     }
@@ -450,17 +515,20 @@ public class AxisTest {
     /*********************************************************************
      * Miscellaneous Tests                                         *
      ********************************************************************/
-    @Test public void setSideAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setSideAndSeeValueIsReflectedInModel() {
         axis.setSide(Side.BOTTOM);
         assertSame(axis.sideProperty().getValue(), Side.BOTTOM);
     }
 
-    @Test public void setHbarPolicyAndSeeValue() {
+    @Test
+    public void setHbarPolicyAndSeeValue() {
         axis.setSide(Side.TOP);
         assertSame(axis.getSide(), Side.TOP);
     }
 
-    @Test public void setTickMarkVisibleAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setTickMarkVisibleAndSeeValueIsReflectedInModel() {
         axis.setTickMarkVisible(false);
         assertFalse(axis.tickMarkVisibleProperty().getValue());
     }
@@ -470,85 +538,99 @@ public class AxisTest {
         assertTrue(axis.isTickMarkVisible());
     }
 
-    @Test public void setTickLabelsVisibleAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setTickLabelsVisibleAndSeeValueIsReflectedInModel() {
         axis.setTickLabelsVisible(false);
         assertFalse(axis.tickLabelsVisibleProperty().getValue());
     }
 
-    @Test public void setTickLabelsVisibleAndSeeValue() {
+    @Test
+    public void setTickLabelsVisibleAndSeeValue() {
         axis.setTickLabelsVisible(true);
         assertTrue(axis.isTickLabelsVisible());
     }
 
-    @Test public void setTickLengthAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setTickLengthAndSeeValueIsReflectedInModel() {
         axis.setTickLength(30.0);
         assertEquals(axis.tickLengthProperty().getValue(), 30.0, 0.0);
     }
 
-    @Test public void setTickLengthAndSeeValue() {
+    @Test
+    public void setTickLengthAndSeeValue() {
         axis.setTickLength(30.0);
         assertEquals(axis.getTickLength(), 30.0, 0.0);
     }
 
-    @Test public void setAutoRangingAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setAutoRangingAndSeeValueIsReflectedInModel() {
         axis.setAutoRanging(false);
         assertFalse(axis.autoRangingProperty().getValue());
     }
 
-    @Test public void setAutoRangingAndSeeValue() {
+    @Test
+    public void setAutoRangingAndSeeValue() {
         axis.setAutoRanging(true);
         assertTrue(axis.isAutoRanging());
     }
 
-    @Test public void setTickLabelFontAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setTickLabelFontAndSeeValueIsReflectedInModel() {
         axis.setTickLabelFont(Font.getDefault());
         assertSame(axis.tickLabelFontProperty().getValue(), Font.getDefault());
     }
 
-    @Test public void setTickLabelFontAndSeeValue() {
+    @Test
+    public void setTickLabelFontAndSeeValue() {
         axis.setTickLabelFont(Font.getDefault());
         assertSame(axis.getTickLabelFont(), Font.getDefault());
     }
 
-    @Test public void setTickLabelFillAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setTickLabelFillAndSeeValueIsReflectedInModel() {
         axis.setTickLabelFill(Color.AQUA);
         assertSame(axis.tickLabelFillProperty().getValue(), Color.AQUA);
     }
 
-    @Test public void setTickLabelFillAndSeeValue() {
+    @Test
+    public void setTickLabelFillAndSeeValue() {
         axis.setTickLabelFill(Color.AQUA);
         assertSame(axis.getTickLabelFill(), Color.AQUA);
     }
 
-    @Test public void setTickLabelGapAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setTickLabelGapAndSeeValueIsReflectedInModel() {
         axis.setTickLabelGap(30.0);
         assertEquals(axis.tickLabelGapProperty().getValue(), 30.0, 0.0);
     }
 
-    @Test public void setTickLabelGapAndSeeValue() {
+    @Test
+    public void setTickLabelGapAndSeeValue() {
         axis.setTickLabelGap(30.0);
         assertEquals(axis.getTickLabelGap(), 30.0, 0.0);
     }
 
-    @Test public void setAnimatedAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setAnimatedAndSeeValueIsReflectedInModel() {
         axis.setAnimated(false);
         assertFalse(axis.animatedProperty().getValue());
     }
 
-    @Test public void setAnimatedAndSeeValue() {
+    @Test
+    public void setAnimatedAndSeeValue() {
         axis.setAnimated(true);
         assertTrue(axis.getAnimated());
     }
 
-    @Test public void setTickLabelRotationAndSeeValueIsReflectedInModel() {
+    @Test
+    public void setTickLabelRotationAndSeeValueIsReflectedInModel() {
         axis.setTickLabelRotation(30.0);
         assertEquals(axis.tickLabelRotationProperty().getValue(), 30.0, 0.0);
     }
 
-    @Test public void setTickLabelRotationAndSeeValue() {
+    @Test
+    public void setTickLabelRotationAndSeeValue() {
         axis.setTickLabelRotation(30.0);
         assertEquals(axis.getTickLabelRotation(), 30.0, 0.0);
     }
-
-
 }
