@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,6 +25,11 @@
 
 package test.javafx.scene.chart;
 
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import java.util.List;
+import java.util.stream.Collectors;
 import javafx.collections.ObservableList;
 import javafx.geometry.Point2D;
 import javafx.scene.Node;
@@ -36,24 +41,20 @@ import javafx.scene.chart.XYChartShim;
 import javafx.scene.shape.LineTo;
 import javafx.scene.shape.Path;
 import javafx.scene.shape.PathElement;
-import org.junit.Ignore;
-import org.junit.Test;
-
-import java.util.List;
-import java.util.stream.Collectors;
-
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
 public class LineChartTest extends XYChartTestBase {
 
     LineChart<Number,Number> lineChart;
     final XYChart.Series<Number, Number> series1 = new XYChart.Series<>();
 
-    @Override protected Chart createChart() {
+    @Override
+    protected void createChart() {
         final NumberAxis xAxis = new NumberAxis(0, 90, 10);
         final NumberAxis yAxis = new NumberAxis(0, 30, 2);
         lineChart = new LineChart<>(xAxis,yAxis);
+        lineChart.setAnimated(false);
         xAxis.setLabel("X Axis");
         yAxis.setLabel("Y Axis");
         lineChart.setTitle("HelloLineChart");
@@ -63,6 +64,10 @@ public class LineChartTest extends XYChartTestBase {
         series1.getData().add(new XYChart.Data(30d, 15d));
         series1.getData().add(new XYChart.Data(50d, 15d));
         series1.getData().add(new XYChart.Data(80d, 10d));
+    }
+
+    @Override
+    protected Chart getChart() {
         return lineChart;
     }
 
@@ -78,6 +83,7 @@ public class LineChartTest extends XYChartTestBase {
 
     @Test
     public void testCreateSymbols() {
+        createChart();
         startApp();
         lineChart.setCreateSymbols(false);
         pulse();
@@ -95,6 +101,7 @@ public class LineChartTest extends XYChartTestBase {
 
     @Test
     public void testDataItemAdd() {
+        createChart();
         startApp();
         lineChart.getData().addAll(series1);
         pulse();
@@ -104,24 +111,27 @@ public class LineChartTest extends XYChartTestBase {
         assertEquals(7, XYChartShim.getPlotChildren(lineChart).size());
     }
 
-     @Test @Ignore
+     @Test
+     @Disabled
      // Ignored because the animation's Timeline doesn't run. It used to be that the item was added before the
      // animation was run. Now the item is added as the onFinished handler of the first KeyFrame. Since the
      // Timeline doesn't run in the context of the unit test, this test fails. In fact, this test never really
      // achieved its purpose.
-    public void testDataItemAddWithAnimation() {
-        startApp();
-        lineChart.setAnimated(true);
-        lineChart.getData().addAll(series1);
-        pulse();
-        series1.getData().add(new XYChart.Data(60d, 30d));
-        pulse();
-        // 5 stackpane nodes and 1 path node + new stackpane for data added
-        assertEquals(7, XYChartShim.getPlotChildren(lineChart).size());
-    }
+     public void testDataItemAddWithAnimation() {
+         createChart();
+         startApp();
+         lineChart.setAnimated(true);
+         lineChart.getData().addAll(series1);
+         pulse();
+         series1.getData().add(new XYChart.Data(60d, 30d));
+         pulse();
+         // 5 stackpane nodes and 1 path node + new stackpane for data added
+         assertEquals(7, XYChartShim.getPlotChildren(lineChart).size());
+     }
 
     @Test
     public void testDataItemRemove() {
+        createChart();
         startApp();
         lineChart.getData().addAll(series1);
         pulse();
@@ -133,8 +143,9 @@ public class LineChartTest extends XYChartTestBase {
         }
     }
 
-     @Test
+    @Test
     public void testSeriesAddWithAnimation() {
+        createChart();
         startApp();
         lineChart.setAnimated(true);
         final XYChart.Series<Number, Number> series2 = new XYChart.Series<>();
@@ -162,22 +173,27 @@ public class LineChartTest extends XYChartTestBase {
 
     @Test
     public void testSeriesRemoveAnimatedStyleClasses() {
+        createChart();
         startApp();
         //lineChart.setCreateSymbols(false);
         int nodesPerSeries = 4; // 3 symbols + 1 path
         checkSeriesRemoveAnimatedStyleClasses(lineChart, nodesPerSeries, 900);
     }
 
-    @Test public void testPathInsideXAndInsideYBounds() {
+    @Test
+    public void testPathInsideXAndInsideYBounds() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(85d, 15d)); // upper bound is 90, 30
         lineChart.getData().addAll(series1);
         pulse();
 
-        assertArrayEquals(convertSeriesDataToPoint2D(series1).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(series1, lineChart);
     }
 
-    @Test public void testPathOutsideXBoundsWithDuplicateXAndHigherY() {
+    @Test
+    public void testPathOutsideXBoundsWithDuplicateXAndHigherY() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(100d, 20d)); // upper bound is 90
         series1.getData().add(new XYChart.Data(100d, 50d));
@@ -194,10 +210,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(100d, 20d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXBoundsWithDuplicateXAndLowerY() {
+    @Test
+    public void testPathOutsideXBoundsWithDuplicateXAndLowerY() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(100d, 20d)); // upper bound is 90
         series1.getData().add(new XYChart.Data(100d, 15d));
@@ -214,10 +232,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(100d, 20d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideYBoundsWithDuplicateYAndHigherX() {
+    @Test
+    public void testPathOutsideYBoundsWithDuplicateYAndHigherX() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(80d, 32d)); // upper bound is 30
         series1.getData().add(new XYChart.Data(90d, 32d));
@@ -235,10 +255,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(90d, 32d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideYBoundsWithDuplicateYAndLowerX() {
+    @Test
+    public void testPathOutsideYBoundsWithDuplicateYAndLowerX() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(85d, 40d)); // upper bound is 30
         series1.getData().add(new XYChart.Data(90d, 40d));
@@ -256,10 +278,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(90d, 40d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYBoundsWithDuplicateXAndHigherY() {
+    @Test
+    public void testPathOutsideXAndYBoundsWithDuplicateXAndHigherY() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(95d, 35d)); // upper bound is 90,30
         series1.getData().add(new XYChart.Data<>(95d, 40d));
@@ -276,10 +300,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(95d, 35d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYBoundsWithDuplicateXAndLowerY() {
+    @Test
+    public void testPathOutsideXAndYBoundsWithDuplicateXAndLowerY() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(95d, 40d)); // upper bound is 90,30
         series1.getData().add(new XYChart.Data<>(95d, 35d));
@@ -296,10 +322,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(95d, 40d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYBoundsWithDuplicateYAndHigherX() {
+    @Test
+    public void testPathOutsideXAndYBoundsWithDuplicateYAndHigherX() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(95d, 32d)); // upper bound is 90,30
         series1.getData().add(new XYChart.Data<>(100d, 32d));
@@ -316,10 +344,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(95d, 32d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYBoundsWithDuplicateYAndLowerX() {
+    @Test
+    public void testPathOutsideXAndYBoundsWithDuplicateYAndLowerX() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(100d, 40d)); // upper bound is 90,30
         series1.getData().add(new XYChart.Data<>(95d, 40d));
@@ -336,10 +366,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(95d, 40d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXLowerBoundsWithDuplicateXAndHigherYWithSortYAxis() {
+    @Test
+    public void testPathOutsideXLowerBoundsWithDuplicateXAndHigherYWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(-10d, 20d)); // lower bound is 0
         series1.getData().add(new XYChart.Data(-10d, 50d));
@@ -358,10 +390,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXUpperBoundsWithDuplicateXAndHigherYWithSortYAxis() {
+    @Test
+    public void testPathOutsideXUpperBoundsWithDuplicateXAndHigherYWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(100d, 20d)); // upper bound is 90
         series1.getData().add(new XYChart.Data(100d, 50d));
@@ -380,10 +414,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXLowerBoundsWithDuplicateXAndLowerYWithSortYAxis() {
+    @Test
+    public void testPathOutsideXLowerBoundsWithDuplicateXAndLowerYWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(-10d, 20d)); // lower bound is 0
         series1.getData().add(new XYChart.Data(-10d, 15d));
@@ -402,10 +438,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXUpperBoundsWithDuplicateXAndLowerYWithSortYAxis() {
+    @Test
+    public void testPathOutsideXUpperBoundsWithDuplicateXAndLowerYWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(100d, 20d)); // upper bound is 90
         series1.getData().add(new XYChart.Data(100d, 15d));
@@ -424,10 +462,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideYLowerBoundsWithDuplicateYAndHigherXWithSortYAxis() {
+    @Test
+    public void testPathOutsideYLowerBoundsWithDuplicateYAndHigherXWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(80d, -10d)); // lower bound is 0
         series1.getData().add(new XYChart.Data(90d, -10d));
@@ -445,10 +485,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, -10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideYUpperBoundsWithDuplicateYAndHigherXWithSortYAxis() {
+    @Test
+    public void testPathOutsideYUpperBoundsWithDuplicateYAndHigherXWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(80d, 32d)); // upper bound is 30
         series1.getData().add(new XYChart.Data(90d, 32d));
@@ -466,10 +508,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideYLowerBoundsWithDuplicateYAndLowerXWithSortYAxis() {
+    @Test
+    public void testPathOutsideYLowerBoundsWithDuplicateYAndLowerXWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(80d, -10d)); // lower bound is 0
         series1.getData().add(new XYChart.Data(70d, -10d));
@@ -486,10 +530,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d),
                 new XYChart.Data<>(80d, -10d)
         );
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideYUpperBoundsWithDuplicateYAndLowerXWithSortYAxis() {
+    @Test
+    public void testPathOutsideYUpperBoundsWithDuplicateYAndLowerXWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data(80d, 40d)); // upper bound is 30
         series1.getData().add(new XYChart.Data(70d, 40d));
@@ -507,10 +553,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYLowerBoundsWithDuplicateXAndHigherYWithSortYAxis() {
+    @Test
+    public void testPathOutsideXAndYLowerBoundsWithDuplicateXAndHigherYWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(95d, -10d)); // lower bound is 0,0
         series1.getData().add(new XYChart.Data<>(95d, -5d));
@@ -529,10 +577,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(95d, -10d)*/
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYUpperBoundsWithDuplicateXAndHigherYWithSortYAxis() {
+    @Test
+    public void testPathOutsideXAndYUpperBoundsWithDuplicateXAndHigherYWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(95d, 35d)); // upper bound is 90,30
         series1.getData().add(new XYChart.Data<>(95d, 40d));
@@ -550,10 +600,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYLowerBoundsWithDuplicateXAndLowerYWithSortYAxis() {
+    @Test
+    public void testPathOutsideXAndYLowerBoundsWithDuplicateXAndLowerYWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(-10d, -10d)); // lower bound is 0,0
         series1.getData().add(new XYChart.Data<>(-10d, -20d));
@@ -571,10 +623,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(-10d, -10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYUpperBoundsWithDuplicateXAndLowerYWithSortYAxis() {
+    @Test
+    public void testPathOutsideXAndYUpperBoundsWithDuplicateXAndLowerYWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(95d, 40d)); // upper bound is 90,30
         series1.getData().add(new XYChart.Data<>(95d, 35d));
@@ -592,10 +646,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYLowerBoundsWithDuplicateYAndHigherXWithSortYAxis() {
+    @Test
+    public void testPathOutsideXAndYLowerBoundsWithDuplicateYAndHigherXWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(-15d, -10d)); // lower bound is 0,0
         series1.getData().add(new XYChart.Data<>(-10d, -10d));
@@ -613,10 +669,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(-15d, -10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYUpperBoundsWithDuplicateYAndHigherXWithSortYAxis() {
+    @Test
+    public void testPathOutsideXAndYUpperBoundsWithDuplicateYAndHigherXWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(95d, 32d)); // upper bound is 90,30
         series1.getData().add(new XYChart.Data<>(100d, 32d));
@@ -634,10 +692,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYLowerBoundsWithDuplicateYAndLowerXWithSortYAxis() {
+    @Test
+    public void testPathOutsideXAndYLowerBoundsWithDuplicateYAndLowerXWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(-10d, -10d)); // lower bound is 0,0
         series1.getData().add(new XYChart.Data<>(-15d, -10d));
@@ -655,10 +715,12 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(-10d, -10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
     }
 
-    @Test public void testPathOutsideXAndYUpperBoundsWithDuplicateYAndLowerXWithSortYAxis() {
+    @Test
+    public void testPathOutsideXAndYUpperBoundsWithDuplicateYAndLowerXWithSortYAxis() {
+        createChart();
         startApp();
         series1.getData().add(new XYChart.Data<>(100d, 40d)); // upper bound is 90,30
         series1.getData().add(new XYChart.Data<>(95d, 40d));
@@ -676,7 +738,20 @@ public class LineChartTest extends XYChartTestBase {
                 new XYChart.Data<>(80d, 10d)
         );
 
-        assertArrayEquals(convertSeriesDataToPoint2D(expectedSeries).toArray(), findDataPointsFromPathLine(lineChart).toArray());
+        eq(expectedSeries, lineChart);
+    }
+
+    //JDK-8283675
+    @Test
+    public void testChartLineRemovedOnClearingSeries() {
+        createChart();
+        startApp();
+        lineChart.getData().addAll(series1);
+        pulse();
+        assertTrue(0 < ((Path)series1.getNode()).getElements().size());
+        series1.getData().clear();
+        pulse();
+        assertEquals(0, ((Path)series1.getNode()).getElements().size());
     }
 
     private List<Point2D> convertSeriesDataToPoint2D(XYChart.Series<Number, Number> series) {
@@ -702,4 +777,17 @@ public class LineChartTest extends XYChartTestBase {
                 .collect(Collectors.toList());
         return data.subList(0, data.size());
     }
+
+    private void eq(XYChart.Series<Number, Number> expected, LineChart<Number, Number> ch) {
+        List<Point2D> exp = convertSeriesDataToPoint2D(expected);
+        List<Point2D> res = findDataPointsFromPathLine(lineChart);
+
+        assertEquals(exp.size(), res.size());
+        for (int i = 0; i < exp.size(); i++) {
+            Point2D pe = exp.get(i);
+            Point2D pr = res.get(i);
+            assertEquals(pe.getX(), pr.getX(), 1e-9, "at index " + i + " expected=" + pe + " actual=" + pr);
+            assertEquals(pe.getY(), pr.getY(), 1e-9, "at index " + i + " expected=" + pe + " actual=" + pr);
+        }
+    }
 }
