@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,25 +25,25 @@
 
 package test.javafx.scene.control;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static test.com.sun.javafx.scene.control.infrastructure.ControlSkinFactory.attemptGC;
+import static test.com.sun.javafx.scene.control.infrastructure.ControlTestUtils.assertStyleClassContains;
 import java.lang.ref.WeakReference;
 import java.util.ArrayList;
 import java.util.List;
-
-import javafx.beans.property.SimpleStringProperty;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
-
-import com.sun.javafx.tk.Toolkit;
-
-import static org.junit.Assert.*;
-import static test.com.sun.javafx.scene.control.infrastructure.ControlTestUtils.*;
-import static test.com.sun.javafx.scene.control.infrastructure.ControlSkinFactory.*;
-
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicInteger;
 import javafx.beans.property.SimpleObjectProperty;
+import javafx.beans.property.SimpleStringProperty;
 import javafx.collections.FXCollections;
 import javafx.collections.ObservableList;
 import javafx.scene.control.CellShim;
+import javafx.scene.control.IndexedCell;
 import javafx.scene.control.MenuItem;
 import javafx.scene.control.TableCell;
 import javafx.scene.control.TableCellShim;
@@ -53,20 +53,25 @@ import javafx.scene.control.TablePosition;
 import javafx.scene.control.TableRow;
 import javafx.scene.control.TableView;
 import javafx.scene.control.skin.TableCellSkin;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import com.sun.javafx.tk.Toolkit;
 import test.com.sun.javafx.scene.control.infrastructure.StageLoader;
 import test.com.sun.javafx.scene.control.infrastructure.VirtualFlowTestUtils;
 
 /**
  */
 public class TableCellTest {
-    private TableCell<String,String> cell;
+    private TableCellShim<String, String> cell;
     private TableView<String> table;
     private TableColumn<String, String> editingColumn;
     private TableRow<String> row;
     private ObservableList<String> model;
     private StageLoader stageLoader;
 
-    @Before public void setup() {
+    @BeforeEach
+    public void setup() {
         Thread.currentThread().setUncaughtExceptionHandler((thread, throwable) -> {
             if (throwable instanceof RuntimeException) {
                 throw (RuntimeException)throwable;
@@ -75,7 +80,7 @@ public class TableCellTest {
             }
         });
 
-        cell = new TableCell<>();
+        cell = new TableCellShim<>();
         model = FXCollections.observableArrayList("Four", "Five", "Fear"); // "Flop", "Food", "Fizz"
         table = new TableView<>(model);
         editingColumn = new TableColumn<>("TEST");
@@ -83,7 +88,7 @@ public class TableCellTest {
         row = new TableRow<>();
     }
 
-    @After
+    @AfterEach
     public void cleanup() {
         if (stageLoader != null) stageLoader.dispose();
         Thread.currentThread().setUncaughtExceptionHandler(null);
@@ -216,8 +221,8 @@ public class TableCellTest {
         assertNull(cell.getItem());
         assertFalse(cell.isEmpty());
 
-        // This test used to be as shown below....but due to RT-33108, it changed
-        // to the enabled code beneath. Refer to the first comment in RT-33108
+        // This test used to be as shown below....but due to JDK-8122970, it changed
+        // to the enabled code beneath. Refer to the first comment in JDK-8122970
         // for more detail, but in short we can't optimise and not call updateItem
         // when the new and old items are the same - doing so means we can end
         // up with bad bindings, etc in the individual cells (in other words,
@@ -489,8 +494,8 @@ public class TableCellTest {
         List<CellEditEvent<?, ?>> events = new ArrayList<>();
         editingColumn.setOnEditCancel(events::add);
         cell.cancelEdit();
-        assertEquals("column must have received editCancel", 1, events.size());
-        assertEquals("editing location of cancel event", editingPosition, events.get(0).getTablePosition());
+        assertEquals(1, events.size(), "column must have received editCancel");
+        assertEquals(editingPosition, events.get(0).getTablePosition(), "editing location of cancel event");
     }
 
     @Test
@@ -503,8 +508,8 @@ public class TableCellTest {
         List<CellEditEvent<?, ?>> events = new ArrayList<>();
         editingColumn.setOnEditCancel(events::add);
         table.edit(-1, null);
-        assertEquals("column must have received editCancel", 1, events.size());
-        assertEquals("editing location of cancel event", editingPosition, events.get(0).getTablePosition());
+        assertEquals(1, events.size(), "column must have received editCancel");
+        assertEquals(editingPosition, events.get(0).getTablePosition(), "editing location of cancel event");
     }
 
     @Test
@@ -517,8 +522,8 @@ public class TableCellTest {
         List<CellEditEvent<?, ?>> events = new ArrayList<>();
         editingColumn.setOnEditCancel(events::add);
         cell.updateIndex(0);
-        assertEquals("column must have received editCancel", 1, events.size());
-        assertEquals("editing location of cancel event", editingPosition, events.get(0).getTablePosition());
+        assertEquals(1, events.size(), "column must have received editCancel");
+        assertEquals(editingPosition, events.get(0).getTablePosition(), "editing location of cancel event");
     }
 
     @Test
@@ -532,8 +537,8 @@ public class TableCellTest {
         editingColumn.setOnEditCancel(events::add);
         table.getItems().add(0, "added");
         Toolkit.getToolkit().firePulse();
-        assertEquals("column must have received editCancel", 1, events.size());
-        assertEquals("editing location of cancel event", editingPosition, events.get(0).getTablePosition());
+        assertEquals(1, events.size(), "column must have received editCancel");
+        assertEquals(editingPosition, events.get(0).getTablePosition(), "editing location of cancel event");
     }
 
     /**
@@ -551,9 +556,9 @@ public class TableCellTest {
         editingColumn.setOnEditCancel(events::add);
         table.getItems().remove(editingIndex);
         Toolkit.getToolkit().firePulse();
-        assertNull("sanity: editing terminated on items modification", table.getEditingCell());
-        assertEquals("column must have received editCancel", 1, events.size());
-        assertEquals("editing location of cancel event", editingPosition, events.get(0).getTablePosition());
+        assertNull(table.getEditingCell(), "sanity: editing terminated on items modification");
+        assertEquals(1, events.size(), "column must have received editCancel");
+        assertEquals(editingPosition, events.get(0).getTablePosition(), "editing location of cancel event");
     }
 
     /**
@@ -576,7 +581,7 @@ public class TableCellTest {
         editingItem = null;
         Toolkit.getToolkit().firePulse();
         attemptGC(itemRef);
-        assertEquals("item must be gc'ed", null, itemRef.get());
+        assertEquals(null, itemRef.get(), "item must be gc'ed");
     }
 
     @Test
@@ -586,7 +591,7 @@ public class TableCellTest {
         List<CellEditEvent<?, ?>> events = new ArrayList<>();
         editingColumn.setOnEditStart(events::add);
         cell.startEdit();
-        assertEquals("startEdit must fire", 1, events.size());
+        assertEquals(1, events.size(), "startEdit must fire");
     }
 
     @Test
@@ -596,7 +601,7 @@ public class TableCellTest {
         cell.updateIndex(editingRow);
         TablePosition<?, ?> editingCell = new TablePosition<>(table, editingRow, editingColumn);
         cell.startEdit();
-        assertEquals("table must be editing at", editingCell, table.getEditingCell());
+        assertEquals(editingCell, table.getEditingCell(), "table must be editing at");
     }
 
     @Test
@@ -608,7 +613,7 @@ public class TableCellTest {
         TablePosition<?, ?> editingCell = new TablePosition<>(table, editingRow, null);
         cell.startEdit();
         assertTrue(cell.isEditing());
-        assertEquals("table must be editing at", editingCell, table.getEditingCell());
+        assertEquals(editingCell, table.getEditingCell(), "table must be editing at");
     }
 
     @Test
@@ -619,7 +624,7 @@ public class TableCellTest {
         List<CellEditEvent<?, ?>> events = new ArrayList<>();
         editingColumn.setOnEditStart(events::add);
         cell.startEdit();
-        assertEquals("startEdit must not fire while editing", 0, events.size());
+        assertEquals(0, events.size(), "startEdit must not fire while editing");
     }
 
     @Test
@@ -665,8 +670,8 @@ public class TableCellTest {
         editingColumn.setOnEditCancel(events::add);
         String value = "edited";
         cell.commitEdit(value);
-        assertEquals("sanity: value committed", value, table.getItems().get(editingRow));
-        assertEquals("commit must not have fired editCancel", 0, events.size());
+        assertEquals(value, table.getItems().get(editingRow), "sanity: value committed");
+        assertEquals(0, events.size(), "commit must not have fired editCancel");
     }
 
 
@@ -682,9 +687,8 @@ public class TableCellTest {
          List<CellEditEvent<?, ?>> events = new ArrayList<>();
          editingColumn.setOnEditCommit(events::add);
          cell.commitEdit("edited");
-         assertEquals("column must have received editCommit", 1, events.size());
-         assertEquals("editing location of commit event must be same as table's editingCell",
-                 editingPosition, events.get(0).getTablePosition());
+         assertEquals(1, events.size(), "column must have received editCommit");
+         assertEquals(editingPosition, events.get(0).getTablePosition(), "editing location of commit event must be same as table's editingCell");
      }
 
      @Test
@@ -697,9 +701,8 @@ public class TableCellTest {
          List<CellEditEvent<?, ?>> events = new ArrayList<>();
          editingColumn.setOnEditCommit(events::add);
          cell.commitEdit("edited");
-         assertEquals("column must have received editCommit", 1, events.size());
-         assertEquals("editing location of commit event  must be same as editingCellAtStartEdit",
-                 editingCellAtStartEdit, events.get(0).getTablePosition());
+         assertEquals(1, events.size(), "column must have received editCommit");
+         assertEquals(editingCellAtStartEdit, events.get(0).getTablePosition(), "editing location of commit event  must be same as editingCellAtStartEdit");
      }
 
      @Test
@@ -710,9 +713,8 @@ public class TableCellTest {
          List<CellEditEvent<?, ?>> events = new ArrayList<>();
          editingColumn.addEventHandler(TableColumn.editAnyEvent(), events::add);
          cell.commitEdit("edited");
-         assertEquals("column must have received editCommit", 1, events.size());
-         assertEquals("editing location of commit event must be same as editingCellAtStartEdit",
-                 editingCellAtStartEdit, events.get(0).getTablePosition());
+         assertEquals(1, events.size(), "column must have received editCommit");
+         assertEquals(editingCellAtStartEdit, events.get(0).getTablePosition(), "editing location of commit event must be same as editingCellAtStartEdit");
      }
 
 // --- JDK-8271474: implement consistent event firing pattern
@@ -799,8 +801,8 @@ public class TableCellTest {
          List<CellEditEvent<?, ?>> events = new ArrayList<>();
          editingColumn.addEventHandler(TableColumn.editStartEvent(), events::add);
          cell.startEdit();
-         assertFalse("sanity: off-range cell must not be editing", cell.isEditing());
-         assertEquals("must not fire editStart", 0, events.size());
+         assertFalse(cell.isEditing(), "sanity: off-range cell must not be editing");
+         assertEquals(0, events.size(), "must not fire editStart");
      }
 
      @Test
@@ -809,8 +811,8 @@ public class TableCellTest {
          int editingRow = table.getItems().size();
          cell.updateIndex(editingRow);
          cell.startEdit();
-         assertFalse("sanity: off-range cell must not be editing", cell.isEditing());
-         assertNull("table editing location must not be updated", table.getEditingCell());
+         assertFalse(cell.isEditing(), "sanity: off-range cell must not be editing");
+         assertNull(table.getEditingCell(), "table editing location must not be updated");
      }
 
  //--------- test the test setup
@@ -852,7 +854,7 @@ public class TableCellTest {
          }
          if (editingColumn != null ) cell.updateTableColumn(editingColumn);
          // force into editable state (not empty)
-         TableCellShim.set_lockItemOnEdit(cell, true);
+         cell.setLockItemOnStartEdit(true);
          CellShim.updateItem(cell, "something", false);
      }
 
@@ -879,29 +881,103 @@ public class TableCellTest {
         int intermediate = 0;
         cell.updateIndex(editingIndex);
         table.edit(editingIndex, editingColumn);
-        assertTrue("sanity: ", cell.isEditing());
+        assertTrue(cell.isEditing(), "sanity: ");
         try {
             table.edit(intermediate, editingColumn);
         } catch (Exception ex) {
             // just catching to test in finally
         } finally {
-            assertFalse("cell must not be editing", cell.isEditing());
-            assertEquals("table must be editing at intermediate index", intermediate, table.getEditingCell().getRow());
+            assertFalse(cell.isEditing(), "cell must not be editing");
+            assertEquals(intermediate, table.getEditingCell().getRow(), "table must be editing at intermediate index");
         }
         // test editing: second round
         // switch cell off editing by cell api
         table.edit(editingIndex, editingColumn);
-        assertTrue("sanity: ", cell.isEditing());
+        assertTrue(cell.isEditing(), "sanity: ");
         try {
             cell.cancelEdit();
         } catch (Exception ex) {
             // just catching to test in finally
         } finally {
-            assertFalse("cell must not be editing", cell.isEditing());
-            assertNull("table editing must be cancelled by cell", table.getEditingCell());
+            assertFalse(cell.isEditing(), "cell must not be editing");
+            assertNull(table.getEditingCell(), "table editing must be cancelled by cell");
         }
     }
 
+    /**
+     * See also: <a href="https://bugs.openjdk.org/browse/JDK-8187314">JDK-8187314</a>.
+     */
+    @Test
+    public void testEditCommitValueChangeIsReflectedInCell() {
+        setupForEditing();
+        editingColumn.setCellValueFactory(cc -> new SimpleObjectProperty<>(cc.getValue()));
+        editingColumn.setOnEditCommit(event -> {
+            assertEquals("ABCDEF", event.getNewValue());
+            // Change the underlying item.
+            model.set(0, "ABCDEF [Changed]");
+        });
+
+        cell.updateIndex(0);
+
+        assertEquals("Four", cell.getItem());
+
+        cell.startEdit();
+        cell.commitEdit("ABCDEF");
+
+        assertEquals("ABCDEF [Changed]", cell.getItem());
+    }
+
+    /**
+     * Same index and underlying item should not cause the updateItem(..) method to be called.
+     */
+    @Test
+    public void testSameIndexAndItemShouldNotUpdateItem() {
+        AtomicInteger counter = new AtomicInteger();
+
+        editingColumn.setCellFactory(view -> new TableCell<>() {
+            @Override
+            protected void updateItem(String item, boolean empty) {
+                counter.incrementAndGet();
+                super.updateItem(item, empty);
+            }
+        });
+        setupForEditing();
+
+        stageLoader = new StageLoader(table);
+
+        counter.set(0);
+        IndexedCell<String> cell = VirtualFlowTestUtils.getCell(table, 0, 0);
+        cell.updateIndex(0);
+
+        assertEquals(0, counter.get());
+    }
+
+    /**
+     * The contract of a {@link TableCell} is that isItemChanged(..)
+     * is called when the index is 'changed' to the same number as the old one, to evaluate if we need to call
+     * updateItem(..).
+     */
+    @Test
+    public void testSameIndexIsItemsChangedShouldBeCalled() {
+        AtomicBoolean isItemChangedCalled = new AtomicBoolean();
+
+        editingColumn.setCellFactory(view -> new TableCell<>() {
+            @Override
+            protected boolean isItemChanged(String oldItem, String newItem) {
+                isItemChangedCalled.set(true);
+                return super.isItemChanged(oldItem, newItem);
+            }
+        });
+        setupForEditing();
+
+        stageLoader = new StageLoader(table);
+
+        IndexedCell<String> cell = VirtualFlowTestUtils.getCell(table, 0, 0);
+        cell.updateIndex(0);
+
+        assertTrue(isItemChangedCalled.get());
+    }
+
     public static class MisbehavingOnCancelTableCell<S, T> extends TableCell<S, T> {
 
         @Override
