@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,9 +25,10 @@
 
 package test.javafx.scene.control;
 
-import java.util.Arrays;
-import java.util.Collection;
-
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import javafx.collections.FXCollections;
 import javafx.collections.ListChangeListener;
 import javafx.collections.ObservableList;
@@ -41,18 +42,12 @@ import javafx.scene.control.TableView.TableViewSelectionModel;
 import javafx.scene.control.TableViewShim;
 import javafx.scene.control.TreeViewShim;
 import javafx.scene.control.cell.PropertyValueFactory;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import test.com.sun.javafx.scene.control.test.Person;
 
-import org.junit.After;
-import org.junit.AfterClass;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
-import org.junit.runners.Parameterized.Parameters;
-
-import static org.junit.Assert.*;
-
 /**
  * Unit tests that are specific for the TableViewSelectionModel API. Other tests
  * for the MultipleSelectionModel API (from which TableViewSelectionModel
@@ -60,13 +55,13 @@ import static org.junit.Assert.*;
  *
  * @author Jonathan Giles
  */
-@RunWith(Parameterized.class)
 public class TableViewSelectionModelImplTest {
 
     private TableViewSelectionModel<String> model;
     private TableViewFocusModel focusModel;
 
-    private Class<? extends TableViewSelectionModel >modelClass;
+    // converted from parameterized test with just one choice
+    private static final Class<? extends TableViewSelectionModel>modelClass = TableViewShim.get_TableViewArrayListSelectionModel_class();
 
     // ListView model data
     private static ObservableList<String> defaultData = FXCollections.<String>observableArrayList();
@@ -97,24 +92,13 @@ public class TableViewSelectionModelImplTest {
             col1 = new TableColumn<>(),
             col2 = new TableColumn<>()
         );
-
-
-        // --- TableView init
     }
 
-    @Parameters public static Collection implementations() {
-        return Arrays.asList(new Object[][] {
-            { TableViewShim.get_TableViewArrayListSelectionModel_class() }
-        });
-    }
+    @AfterAll
+    public static void tearDownClass() throws Exception {    }
 
-    public TableViewSelectionModelImplTest(Class<? extends TableViewSelectionModel> modelClass) {
-        this.modelClass = modelClass;
-    }
-
-    @AfterClass public static void tearDownClass() throws Exception {    }
-
-    @Before public void setUp() throws Exception {
+    @BeforeEach
+    public void setUp() throws Exception {
         // reset the data model
         data.setAll(defaultData);
 
@@ -129,7 +113,8 @@ public class TableViewSelectionModelImplTest {
         }
     }
 
-    @After public void tearDown() {
+    @AfterEach
+    public void tearDown() {
         model = null;
     }
 
@@ -173,7 +158,7 @@ public class TableViewSelectionModelImplTest {
         model.select(3);
         assertFalse(model.isSelected(1, col0));
         assertFalse(model.isSelected(3, col0));
-        assertFalse(cells(model), model.isSelected(3, null));
+        assertFalse(model.isSelected(3, null), cells(model));
         assertTrue(model.isSelected(3));
         assertEquals(1, model.getSelectedCells().size());
     }
@@ -186,7 +171,7 @@ public class TableViewSelectionModelImplTest {
 
         assertFalse(model.isSelected(1, col0));
         assertFalse(model.isSelected(3, col0));
-        assertFalse(cells(model), model.isSelected(3, null));
+        assertFalse(model.isSelected(3, null), cells(model));
         assertTrue(model.isSelected(3));
         assertEquals(1, model.getSelectedCells().size());
     }
@@ -319,8 +304,8 @@ public class TableViewSelectionModelImplTest {
         model.select(2, col1);
         assertTrue(model.isSelected(2, col1));
         model.selectNext();
-        assertFalse(cells(model), model.isSelected(2, col1));
-        assertTrue(cells(model), model.isSelected(2, col2));
+        assertFalse(model.isSelected(2, col1), cells(model));
+        assertTrue(model.isSelected(2, col2), cells(model));
     }
 
     @Test public void selectPreviousRowInCellSelectionMode() {
@@ -361,8 +346,8 @@ public class TableViewSelectionModelImplTest {
         model.clearSelection();
         model.select(2, col1);
         model.selectLeftCell();
-        assertTrue(cells(model), model.isSelected(2, col1));
-        assertTrue(cells(model), model.isSelected(2, col0));
+        assertTrue(model.isSelected(2, col1), cells(model));
+        assertTrue(model.isSelected(2, col0), cells(model));
         assertEquals(2, model.getSelectedCells().size());
     }
 
@@ -372,8 +357,8 @@ public class TableViewSelectionModelImplTest {
         model.clearSelection();
         model.select(2, col1);
         model.selectRightCell();
-        assertTrue(cells(model), model.isSelected(2, col1));
-        assertTrue(cells(model), model.isSelected(2, col2));
+        assertTrue(model.isSelected(2, col1), cells(model));
+        assertTrue(model.isSelected(2, col2), cells(model));
         assertEquals(2, model.getSelectedCells().size());
     }
 
@@ -382,7 +367,7 @@ public class TableViewSelectionModelImplTest {
         assertFalse(model.isSelected(0, null));
 
         model.select(10);
-        assertFalse(cells(model), model.isSelected(10, null));
+        assertFalse(model.isSelected(10, null), cells(model));
         assertEquals(1, model.getSelectedCells().size());
     }
 
@@ -391,8 +376,8 @@ public class TableViewSelectionModelImplTest {
         model.select(2, col2);
         assertEquals(2, model.getSelectedCells().get(0).getRow());
         assertEquals(col2, model.getSelectedCells().get(0).getTableColumn());
-        assertTrue(cells(model), model.isSelected(2, col2));
-        assertTrue(cells(model), model.isSelected(2));
+        assertTrue(model.isSelected(2, col2), cells(model));
+        assertTrue(model.isSelected(2), cells(model));
     }
 
     @Test public void clearSelectionOfSelectedCell() {
@@ -415,15 +400,15 @@ public class TableViewSelectionModelImplTest {
         assertTrue(model.isSelected(2));
         assertTrue(model.isSelected(3));
         model.clearSelection(2);
-        assertFalse(indices(model), model.isSelected(2));
-        assertTrue(indices(model), model.isSelected(3));
+        assertFalse(model.isSelected(2), indices(model));
+        assertTrue(model.isSelected(3), indices(model));
     }
 
     @Test public void selectNextCellWhenAtFirstCell() {
         model.setCellSelectionEnabled(true);
         model.select(0, col0);
         model.selectBelowCell();
-        assertTrue(cells(model), model.isSelected(1, col0));
+        assertTrue(model.isSelected(1, col0), cells(model));
     }
 
 
@@ -433,8 +418,8 @@ public class TableViewSelectionModelImplTest {
         model.setCellSelectionEnabled(false);
         model.select(4);
         model.selectFirst();
-        assertTrue(cells(model), model.isSelected(0, null));
-        assertTrue(cells(model), model.isSelected(0));
+        assertTrue(model.isSelected(0, null), cells(model));
+        assertTrue(model.isSelected(0), cells(model));
         assertEquals(1, model.getSelectedCells().size());
     }
 
@@ -445,9 +430,9 @@ public class TableViewSelectionModelImplTest {
         model.selectFirst();
 
         // we should go to the top of the currently focused cells column (i.e column 1)
-        assertTrue(cells(model), model.isSelected(0, col1));
-        assertFalse(cells(model), model.isSelected(0, null));
-        assertFalse(cells(model), model.isSelected(0, col0));
+        assertTrue(model.isSelected(0, col1), cells(model));
+        assertFalse(model.isSelected(0, null), cells(model));
+        assertFalse(model.isSelected(0, col0), cells(model));
         assertEquals(1, model.getSelectedCells().size());
     }
 
@@ -456,9 +441,9 @@ public class TableViewSelectionModelImplTest {
         model.setCellSelectionEnabled(false);
         model.select(4);
         model.selectFirst();
-        assertTrue(cells(model), model.isSelected(0));
-        assertTrue(cells(model), model.isSelected(0, null));
-        assertTrue(cells(model), model.isSelected(4));
+        assertTrue(model.isSelected(0), cells(model));
+        assertTrue(model.isSelected(0, null), cells(model));
+        assertTrue(model.isSelected(4), cells(model));
         assertEquals(2, model.getSelectedCells().size());
     }
 
@@ -468,8 +453,8 @@ public class TableViewSelectionModelImplTest {
         model.clearSelection();
         model.select(4, col1);
         model.selectFirst();
-        assertTrue(cells(model), model.isSelected(0, col1));
-        assertTrue(cells(model), model.isSelected(4, col1));
+        assertTrue(model.isSelected(0, col1), cells(model));
+        assertTrue(model.isSelected(4, col1), cells(model));
         assertEquals(2, model.getSelectedCells().size());
     }
 
@@ -480,7 +465,7 @@ public class TableViewSelectionModelImplTest {
         model.setCellSelectionEnabled(false);
         model.select(4);
         model.selectLast();
-        assertTrue(cells(model), model.isSelected(tableView.getItems().size() - 1));
+        assertTrue(model.isSelected(tableView.getItems().size() - 1), cells(model));
         assertEquals(1, model.getSelectedCells().size());
     }
 
@@ -489,7 +474,7 @@ public class TableViewSelectionModelImplTest {
         model.setCellSelectionEnabled(true);
         model.select(4, col1);
         model.selectLast();
-        assertTrue(cells(model), model.isSelected(tableView.getItems().size() - 1, col1));
+        assertTrue(model.isSelected(tableView.getItems().size() - 1, col1), cells(model));
         assertEquals(1, model.getSelectedCells().size());
     }
 
@@ -499,8 +484,8 @@ public class TableViewSelectionModelImplTest {
         model.clearSelection();
         model.select(4);
         model.selectLast();
-        assertTrue(cells(model), model.isSelected(tableView.getItems().size() - 1));
-        assertTrue(cells(model), model.isSelected(4));
+        assertTrue(model.isSelected(tableView.getItems().size() - 1), cells(model));
+        assertTrue(model.isSelected(4), cells(model));
         assertEquals(2, model.getSelectedCells().size());
     }
 
@@ -510,15 +495,15 @@ public class TableViewSelectionModelImplTest {
         model.clearSelection();
         model.select(4, col1);
         model.selectLast();
-        assertTrue(cells(model), model.isSelected(tableView.getItems().size() - 1, col1));
-        assertTrue(cells(model), model.isSelected(4, col1));
+        assertTrue(model.isSelected(tableView.getItems().size() - 1, col1), cells(model));
+        assertTrue(model.isSelected(4, col1), cells(model));
         assertEquals(2, model.getSelectedCells().size());
     }
 
     @Test public void selectCellInRowSelectionMode_expectCellInformationToRemain() {
         model.setCellSelectionEnabled(false);
         model.select(4, col0);
-        assertEquals(cells(model), col0, model.getSelectedCells().get(0).getTableColumn());
+        assertEquals(col0, model.getSelectedCells().get(0).getTableColumn(), cells(model));
         assertEquals(col0, focusModel.getFocusedCell().getTableColumn());
         assertTrue(model.isSelected(4, col0));
         assertTrue(model.isSelected(4));
@@ -531,41 +516,41 @@ public class TableViewSelectionModelImplTest {
         model.clearSelection();
 
         model.select(0, col0);
-        assertTrue(cells(model), model.isSelected(0));
-        assertFalse(cells(model), model.isSelected(1));
-        assertFalse(cells(model), model.isSelected(2));
+        assertTrue(model.isSelected(0), cells(model));
+        assertFalse(model.isSelected(1), cells(model));
+        assertFalse(model.isSelected(2), cells(model));
 
         model.select(1, col0);
         model.select(1, col1);
-        assertTrue(cells(model), model.isSelected(0));
-        assertTrue(cells(model), model.isSelected(1));
-        assertFalse(cells(model), model.isSelected(2));
+        assertTrue(model.isSelected(0), cells(model));
+        assertTrue(model.isSelected(1), cells(model));
+        assertFalse(model.isSelected(2), cells(model));
 
         model.select(2, col0);
         model.select(2, col1);
         model.select(2, col2);
-        assertTrue(cells(model), model.isSelected(0));
-        assertTrue(cells(model), model.isSelected(1));
-        assertTrue(cells(model), model.isSelected(2));
+        assertTrue(model.isSelected(0), cells(model));
+        assertTrue(model.isSelected(1), cells(model));
+        assertTrue(model.isSelected(2), cells(model));
 
-        assertFalse(cells(model), model.isSelected(3));
+        assertFalse(model.isSelected(3), cells(model));
 
         assertEquals(6, model.getSelectedCells().size());
 
         model.clearSelection(0, col0);
-        assertFalse(cells(model), model.isSelected(0));
+        assertFalse(model.isSelected(0), cells(model));
 
         model.clearSelection(1, col0);
-        assertTrue(cells(model), model.isSelected(1));
+        assertTrue(model.isSelected(1), cells(model));
         model.clearSelection(1, col1);
-        assertFalse(cells(model), model.isSelected(1));
+        assertFalse(model.isSelected(1), cells(model));
 
         model.clearSelection(2, col0);
-        assertTrue(cells(model), model.isSelected(2));
+        assertTrue(model.isSelected(2), cells(model));
         model.clearSelection(2, col1);
-        assertTrue(cells(model), model.isSelected(2));
+        assertTrue(model.isSelected(2), cells(model));
         model.clearSelection(2, col2);
-        assertFalse(cells(model), model.isSelected(2));
+        assertFalse(model.isSelected(2), cells(model));
 
         assertEquals(0, model.getSelectedCells().size());
     }
@@ -578,8 +563,8 @@ public class TableViewSelectionModelImplTest {
 
     @Test public void focusOnRow() {
         focusModel.focus(3);
-        assertTrue(focusedCell(), focusModel.isFocused(3));
-        assertTrue(focusedCell(), focusModel.isFocused(3, null));
+        assertTrue(focusModel.isFocused(3), focusedCell());
+        assertTrue(focusModel.isFocused(3, null), focusedCell());
         assertEquals(new TablePosition(tableView, 3, null), focusModel.getFocusedCell());
         assertEquals(tableView.getItems().get(3), focusModel.getFocusedItem());
     }
@@ -587,39 +572,39 @@ public class TableViewSelectionModelImplTest {
     @Test public void focusOnNegativeRowIndex() {
         focusModel.focus(-20);
         assertEquals(new TablePosition(tableView, -1, null), focusModel.getFocusedCell());
-        assertFalse(focusedCell(), focusModel.isFocused(-20, null));
+        assertFalse(focusModel.isFocused(-20, null), focusedCell());
     }
 
     @Test public void focusOutOfColumnsBounds() {
         focusModel.focus(3, null);
         assertEquals(new TablePosition(tableView, 3, null), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(3, null));
+        assertTrue(focusModel.isFocused(3, null), focusedCell());
     }
 
     @Test public void focusPreviousRow() {
         focusModel.focus(3);
         assertEquals(new TablePosition(tableView, 3, null), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(3));
-        assertTrue(focusedCell(), focusModel.isFocused(3, null));
+        assertTrue(focusModel.isFocused(3), focusedCell());
+        assertTrue(focusModel.isFocused(3, null), focusedCell());
 
         focusModel.focusPrevious();
         assertEquals(new TablePosition(tableView, 2, null), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(2));
-        assertTrue(focusedCell(), focusModel.isFocused(2, null));
+        assertTrue(focusModel.isFocused(2), focusedCell());
+        assertTrue(focusModel.isFocused(2, null), focusedCell());
     }
 
     @Test public void focusPreviousRowImmediately() {
         focusModel.focusPrevious();
         assertEquals(new TablePosition(tableView, 0, col0), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(0, null));
+        assertTrue(focusModel.isFocused(0, null), focusedCell());
     }
 
     @Test public void focusPreviousRowFromFirstRow() {
         focusModel.focus(0);
         focusModel.focusPrevious();
         assertEquals(new TablePosition(tableView, 0, null), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(0));
-        assertTrue(focusedCell(), focusModel.isFocused(0, null));
+        assertTrue(focusModel.isFocused(0), focusedCell());
+        assertTrue(focusModel.isFocused(0, null), focusedCell());
     }
 
     @Test public void focusNextRow() {
@@ -627,8 +612,8 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusNext();
 
         assertEquals(new TablePosition(tableView, 4, null), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(4));
-        assertTrue(focusedCell(), focusModel.isFocused(4, null));
+        assertTrue(focusModel.isFocused(4), focusedCell());
+        assertTrue(focusModel.isFocused(4, null), focusedCell());
     }
 
     @Test public void focusNextRowImmediately() {
@@ -637,8 +622,8 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusNext();
 
         assertEquals(new TablePosition(tableView, 1, col0), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(1));
-        assertTrue(focusedCell(), focusModel.isFocused(1, null));
+        assertTrue(focusModel.isFocused(1), focusedCell());
+        assertTrue(focusModel.isFocused(1, null), focusedCell());
     }
 
     @Test public void focusNextRowFromLastRow() {
@@ -647,28 +632,28 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusNext();
 
         assertEquals(new TablePosition(tableView, rowCount, null), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(rowCount));
-        assertTrue(focusedCell(), focusModel.isFocused(rowCount, null));
+        assertTrue(focusModel.isFocused(rowCount), focusedCell());
+        assertTrue(focusModel.isFocused(rowCount, null), focusedCell());
     }
 
     @Test public void focusAboveCell() {
         focusModel.focus(3, col1);
         assertEquals(new TablePosition(tableView, 3, col1), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(3, col1));
+        assertTrue(focusModel.isFocused(3, col1), focusedCell());
 
         focusModel.focusAboveCell();
         assertEquals(new TablePosition(tableView, 2, col1), focusModel.getFocusedCell());
         // not sure about this - a row probably shouldn't be focused when we've given it specifically to a cell
-        assertTrue(focusedCell(), focusModel.isFocused(2));
-        assertTrue(focusedCell(), focusModel.isFocused(2, col1));
+        assertTrue(focusModel.isFocused(2), focusedCell());
+        assertTrue(focusModel.isFocused(2, col1), focusedCell());
     }
 
     @Test public void focusAboveCellFromFirstRow() {
         focusModel.focus(0, col1);
         focusModel.focusAboveCell();
         assertEquals(new TablePosition(tableView, 0, col1), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(0));
-        assertTrue(focusedCell(), focusModel.isFocused(0, col1));
+        assertTrue(focusModel.isFocused(0), focusedCell());
+        assertTrue(focusModel.isFocused(0, col1), focusedCell());
     }
 
     @Test public void focusBelowCell() {
@@ -676,8 +661,8 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusBelowCell();
 
         assertEquals(new TablePosition(tableView, 4, col1), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(4));
-        assertTrue(focusedCell(), focusModel.isFocused(4, col1));
+        assertTrue(focusModel.isFocused(4), focusedCell());
+        assertTrue(focusModel.isFocused(4, col1), focusedCell());
     }
 
     @Test public void focusBelowCellFromLastRow() {
@@ -686,8 +671,8 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusBelowCell();
 
         assertEquals(new TablePosition(tableView, rowCount, col1), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(rowCount));
-        assertTrue(focusedCell(), focusModel.isFocused(rowCount, col1));
+        assertTrue(focusModel.isFocused(rowCount), focusedCell());
+        assertTrue(focusModel.isFocused(rowCount, col1), focusedCell());
     }
 
     @Test public void focusLeftCell() {
@@ -695,8 +680,8 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusLeftCell();
 
         assertEquals(new TablePosition(tableView, 3, col0), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(3));
-        assertTrue(focusedCell(), focusModel.isFocused(3, col0));
+        assertTrue(focusModel.isFocused(3), focusedCell());
+        assertTrue(focusModel.isFocused(3, col0), focusedCell());
     }
 
     @Test public void focusLeftCellFromFirstColumn() {
@@ -704,8 +689,8 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusLeftCell();
 
         assertEquals(new TablePosition(tableView, 3, col0), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(3));
-        assertTrue(focusedCell(), focusModel.isFocused(3, col0));
+        assertTrue(focusModel.isFocused(3), focusedCell());
+        assertTrue(focusModel.isFocused(3, col0), focusedCell());
     }
 
     @Test public void focusLeftCellFromNullColumn() {
@@ -713,8 +698,8 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusLeftCell();
 
         assertEquals(new TablePosition(tableView, 3, null), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(3));
-        assertTrue(focusedCell(), focusModel.isFocused(3, null));
+        assertTrue(focusModel.isFocused(3), focusedCell());
+        assertTrue(focusModel.isFocused(3, null), focusedCell());
     }
 
     @Test public void focusRightCell() {
@@ -722,8 +707,8 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusRightCell();
 
         assertEquals(new TablePosition(tableView, 3, col1), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(3));
-        assertTrue(focusedCell(), focusModel.isFocused(3, col1));
+        assertTrue(focusModel.isFocused(3), focusedCell());
+        assertTrue(focusModel.isFocused(3, col1), focusedCell());
     }
 
     @Test public void focusRightCellFromEndColumn() {
@@ -734,8 +719,8 @@ public class TableViewSelectionModelImplTest {
         focusModel.focusRightCell();
 
         assertEquals(new TablePosition(tableView, 3, rightEdge), focusModel.getFocusedCell());
-        assertTrue(focusedCell(), focusModel.isFocused(3));
-        assertTrue(focusedCell(), focusModel.isFocused(3, rightEdge));
+        assertTrue(focusModel.isFocused(3), focusedCell());
+        assertTrue(focusModel.isFocused(3, rightEdge), focusedCell());
     }
 
     @Test public void test_rt33442() {
@@ -915,10 +900,10 @@ public class TableViewSelectionModelImplTest {
         model.setCellSelectionEnabled(true);
         model.select(3);
         // test against contract
-        assertEquals("selected index", 3, model.getSelectedIndex());
-        assertTrue("contained in selected indices", model.getSelectedIndices().contains(3));
+        assertEquals(3, model.getSelectedIndex(), "selected index");
+        assertTrue(model.getSelectedIndices().contains(3), "contained in selected indices");
         // test against spec
-        assertEquals("is selected index", model.getSelectedIndices().contains(3), model.isSelected(3));
+        assertEquals(model.getSelectedIndices().contains(3), model.isSelected(3), "is selected index");
     }
 
     @Test
@@ -957,11 +942,11 @@ public class TableViewSelectionModelImplTest {
         TableColumn<Person, ?> column = table.getColumns().get(col);
 
         sm.select(row, column);
-        assertTrue("sanity: row " + row + "contained in selectedIndices", sm.getSelectedIndices().contains(row));
-        assertTrue("sanity: row must be selected" , sm.isSelected(row));
+        assertTrue(sm.getSelectedIndices().contains(row), "sanity: row " + row + "contained in selectedIndices");
+        assertTrue(sm.isSelected(row), "sanity: row must be selected");
         column.setVisible(false);
-        assertTrue("after hiding column: row " + row + "contained in selectedIndices", sm.getSelectedIndices().contains(row));
-        assertTrue("after hiding column: row must be selected" , sm.isSelected(row));
+        assertTrue(sm.getSelectedIndices().contains(row), "after hiding column: row " + row + "contained in selectedIndices");
+        assertTrue(sm.isSelected(row), "after hiding column: row must be selected");
     }
 
     /**
