@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2022, 2023 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2022, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -28,8 +28,11 @@ package test.javafx.scene.control.skin;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import java.lang.ref.WeakReference;
+
+import javafx.beans.property.SimpleStringProperty;
 import javafx.collections.FXCollections;
 import javafx.collections.ObservableList;
 import javafx.geometry.Insets;
@@ -45,6 +48,7 @@ import javafx.scene.control.cell.TreeItemPropertyValueFactory;
 import javafx.scene.control.skin.TableColumnHeader;
 import javafx.scene.control.skin.TableColumnHeaderShim;
 import javafx.scene.control.skin.TreeTableRowSkin;
+import javafx.scene.shape.Rectangle;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
@@ -326,6 +330,28 @@ public class TreeTableRowSkinTest {
         invisibleColumnsShouldRemoveCorrespondingCellsInRowImpl();
     }
 
+    /**
+     * The {@link TreeTableRowSkin} should add new cells after new columns are added.
+     * See: JDK-8321970
+     */
+    @Test
+    public void cellsShouldBeAddedInRowFixedCellSize() {
+        treeTableView.setPrefWidth(800);
+        treeTableView.setFixedCellSize(24);
+
+        TreeTableColumn<Person, String> otherColumn = new TreeTableColumn<>("other");
+        otherColumn.setPrefWidth(100);
+        otherColumn.setCellValueFactory(value -> new SimpleStringProperty("other"));
+        treeTableView.getColumns().add(otherColumn);
+
+        Toolkit.getToolkit().firePulse();
+        assertEquals(5, treeTableView.getColumns().size());
+
+        Toolkit.getToolkit().firePulse();
+        IndexedCell<?> row = VirtualFlowTestUtils.getCell(treeTableView, 1);
+        assertEquals(5, row.getChildrenUnmodifiable().stream().filter(TreeTableCell.class::isInstance).count());
+    }
+
     /** TreeTableView.refresh() must release all discarded cells JDK-8307538 */
     @Test
     public void cellsMustBeCollectableAfterRefresh() {
@@ -356,9 +382,57 @@ public class TreeTableRowSkinTest {
         JMemoryBuddy.assertCollectable(ref);
     }
 
+    // See JDK-8285700
+    @Test
+    public void testGraphicVisibilityOfTreeItem() {
+        TreeTableView<String> tree = new TreeTableView<>();
+        stageLoader = new StageLoader(tree);
+
+        TreeTableColumn<String, String> column = new TreeTableColumn<>("Column");
+        tree.getColumns().add(column);
+        tree.setRoot(new TreeItem("Root"));
+
+        for (int i = 0; i < 4; i++) {
+            TreeItem<String> parent = new TreeItem<>("item - " + i, new Rectangle(10, 10));
+            TreeItem<String> subNode = new TreeItem<>("sub-node - " + i, new Rectangle(10, 10));
+            parent.getChildren().addAll(subNode);
+            tree.getRoot().getChildren().add(parent);
+        }
+        tree.getRoot().setExpanded(true);
+
+        int itemNodeSize = tree.getRoot().getChildren().size();
+        TreeItem treeItem = tree.getRoot().getChildren().get(itemNodeSize - 2);
+        TreeItem treeItemSubNode = tree.getRoot().getChildren().get(itemNodeSize - 2).getChildren().get(0);
+        TreeItem lastItem = tree.getRoot().getChildren().get(itemNodeSize - 1);
+
+        Toolkit.getToolkit().firePulse();
+        assertFalse(treeItem.isExpanded());
+        double lastItemBeforeExpand = lastItem.getGraphic().localToScene(lastItem.getGraphic().getBoundsInLocal()).getMinY();
+
+        treeItem.setExpanded(true);
+        Toolkit.getToolkit().firePulse();
+        assertTrue(treeItem.isExpanded());
+        assertNotEquals(lastItemBeforeExpand, lastItem.getGraphic().localToScene(lastItem.getGraphic().getBoundsInLocal()).getMinY());
+        double treeItemSubNodeAfterExpand = treeItemSubNode.getGraphic().localToScene(treeItemSubNode.getGraphic().getBoundsInLocal()).getMinY();
+
+        treeItem.setExpanded(false);
+        Toolkit.getToolkit().firePulse();
+        assertFalse(treeItem.isExpanded());
+        assertEquals(lastItemBeforeExpand, lastItem.getGraphic().localToScene(lastItem.getGraphic().getBoundsInLocal()).getMinY());
+        assertNotEquals(treeItemSubNodeAfterExpand, treeItemSubNode.getGraphic().localToScene(treeItemSubNode.getGraphic().getBoundsInLocal()).getMinY());
+
+        treeItem.setExpanded(true);
+        Toolkit.getToolkit().firePulse();
+        assertTrue(treeItem.isExpanded());
+        assertEquals(treeItemSubNodeAfterExpand, treeItemSubNode.getGraphic().localToScene(treeItemSubNode.getGraphic().getBoundsInLocal()).getMinY());
+    }
+
     @AfterEach
     public void after() {
-        stageLoader.dispose();
+        if (stageLoader != null) {
+            stageLoader.dispose();
+            stageLoader = null;
+        }
     }
 
     private void invisibleColumnsShouldRemoveCorrespondingCellsInRowImpl() {
@@ -369,9 +443,8 @@ public class TreeTableRowSkinTest {
         Toolkit.getToolkit().firePulse();
 
         // We set 2 columns to invisible, so the cell count should be decremented by 2 as well.
-        // Note: TreeTableView has an additional children - the disclosure node - therefore we subtract 1 here.
         assertEquals(treeTableView.getColumns().size() - 2,
-                VirtualFlowTestUtils.getCell(treeTableView, 0).getChildrenUnmodifiable().size() - 1);
+                VirtualFlowTestUtils.getCell(treeTableView, 0).getChildrenUnmodifiable().size());
     }
 
     private void removedColumnsShouldRemoveCorrespondingCellsInRowImpl() {
@@ -381,9 +454,8 @@ public class TreeTableRowSkinTest {
         Toolkit.getToolkit().firePulse();
 
         // We removed 2 columns, so the cell count should be decremented by 2 as well.
-        // Note: TreeTableView has an additional children - the disclosure node - therefore we subtract 1 here.
         assertEquals(treeTableView.getColumns().size(),
-                VirtualFlowTestUtils.getCell(treeTableView, 0).getChildrenUnmodifiable().size() - 1);
+                VirtualFlowTestUtils.getCell(treeTableView, 0).getChildrenUnmodifiable().size());
     }
 
     private static class ThrowingTreeTableRowSkin<T> extends TreeTableRowSkin<T> {
