@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -34,10 +34,13 @@
 #import "GlassKey.h"
 #import "GlassScreen.h"
 #import "GlassWindow.h"
-#import "GlassTouches.h"
+#import "PlatformSupport.h"
 
 #import "ProcessInfo.h"
 #import <Security/SecRequirement.h>
+#import <Carbon/Carbon.h>
+
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
 
 //#define VERBOSE
 #ifndef VERBOSE
@@ -74,6 +77,11 @@ static NSString* JavaRunLoopMode = @"AWTRunLoopMode";
 // don't deadlock.
 static NSArray<NSString*> *runLoopModes = nil;
 
+// Custom event that is provided by AWT to allow libraries like
+// JavaFX to forward native events to AWT even if AWT runs in
+// embedded mode.
+static NSString* awtEmbeddedEvent = @"AWTEmbeddedEvent";
+
 #ifdef STATIC_BUILD
 jint JNICALL JNI_OnLoad_glass(JavaVM *vm, void *reserved)
 #else
@@ -95,10 +103,13 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
 }
 
 - (id)initWithRunnable:(jobject)runnable;
+- (void)maybeRun;
 - (void)run;
 
 @end
 
+static NSMutableArray<GlassRunnable*> *deferredRunnables = nil;
+
 @implementation GlassRunnable
 
 - (id)initWithRunnable:(jobject)runnable
@@ -128,6 +139,27 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
     [pool drain];
 }
 
+- (void)maybeRun
+{
+    if (isFullScreenExitingLoop) {
+        if (deferredRunnables == nil) {
+            deferredRunnables = [[NSMutableArray alloc] initWithCapacity: 2];
+        }
+        [deferredRunnables addObject: self];
+    } else {
+        [self run];
+    }
+}
+
++ (void)rescheduleDeferredRunnables
+{
+    if (deferredRunnables != nil) {
+        for (GlassRunnable *runnable in deferredRunnables) {
+            [runnable performSelectorOnMainThread:@selector(maybeRun) withObject:nil waitUntilDone:NO modes:runLoopModes];
+        }
+        [deferredRunnables removeAllObjects];
+    }
+}
 @end
 
 @implementation NSApplicationFX
@@ -135,7 +167,9 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
 
 #pragma mark --- GlassApplication
 
-@implementation GlassApplication
+@implementation GlassApplication {
+    PlatformSupport* platformSupport;
+}
 
 - (id)initWithEnv:(JNIEnv*)env application:(jobject)application launchable:(jobject)launchable taskbarApplication:(jboolean)isTaskbarApplication classLoader:(jobject)classLoader
 {
@@ -159,6 +193,15 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
     return self;
 }
 
+- (void)dealloc {
+    if (platformSupport) {
+        [platformSupport stopEventProcessing];
+        [platformSupport release];
+    }
+
+    [super dealloc];
+}
+
 #pragma mark --- delegate methods
 
 - (void)GlassApplicationDidChangeScreenParameters
@@ -181,6 +224,7 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
     NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
     {
         // unblock main thread. Glass is started at this point.
+        self->platformSupport = [[PlatformSupport alloc] initWithEnv:env application:jApplication];
         self->started = YES;
 
         if (self->jLaunchable != NULL)
@@ -262,12 +306,12 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
     [pool drain];
     GLASS_CHECK_EXCEPTION(env);
 
-     if (!NSApp.isActive && requiresActivation) {
+    if (!NSApp.isActive && requiresActivation) {
         // As of macOS 14, application gets to the foreground,
         // but it doesn't get activated, so this is needed:
         LOG("-> need to active application");
         dispatch_async(dispatch_get_main_queue(), ^{
-            [NSApp activate];
+            [NSApp activateIgnoringOtherApps:YES];
         });
     }
 }
@@ -458,6 +502,21 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
     return YES;
 }
 
+- (void) application:(NSApplication *)theApplication openURLs:(NSArray<NSURL *> *)urls
+{
+    for (NSURL* url in urls) {
+         NSDictionary *userInfo = @{
+            @"name": @"openURL",
+            @"url": url.absoluteString
+        };
+
+        [[NSNotificationCenter defaultCenter]
+                postNotificationName:awtEmbeddedEvent
+                object:nil
+                userInfo:userInfo];
+    }
+}
+
 - (BOOL)applicationShouldOpenUntitledFile:(NSApplication *)sender
 {
     LOG("GlassApplication:applicationShouldOpenUntitledFile");
@@ -500,8 +559,7 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
 
     NSAutoreleasePool *pool1 = [[NSAutoreleasePool alloc] init];
 
-    jint error = (*jVM)->AttachCurrentThread(jVM, (void **)&jEnv, NULL);
-    //jint error = (*jVM)->AttachCurrentThreadAsDaemon(jVM, (void **)&jEnv, NULL);
+    jint error = (*jVM)->AttachCurrentThreadAsDaemon(jVM, (void **)&jEnv, NULL);
     if (error == 0)
     {
         NSAutoreleasePool *pool2 = [[NSAutoreleasePool alloc] init];
@@ -554,7 +612,7 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
         }
 
         // List of RunLoopModes in which we will run runnables passed
-        // to _invokeAndWait and _invokeAndExit. This includes
+        // to _invokeAndWait and _submitForLaterInvocation. This includes
         // JavaRunLoopMode to avoid a possible deadlock with AWT.
         // There is no harm always adding it, since it will have no
         // effect if the run loop that receives this message does not
@@ -611,28 +669,25 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
                 char *path = getenv([property UTF8String]);
                 if (path != NULL)
                 {
+                    BOOL isFolder = NO;
                     NSString *overridenPath = [NSString stringWithFormat:@"%s", path];
-                    if ([[NSFileManager defaultManager] fileExistsAtPath:overridenPath isDirectory:NO] == YES)
+                    if ([[NSFileManager defaultManager] fileExistsAtPath:overridenPath isDirectory:&isFolder] && !isFolder)
                     {
                         iconPath = overridenPath;
                     }
                 }
-                if ([[NSFileManager defaultManager] fileExistsAtPath:iconPath isDirectory:NO] == NO)
-                {
-                    // try again using Java generic icon (this icon might go away eventually ?)
-                    iconPath = [NSString stringWithFormat:@"%s", "/System/Library/Frameworks/JavaVM.framework/Resources/GenericApp.icns"];
-                }
 
                 NSImage *image = nil;
                 {
-                    if ([[NSFileManager defaultManager] fileExistsAtPath:iconPath isDirectory:NO] == YES)
+                    BOOL isFolder = NO;
+                    if ([[NSFileManager defaultManager] fileExistsAtPath:iconPath isDirectory:&isFolder] && !isFolder)
                     {
                         image = [[NSImage alloc] initWithContentsOfFile:iconPath];
                     }
                     if (image == nil)
                     {
-                        // last resort - if still no icon, then ask for an empty standard app icon, which is guranteed to exist
-                        image = [[NSImage imageNamed:@"NSApplicationIcon"] retain];
+                        // last resort - if still no icon, then ask for an empty standard app icon, which is guaranteed to exist
+                        image = [[NSImage imageNamed:@"NSImageNameApplicationIcon"] retain];
                     }
                 }
                 [app setApplicationIconImage:image];
@@ -695,26 +750,21 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
             // enter runloop, this will not return until terminated
             [NSApp run];
 
-            // Abort listerning to global touch input events
-            [GlassTouches terminate];
-
             GLASS_CHECK_EXCEPTION(jEnv);
 
             (*jEnv)->CallVoidMethod(jEnv, self->jApplication, javaIDs.MacApplication.notifyApplicationDidTerminate);
             GLASS_CHECK_EXCEPTION(jEnv);
 
-            jint err = (*jVM)->DetachCurrentThread(jVM);
-            if (err < 0)
-            {
-                NSLog(@"Unable to detach from JVM. Error code: %d\n", (int)err);
-            }
-
             jEnv = NULL;
         }
         else // event loop is not started
         {
             if ([NSThread isMainThread] == YES) {
-                [glassApp applicationWillFinishLaunching: NULL];
+                // The NSNotification is ignored but the compiler insists on a non-NULL argument.
+                NSNotification* notification = [NSNotification notificationWithName: NSApplicationWillFinishLaunchingNotification
+                    object: NSApp
+                    userInfo: nil];
+                [glassApp applicationWillFinishLaunching: notification];
             } else {
                 [glassApp performSelectorOnMainThread:@selector(applicationWillFinishLaunching:) withObject:NULL waitUntilDone:NO];
             }
@@ -738,6 +788,11 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
     return self->started;
 }
 
+- (jobject)getPlatformPreferences
+{
+    return platformSupport != nil ? [platformSupport collectPreferences] : nil;
+}
+
 + (jobject)enterNestedEventLoopWithEnv:(JNIEnv*)env
 {
     jobject ret = NULL;
@@ -790,6 +845,7 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
         (*env)->ExceptionClear(env);
     }
     isFullScreenExitingLoop = NO;
+    [GlassRunnable rescheduleDeferredRunnables];
 }
 
 + (void)leaveFullScreenExitingLoopIfNeeded
@@ -802,13 +858,44 @@ jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
             javaIDs.Application.leaveNestedEventLoop, (jobject)NULL);
 }
 
+static void inputDidChangeCallback(CFNotificationCenterRef center, void *observer, CFNotificationName name, const void *object, CFDictionaryRef userInfo)
+{
+    if (keyCodeForCharMap != nil) {
+        [keyCodeForCharMap removeAllObjects];
+    }
+}
+
 + (void)registerKeyEvent:(NSEvent*)event
 {
     if (!keyCodeForCharMap) {
         keyCodeForCharMap = [[NSMutableDictionary alloc] initWithCapacity:100];
         // Note: it's never released, just like, say, the jApplication reference...
+        // To avoid stale entries when the user switches layout
+        CFNotificationCenterRef center = CFNotificationCenterGetDistributedCenter();
+        CFNotificationCenterAddObserver(center, NULL, inputDidChangeCallback,
+                                        kTISNotifySelectedKeyboardInputSourceChanged,
+                                        NULL, CFNotificationSuspensionBehaviorCoalesce);
     }
-    [keyCodeForCharMap setObject:[NSNumber numberWithUnsignedShort:[event keyCode]] forKey:[event characters]];
+
+    // Add the character the user typed to the map.
+    NSNumber* mapObject = [NSNumber numberWithUnsignedShort:[event keyCode]];
+    [keyCodeForCharMap setObject:mapObject forKey:[event characters]];
+    // getKeyCodeForChar should not just match against a character the user types
+    // directly but any other character printed on the same key.
+    NSString* unshifted = GetStringForMacKey(event.keyCode, false);
+    if (unshifted != nil) {
+        [keyCodeForCharMap setObject:mapObject forKey:unshifted];
+    }
+    NSString* shifted = GetStringForMacKey(event.keyCode, true);
+    if (shifted != nil) {
+        [keyCodeForCharMap setObject:mapObject forKey:shifted];
+    }
+    // On some European keyboards there are useful symbols which are only
+    // accessible via the Option key. We don't query for the Option key
+    // character because on most layouts just about every key has some
+    // random symbol assigned to that modifier which the user probably
+    // isn't even aware of. The user can get that character into the map
+    // by typing it directly.
 }
 
 + (jint)getKeyCodeForChar:(jchar)c;
@@ -895,6 +982,10 @@ JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacApplication__1initIDs
             env, jClass, "notifyApplicationDidTerminate", "()V");
     if ((*env)->ExceptionCheck(env)) return;
 
+    javaIDs.MacApplication.notifyPreferencesChanged = (*env)->GetMethodID(
+            env, jClass, "notifyPreferencesChanged", "(Ljava/util/Map;)V");
+    if ((*env)->ExceptionCheck(env)) return;
+
     if (jRunnableRun == NULL)
     {
         jclass jcls = (*env)->FindClass(env, "java/lang/Runnable");
@@ -902,16 +993,35 @@ JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacApplication__1initIDs
         jRunnableRun = (*env)->GetMethodID(env, jcls, "run", "()V");
         if ((*env)->ExceptionCheck(env)) return;
     }
+
+    [PlatformSupport initIDs:env];
+}
+
+/*
+ * Class:     com_sun_glass_ui_mac_MacApplication
+ * Method:    _initDelegate
+ * Signature: (Ljava/lang/ClassLoader;Ljava/lang/Runnable;Z)J
+ */
+JNIEXPORT jlong JNICALL Java_com_sun_glass_ui_mac_MacApplication__1initDelegate
+(JNIEnv *env, jobject japplication, jobject classLoader,
+ jobject jlaunchable, jboolean isTaskbarApplication)
+{
+    LOG("Java_com_sun_glass_ui_mac_MacApplication__1initDelegate");
+
+    return (jlong)[[GlassApplication alloc] initWithEnv:env
+                                            application:japplication
+                                            launchable:jlaunchable
+                                            taskbarApplication:isTaskbarApplication
+                                            classLoader:classLoader];
 }
 
 /*
  * Class:     com_sun_glass_ui_mac_MacApplication
  * Method:    _runLoop
- * Signature: (Ljava/lang/ClassLoader;Ljava/lang/Runnable;Z)V
+ * Signature: (J)V
  */
 JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacApplication__1runLoop
-(JNIEnv *env, jobject japplication, jobject classLoader,
- jobject jlaunchable, jboolean isTaskbarApplication)
+(JNIEnv *env, jobject japplication, jlong appDelegate)
 {
     LOG("Java_com_sun_glass_ui_mac_MacApplication__1runLoop");
 
@@ -929,7 +1039,7 @@ JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacApplication__1runLoop
             }
         }
 
-        GlassApplication *glass = [[GlassApplication alloc] initWithEnv:env application:japplication launchable:jlaunchable taskbarApplication:isTaskbarApplication classLoader:classLoader];
+        GlassApplication* glass = (GlassApplication*)appDelegate;
         if ([NSThread isMainThread] == YES) {
             [glass runLoop: glass];
         } else {
@@ -952,13 +1062,17 @@ JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacApplication__1runLoop
 /*
  * Class:     com_sun_glass_ui_mac_MacApplication
  * Method:    _finishTerminating
- * Signature: ()V
+ * Signature: (J)V
  */
 JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacApplication__1finishTerminating
-(JNIEnv *env, jobject japplication)
+(JNIEnv *env, jobject japplication, jlong appDelegate)
 {
     LOG("Java_com_sun_glass_ui_mac_MacApplication__1finishTerminating");
 
+    if (appDelegate) {
+        [(GlassApplication*)appDelegate release];
+    }
+
     if (isEmbedded) {
         return;
     }
@@ -1040,7 +1154,7 @@ JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacApplication__1submitForLater
     if (jEnv != NULL)
     {
         GlassRunnable *runnable = [[GlassRunnable alloc] initWithRunnable:(*env)->NewGlobalRef(env, jRunnable)];
-        [runnable performSelectorOnMainThread:@selector(run) withObject:nil waitUntilDone:NO modes:runLoopModes];
+        [runnable performSelectorOnMainThread:@selector(maybeRun) withObject:nil waitUntilDone:NO modes:runLoopModes];
     }
 }
 
@@ -1200,3 +1314,28 @@ JNIEXPORT jint JNICALL Java_com_sun_glass_ui_mac_MacApplication__1getMacKey
     GetMacKey(code, &macCode);
     return (macCode & 0xFFFF);
 }
+
+/*
+ * Class:     com_sun_glass_ui_mac_MacApplication
+ * Method:    _getApplicationClassName
+ * Signature: ()Ljava/lang/String;
+ */
+JNIEXPORT jobject JNICALL Java_com_sun_glass_ui_mac_MacApplication__1getApplicationClassName
+(JNIEnv *env, jobject self)
+{
+    NSString* className = NSStringFromClass([[NSApplicationFX sharedApplication] class]);
+    return (*env)->NewStringUTF(env, [className UTF8String]);
+}
+
+/*
+ * Class:     com_sun_glass_ui_mac_MacApplication
+ * Method:    _getPlatformPreferences
+ * Signature: (J)Ljava/util/Map;
+ */
+JNIEXPORT jobject JNICALL Java_com_sun_glass_ui_mac_MacApplication__1getPlatformPreferences
+(JNIEnv *env, jobject self, jlong appDelegate)
+{
+    return appDelegate
+        ? [(GlassApplication*)appDelegate getPlatformPreferences]
+        : nil;
+}
