@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -33,6 +33,8 @@
 #import "GlassHelper.h"
 #import "GlassKey.h"
 
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+
 //#define VERBOSE
 #ifndef VERBOSE
     #define LOG(MSG, ...)
@@ -174,7 +176,7 @@ static jfieldID  jPixelsScaleYField = 0;
     }
 }
 
-// RT-37304: do not use menuNeedsUpdate here, even though Cocoa prohibits
+// JDK-8096139: do not use menuNeedsUpdate here, even though Cocoa prohibits
 // changing the menu structure during menuWillOpen...
 - (void)menuWillOpen: (NSMenu *)menu
 {
@@ -236,7 +238,6 @@ static jfieldID  jPixelsScaleYField = 0;
     }
     if ((jmodifiers & com_sun_glass_events_KeyEvent_MODIFIER_FUNCTION) != 0)
     {
-        modifier = modifier | NSFunctionKeyMask;
         if (jshortcut >= com_sun_glass_events_KeyEvent_VK_F1 &&
             jshortcut <= com_sun_glass_events_KeyEvent_VK_F12) {
             int delta = jshortcut - com_sun_glass_events_KeyEvent_VK_F1;
