@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -31,6 +31,8 @@
 #import "GlassPasteboard.h"
 #import "GlassDragSource.h"
 
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+
 // UTF-16 code points for surrogate pairs
 #define HIGH_SURROGATE_START 0xD800
 #define HIGH_SURROGATE_END 0xDBFF
@@ -634,7 +636,7 @@ JNIEXPORT jbyteArray JNICALL Java_com_sun_glass_ui_mac_MacPasteboard__1getItemAs
 
                     if (pixels != NULL)
                     {
-                        CGColorSpaceRef space = CGColorSpaceCreateDeviceRGB();
+                        CGColorSpaceRef space = CGColorSpaceCreateWithName(kCGColorSpaceSRGB);
                         CGContextRef ctx = CGBitmapContextCreate(pixels, width, height, 8, 4*width, space, kCGImageAlphaPremultipliedFirst|kCGBitmapByteOrder32Little);
                         CGContextSetBlendMode(ctx, kCGBlendModeCopy);
                         CGContextDrawImage(ctx, CGRectMake(0, 0, width, height), cgImage);
