@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -44,7 +44,8 @@
 #import "GlassHelper.h"
 #import "GlassStatics.h"
 #import "GlassPasteboard.h"
-#import "GlassTouches.h"
+
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
 
 //#define VERBOSE
 #ifndef VERBOSE
@@ -193,14 +194,9 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
     [self->parentWindow release];
     self->parentWindow = nil;
 
-    [self->fullscreenWindow release];
-    self->fullscreenWindow = nil;
-
     [self->nativeFullScreenModeWindow release];
     self->nativeFullScreenModeWindow = nil;
 
-    [GlassTouches stopTracking:self];
-
     GET_MAIN_JENV_NOWARN;
 
     if (env != NULL)
@@ -417,19 +413,20 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
 
         case NSMouseEntered:
             type = com_sun_glass_events_MouseEvent_ENTER;
-            [GlassTouches startTracking:self];
             self->lastTrackingNumber = [theEvent trackingNumber];
             break;
 
         case NSMouseExited:
             type = com_sun_glass_events_MouseEvent_EXIT;
-            [GlassTouches stopTracking:self];
             self->lastTrackingNumber = [theEvent trackingNumber];
             break;
 
         case NSScrollWheel:
             type = com_sun_glass_events_MouseEvent_WHEEL;
             break;
+
+        default:
+            break;
     }
 
     NSPoint viewPoint = [nsView convertPoint:[theEvent locationInWindow] fromView:nil]; // convert from window coordinates to view coordinates
@@ -488,7 +485,7 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
 
     BOOL block = NO;
     {
-        // RT-5892
+        // JDK-8107811
         if ((type == com_sun_glass_events_MouseEvent_ENTER) || (type == com_sun_glass_events_MouseEvent_EXIT))
         {
             // userData indicates if this is a synthesized EXIT event that MUST pass through
@@ -613,7 +610,7 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
             // Can be inertia from scroll gesture,
             // scroll gesture or mouse wheel itself
             //
-            // RT-22388, RT-25269
+            // JDK-8126339, JDK-8115029
             jint sender = com_sun_glass_ui_mac_MacGestureSupport_SCROLL_SRC_WHEEL;
             if (isInertialScroll(theEvent))
             {
@@ -667,35 +664,45 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
     }
 }
 
-// RT-11707: zero out the keycode for TYPED events
+// JDK-8112726: zero out the keycode for TYPED events
 #define SEND_KEY_EVENT(type) \
-    (*env)->CallVoidMethod(env, self->jView, jViewNotifyKey, (type), \
+    jboolean thisEventWasConsumed = (*env)->CallBooleanMethod(env, self->jView, jViewNotifyKeyAndReturnConsumed, (type), \
             (type) == com_sun_glass_events_KeyEvent_TYPED ? 0 : jKeyCode, \
             jKeyChars, jModifiers); \
     GLASS_CHECK_EXCEPTION(env);
 
-- (void)sendJavaKeyEvent:(NSEvent *)theEvent isDown:(BOOL)isDown
+- (BOOL)sendJavaKeyEvent:(NSEvent *)theEvent isDown:(BOOL)isDown character:(unichar)textChar
 {
-    if (theEvent == s_lastKeyEvent) {
-        // this must be a keyDown: generated by performKeyEquivalent: which returns NO by design
-        return;
-    }
-    [s_lastKeyEvent release];
-    s_lastKeyEvent = [theEvent retain];
-
     GET_MAIN_JENV;
 
     jint jKeyCode = GetJavaKeyCode(theEvent);
-    jcharArray jKeyChars = GetJavaKeyChars(env, theEvent);
     jint jModifiers = GetJavaModifiers(theEvent);
+    jcharArray jKeyChars;
+    if (textChar != 0) {
+        jchar jc[1] = { textChar };
+        jKeyChars = (*env)->NewCharArray(env, 1);
+        if (jKeyChars == NULL) {
+            return YES;
+        }
+        (*env)->SetCharArrayRegion(env, jKeyChars, 0, 1, jc);
+    } else {
+        jKeyChars = GetJavaKeyChars(env, theEvent);
+    }
 
+    // This routine returns YES if the PRESS event was consumed. This is
+    // used to ensure that performKeyEquivalent doesn't allow an event
+    // to be processed by both JavaFX and the system menus.
+    jboolean wasConsumed = false;
     if (!isDown)
     {
         SEND_KEY_EVENT(com_sun_glass_events_KeyEvent_RELEASE);
     }
     else
     {
+        // We only return YES if the PRESSED event was consumed. The TextInput
+        // control consumes any TYPED event that looks like a shortcut.
         SEND_KEY_EVENT(com_sun_glass_events_KeyEvent_PRESS);
+        wasConsumed = thisEventWasConsumed;
 
         // TYPED events should only be sent for printable characters. Thus we avoid
         // sending them for navigation keys. Perhaps this logic could be enhanced.
@@ -715,10 +722,12 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
 
     (*env)->DeleteLocalRef(env, jKeyChars);
     GLASS_CHECK_EXCEPTION(env);
+
+    return wasConsumed ? YES : NO;
 }
 
 #define SEND_MODIFIER_KEY_EVENT_WITH_TYPE(type, vkCode) \
-        (*env)->CallVoidMethod(env, self->jView, jViewNotifyKey, \
+        (*env)->CallBooleanMethod(env, self->jView, jViewNotifyKeyAndReturnConsumed, \
                 (type), \
                 (vkCode), \
                 jKeyChars, jModifiers);
@@ -903,7 +912,7 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
     int y = (int)draggingLocation.y;
 
     int xAbs = (int)([info draggingLocation].x + [self->nsView window].frame.origin.x);
-    int yAbs = (int)([[self->nsView window] screen].frame.size.height - [self->nsView window].frame.origin.y
+    int yAbs = (int)([[NSScreen screens] objectAtIndex: 0].frame.size.height - [self->nsView window].frame.origin.y
                      - [info draggingLocation].y);
 
     int mask;
@@ -1016,7 +1025,7 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
 
         if (image != nil)
         {
-            DNDLOG("created an image with dim %dx%d", [image size].width, [image size].height);
+            DNDLOG("created an image with dim %fx%f", [image size].width, [image size].height);
             // check the drag image size and scale it down as needed using Safari behavior (sizes) as reference
             rect.size.width = [image size].width;
             rect.size.height = [image size].height;
@@ -1037,30 +1046,27 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
                     [image setSize:NSMakeSize(rect.size.width, rect.size.height)];
                 }
             }
-        }
-
-        if (image != nil)
-        {
-            // select the center of the image as the drag origin
-            // TODO http://javafx-jira.kenai.com/browse/RT-17629
-            // would be nice to get this info from the Java layer,
-            // so that we could adjust the drag image origin based on where in the src it was clicked on
-            dragPoint.x -= ([image size].width/2.0f);
-            dragPoint.y -= ([image size].height/2.0f);
 
             NSString *offsetString = [pbItem stringForType:DRAG_IMAGE_OFFSET];
             if (offsetString != nil) {
                 NSPoint offset = NSPointFromString(offsetString);
                 //Adjust offset to the image size
-                float imageHalfX = [image size].width/2.0f;
-                float imageHalfY = [image size].height/2.0f;
+                float imageW = [image size].width;
+                float imageH = [image size].height;
 
-                if (offset.x > imageHalfX || offset.x < -imageHalfX) {
-                    offset.x = imageHalfX * (offset.x > 0 ? 1 : -1);
+                if (offset.x < 0.0f) {
+                    offset.x = 0.0f;
+                } else if (offset.x > imageW) {
+                    offset.x = imageW;
                 }
-                if (offset.y > imageHalfY || offset.y < -imageHalfY) {
-                    offset.y = imageHalfY * (offset.y > 0 ? 1 : -1);
+                if (offset.y < 0.0f) {
+                    offset.y = 0.0f;
+                } else if (offset.y > imageH) {
+                    offset.y = imageH;
                 }
+
+                dragPoint.x -= offset.x;
+                dragPoint.y -= offset.y;
             }
         }
         else
@@ -1076,7 +1082,7 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
         [image release];
     }
 
-    self->draggingSource = [[GlassDraggingSource alloc] initWithOperation:operation];
+    self->draggingSource = [[GlassDraggingSource alloc] initWithOperation:operation delegate:self];
 
     NSDraggingSession *session = [self->nsView beginDraggingSessionWithItems:items event:self->lastEvent source:self->draggingSource];
 }
@@ -1097,7 +1103,7 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
     [self sendJavaMouseEvent:theEvent];
 }
 
-- (void)draggingEnded
+- (void)draggingEnded:(NSDragOperation)operation
 {
     DNDLOG("draggingEnded");
 
@@ -1109,11 +1115,26 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
 
     [GlassDragSource setDelegate:nil];
 
+    // At the end of dragging we're handed a single definitive
+    // drag operation (no Generic or Any).
+    jint mask = com_sun_glass_ui_Clipboard_ACTION_NONE;
+    if (operation == NSDragOperationNone) {
+        mask = com_sun_glass_ui_Clipboard_ACTION_NONE;
+    } else if (operation == NSDragOperationCopy) {
+        mask = com_sun_glass_ui_Clipboard_ACTION_COPY;
+    } else if (operation == NSDragOperationMove) {
+        mask = com_sun_glass_ui_Clipboard_ACTION_MOVE;
+    } else if (operation == NSDragOperationLink) {
+        mask = com_sun_glass_ui_Clipboard_ACTION_REFERENCE;
+    } else {
+        DNDLOG("Invalid drag operation");
+    }
+
     GET_MAIN_JENV;
-    (*env)->CallVoidMethod(env, self->jView, jViewNotifyDragEnd,  [GlassDragSource getMask]);
+    (*env)->CallVoidMethod(env, self->jView, jViewNotifyDragEnd, mask);
     GLASS_CHECK_EXCEPTION(env);
 
-    // RT-36038: OS X won't send mouseUp after DnD is complete, so we synthesize them
+    // JDK-8095312: OS X won't send mouseUp after DnD is complete, so we synthesize them
     if (self->mouseDownMask & 1 << 0) [self synthesizeMouseUp:NSLeftMouseUp];
     if (self->mouseDownMask & 1 << 1) [self synthesizeMouseUp:NSRightMouseUp];
     if (self->mouseDownMask & 1 << 2) [self synthesizeMouseUp:NSOtherMouseUp];
@@ -1124,6 +1145,11 @@ static jint getSwipeDirFromEvent(NSEvent *theEvent)
     return YES;
 }
 
+- (void)performWindowDrag
+{
+    [[nsView window] performWindowDragWithEvent:[NSApp currentEvent]];
+}
+
 static jstring convertNSStringToJString(id aString, int length)
 {
     GET_MAIN_JENV;
@@ -1218,15 +1244,13 @@ static jstring convertNSStringToJString(id aString, int length)
 - (void)setResizableForFullscreen:(BOOL)resizable
 {
     NSWindow* window =  [self->nsView window];
-    if (!((GlassWindow*) window)->isResizable) {
-        NSUInteger mask = [window styleMask];
-        if (resizable) {
-            mask |= NSResizableWindowMask;
-        } else {
-            mask &= ~(NSUInteger)NSResizableWindowMask;
-        }
-        [window setStyleMask: mask];
+    NSUInteger mask = [window styleMask];
+    if (resizable) {
+        mask |= NSWindowStyleMaskResizable;
+    } else {
+        mask &= ~(NSUInteger)NSWindowStyleMaskResizable;
     }
+    [window setStyleMask: mask];
 }
 
 /*
@@ -1263,40 +1287,6 @@ static jstring convertNSStringToJString(id aString, int length)
             [GlassApplication enterFullScreenExitingLoop];
             return;
         }
-
-        [self->fullscreenWindow toggleFullScreen:self->fullscreenWindow];
-
-        NSRect frame = [self->parentHost bounds];
-        frame.origin = [self->fullscreenWindow point];
-        [self->fullscreenWindow setFrame:frame display:YES animate:animate];
-
-        [self->fullscreenWindow disableFlushWindow];
-        {
-            [self->nsView retain];
-            {
-                [self->nsView removeFromSuperviewWithoutNeedingDisplay];
-                [self->parentHost addSubview:self->nsView];
-            }
-            [self->nsView release];
-
-            [self->parentWindow setInitialFirstResponder:self->nsView];
-            [self->parentWindow makeFirstResponder:self->nsView];
-
-            if ([[self->parentWindow delegate] isKindOfClass:[GlassWindow class]])
-            {
-                GlassWindow *window = (GlassWindow*)[self->parentWindow delegate];
-                [window setFullscreenWindow: nil];
-            }
-        }
-        [self->fullscreenWindow enableFlushWindow];
-        [self->parentWindow enableFlushWindow];
-
-        [self->fullscreenWindow orderOut:nil];
-        [self->fullscreenWindow close];
-        self->fullscreenWindow = nil;
-
-        // It was retained upon entering the FS mode
-        [self->nsView release];
     }
     @catch (NSException *e)
     {
