@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -36,11 +36,12 @@
 #import "GlassWindow+Overrides.h"
 #import "GlassView.h"
 #import "GlassScreen.h"
-#import "GlassTouches.h"
 #import "GlassApplication.h"
 #import "GlassLayer3D.h"
 #import "GlassHelper.h"
 
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+
 //#include <stdio.h>
 //#include <stdarg.h>
 //
@@ -194,6 +195,8 @@ static inline NSView<GlassView> *getMacView(JNIEnv *env, jobject jview)
             [button setAction:nil];                                                     \
             [button setEnabled:NO];                                                     \
             break;                                                                      \
+        default:                                                                        \
+            break;                                                                      \
     }                                                                                   \
     return button;                                                                      \
 }                                                                                       \
@@ -208,6 +211,22 @@ static inline NSView<GlassView> *getMacView(JNIEnv *env, jobject jview)
 
 @implementation GlassWindow_Normal
 GLASS_NS_WINDOW_IMPLEMENTATION
+
+-(NSRect)windowWillUseStandardFrame:(NSWindow*)window defaultFrame:(NSRect)newFrame
+{
+    // For windows without titlebars the OS will suggest a frame that's the
+    // same size as the existing window, not the screen.
+    if (window.screen != nil && (window.styleMask & NSWindowStyleMaskTitled) == 0) {
+        return window.screen.visibleFrame;
+    }
+    return newFrame;
+}
+
+-(BOOL)isZoomed
+{
+    // Ensure the window is not reported as maximized during initialization
+    return self.screen != nil && [super isZoomed];
+}
 @end
 
 @implementation GlassWindow_Panel
@@ -271,35 +290,6 @@ GLASS_NS_WINDOW_IMPLEMENTATION
 
 @implementation GlassWindow
 
-- (void)setFullscreenWindow:(NSWindow*)fsWindow
-{
-    if (self->fullscreenWindow == fsWindow) {
-        return;
-    }
-
-    [self _ungrabFocus];
-
-    NSWindow *from, *to;
-    from = self->fullscreenWindow ? self->fullscreenWindow : self->nsWindow;
-    to = fsWindow ? fsWindow : self->nsWindow;
-
-    NSArray * children = [from childWindows];
-    for (NSUInteger i=0; i<[children count]; i++)
-    {
-        NSWindow *child = (NSWindow*)[children objectAtIndex:i];
-        if ([[child delegate] isKindOfClass: [GlassWindow class]]) {
-            [from removeChildWindow: child];
-            [to addChildWindow:child ordered:NSWindowAbove];
-        }
-    }
-
-    self->fullscreenWindow = fsWindow;
-
-    GET_MAIN_JENV;
-    (*env)->CallVoidMethod(env, self->jWindow, jWindowNotifyDelegatePtr, ptr_to_jlong(fsWindow));
-    GLASS_CHECK_EXCEPTION(env);
-}
-
 - (void)close
 {
     [self _ungrabFocus];
@@ -383,39 +373,57 @@ static jlong _createWindowCommonDo(JNIEnv *env, jobject jWindow, jlong jOwnerPtr
 
     NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
     {
+        bool isTitled = (jStyleMask & com_sun_glass_ui_Window_TITLED) != 0;
+        bool isClosable = (jStyleMask & com_sun_glass_ui_Window_CLOSABLE) != 0;
+        bool isMinimizable = (jStyleMask & com_sun_glass_ui_Window_MINIMIZABLE) != 0;
+        bool isMaximizable = (jStyleMask & com_sun_glass_ui_Window_MAXIMIZABLE) != 0;
+        bool isTransparent = (jStyleMask & com_sun_glass_ui_Window_TRANSPARENT) != 0;
+        bool isUtility = (jStyleMask & com_sun_glass_ui_Window_UTILITY) != 0;
+        bool isPopup = (jStyleMask & com_sun_glass_ui_Window_POPUP) != 0;
+        bool isUnified = (jStyleMask & com_sun_glass_ui_Window_UNIFIED) != 0;
+        bool isExtended = (jStyleMask & com_sun_glass_ui_Window_EXTENDED) != 0;
+
         NSUInteger styleMask = NSWindowStyleMaskBorderless;
         // only titled windows get title
-        if ((jStyleMask&com_sun_glass_ui_Window_TITLED) != 0)
+        if (isTitled)
         {
             styleMask = styleMask|NSWindowStyleMaskTitled;
         }
 
-        bool isUtility = (jStyleMask & com_sun_glass_ui_Window_UTILITY) != 0;
-        bool isPopup = (jStyleMask & com_sun_glass_ui_Window_POPUP) != 0;
-
         // only nontransparent windows get decorations
-        if ((jStyleMask&com_sun_glass_ui_Window_TRANSPARENT) == 0)
+        if (!isTransparent)
         {
-            if ((jStyleMask&com_sun_glass_ui_Window_CLOSABLE) != 0)
+            if (isClosable)
             {
                 styleMask = styleMask|NSWindowStyleMaskClosable;
             }
 
-            if (((jStyleMask&com_sun_glass_ui_Window_MINIMIZABLE) != 0) ||
-                ((jStyleMask&com_sun_glass_ui_Window_MAXIMIZABLE) != 0))
+            if (isMinimizable || isMaximizable)
             {
                 // on Mac OS X there is one set for min/max buttons,
                 // so if clients requests either one, we turn them both on
                 styleMask = styleMask|NSWindowStyleMaskMiniaturizable;
             }
 
-            if ((jStyleMask&com_sun_glass_ui_Window_UNIFIED) != 0) {
+            if (isExtended) {
+                styleMask = styleMask | NSWindowStyleMaskTitled | NSWindowStyleMaskFullSizeContentView;
+            }
+
+            if (isUnified) {
                 styleMask = styleMask|NSWindowStyleMaskTexturedBackground;
             }
 
             if (isUtility)
             {
-                styleMask = styleMask | NSWindowStyleMaskUtilityWindow | NSWindowStyleMaskNonactivatingPanel;
+                styleMask = styleMask | NSWindowStyleMaskNonactivatingPanel;
+
+                // The NSWindowStyleMaskUtilityWindow style makes the close button appear very small (because the
+                // title bar is thinner than normal). This doesn't work well with client-side title bars in extended
+                // windows: the point of a client-side title bar is its ability to host custom controls, so it can't
+                // be very thin. We therefore only add this style for non-extended windows.
+                if (!isExtended) {
+                    styleMask |= NSWindowStyleMaskUtilityWindow;
+                }
             }
         }
 
@@ -433,15 +441,27 @@ static jlong _createWindowCommonDo(JNIEnv *env, jobject jWindow, jlong jOwnerPtr
 
         NSScreen *screen = (NSScreen*)jlong_to_ptr(jScreenPtr);
         window = [[GlassWindow alloc] _initWithContentRect:NSMakeRect(x, y, w, h) styleMask:styleMask screen:screen jwindow:jWindow];
+        window->isStandardButtonsVisible = YES;
 
-        if ((jStyleMask & com_sun_glass_ui_Window_UNIFIED) != 0) {
+        if (isExtended) {
+            [window->nsWindow setTitleVisibility:NSWindowTitleHidden];
+            [window->nsWindow setTitlebarAppearsTransparent:YES];
+            [window->nsWindow setToolbar:[NSToolbar new]];
+        }
+
+        if (isUnified) {
             //Prevent the textured effect from disappearing on border thickness recalculation
             [window->nsWindow setAutorecalculatesContentBorderThickness:NO forEdge:NSMaxYEdge];
         }
 
-        if ((jStyleMask & com_sun_glass_ui_Window_UTILITY) != 0) {
-            [[window->nsWindow standardWindowButton:NSWindowMiniaturizeButton] setHidden:YES];
-            [[window->nsWindow standardWindowButton:NSWindowZoomButton] setHidden:YES];
+        if (isUtility) {
+            // When we hide the standard window buttons, they are still part of the button group that activates
+            // the hover appearance (the icons inside the buttons) when the cursor is over any of the buttons.
+            // This leads to the close button receiving the hover appearance when the mouse cursor is over one
+            // of the hidden buttons. Setting the hidden buttons' frame to an empty rectangle fixes this.
+            [[window->nsWindow standardWindowButton:NSWindowMiniaturizeButton] setFrame:CGRectMake(0, 0, 0, 0)];
+            [[window->nsWindow standardWindowButton:NSWindowZoomButton] setFrame:CGRectMake(0, 0, 0, 0)];
+
             if (!jOwnerPtr) {
                 [window->nsWindow setLevel:NSNormalWindowLevel];
             }
@@ -451,8 +471,7 @@ static jlong _createWindowCommonDo(JNIEnv *env, jobject jWindow, jlong jOwnerPtr
         {
             window->owner = getGlassWindow(env, jOwnerPtr)->nsWindow; // not retained (use weak reference?)
         }
-        window->isResizable = NO;
-        window->isDecorated = (jStyleMask&com_sun_glass_ui_Window_TITLED) != 0;
+
         /* 10.7 full screen window support */
         if ([NSWindow instancesRespondToSelector:@selector(toggleFullScreen:)]) {
             NSWindowCollectionBehavior behavior = [window->nsWindow collectionBehavior];
@@ -470,8 +489,7 @@ static jlong _createWindowCommonDo(JNIEnv *env, jobject jWindow, jlong jOwnerPtr
             [window->nsWindow setCollectionBehavior: behavior];
         }
 
-        window->isTransparent = (jStyleMask & com_sun_glass_ui_Window_TRANSPARENT) != 0;
-        if (window->isTransparent == YES)
+        if (isTransparent)
         {
             [window->nsWindow setBackgroundColor:[NSColor clearColor]];
             [window->nsWindow setHasShadow:NO];
@@ -483,11 +501,12 @@ static jlong _createWindowCommonDo(JNIEnv *env, jobject jWindow, jlong jOwnerPtr
             [window->nsWindow setOpaque:YES];
         }
 
-        window->fullscreenWindow = nil;
-
+        window->isDecorated = isTitled || isExtended;
+        window->isTransparent = isTransparent;
         window->isSizeAssigned = NO;
         window->isLocationAssigned = NO;
-
+        window->isResizable = NO;
+        [window _setResizable:NO]; // actual value will be set later with a separate JNI downcall
     }
     [pool drain];
 
@@ -760,7 +779,7 @@ JNIEXPORT jboolean JNICALL Java_com_sun_glass_ui_mac_MacWindow__1setBackground
     GLASS_POOL_ENTER;
     {
         GlassWindow *window = getGlassWindow(env, jPtr);
-        [window->nsWindow setBackgroundColor:[NSColor colorWithCalibratedRed:r green:g blue:b alpha:1.0f]];
+        [window->nsWindow setBackgroundColor:[NSColor colorWithSRGBRed:r green:g blue:b alpha:1.0f]];
     }
     GLASS_POOL_EXIT;
     GLASS_CHECK_EXCEPTION(env);
@@ -824,7 +843,7 @@ JNIEXPORT jboolean JNICALL Java_com_sun_glass_ui_mac_MacWindow__1setView
                 [((CAOpenGLLayer*)layer) setOpaque:[window->nsWindow isOpaque]];
             }
 
-            window->suppressWindowMoveEvent = YES; // RT-11215
+            window->suppressWindowMoveEvent = YES; // JDK-8111165
             {
                 NSRect viewFrame = [window->view frame];
                 if ((viewFrame.size.width != 0.0f) && (viewFrame.size.height != 0.0f))
@@ -903,7 +922,7 @@ JNIEXPORT jboolean JNICALL Java_com_sun_glass_ui_mac_MacWindow__1close
         // ensure that performKeyEquivalent returns YES.
         window->isClosed = YES;
 
-        // RT-39813 When closing a window as the result of a global right-click
+        // JDK-8095359 When closing a window as the result of a global right-click
         //          mouse event outside the bounds of the window, using an immediate
         //          [window->nsWindow close] crashes the JDK as the AppKit at this
         //          point still has another [NSWindow _resignKeyFocus] from the
@@ -1143,10 +1162,7 @@ JNIEXPORT jboolean JNICALL Java_com_sun_glass_ui_mac_MacWindow__1setResizable
     GLASS_POOL_ENTER;
     {
         GlassWindow *window = getGlassWindow(env, jPtr);
-        if (window->isResizable != jResizable)
-        {
-            [window performSelectorOnMainThread:@selector(_setResizable) withObject:nil waitUntilDone:YES];
-        }
+        [window _setResizable:jResizable];
     }
     GLASS_POOL_EXIT;
     GLASS_CHECK_EXCEPTION(env);
@@ -1194,7 +1210,7 @@ JNIEXPORT jboolean JNICALL Java_com_sun_glass_ui_mac_MacWindow__1setVisible
         }
         now = [window->nsWindow isVisible] ? JNI_TRUE : JNI_FALSE;
 
-        // RT-22502 temp workaround: bring plugin window in front of a browser
+        // JDK-8088691 temp workaround: bring plugin window in front of a browser
         if (now == YES)
         {
             static BOOL isBackgroundOnlyAppChecked = NO;
@@ -1386,23 +1402,22 @@ JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacWindow__1toBack
     GLASS_CHECK_EXCEPTION(env);
 }
 
-
 /*
  * Class:     com_sun_glass_ui_mac_MacWindow
- * Method:    _enterModal
+ * Method:    _performWindowDrag
  * Signature: (J)V
  */
-JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacWindow__1enterModal
+JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacWindow__1performWindowDrag
 (JNIEnv *env, jobject jWindow, jlong jPtr)
 {
-    LOG("Java_com_sun_glass_ui_mac_MacWindow__1enterModal");
+    LOG("Java_com_sun_glass_ui_mac_MacWindow__1performWindowDrag");
     if (!jPtr) return;
 
     GLASS_ASSERT_MAIN_JAVA_THREAD(env);
     GLASS_POOL_ENTER;
     {
         GlassWindow *window = getGlassWindow(env, jPtr);
-        [NSApp runModalForWindow:window->nsWindow];
+        [[window->view delegate] performWindowDrag];
     }
     GLASS_POOL_EXIT;
     GLASS_CHECK_EXCEPTION(env);
@@ -1410,41 +1425,82 @@ JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacWindow__1enterModal
 
 /*
  * Class:     com_sun_glass_ui_mac_MacWindow
- * Method:    _enterModalWithWindow
- * Signature: (JJ)V
- */
-JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacWindow__1enterModalWithWindow
-(JNIEnv *env, jobject jWindow, jlong jDialogPtr, jlong jWindowPtr)
-{
-    LOG("Java_com_sun_glass_ui_mac_MacWindow__1enterModalWithWindow");
-
-    GLASS_ASSERT_MAIN_JAVA_THREAD(env);
-    GLASS_POOL_ENTER;
-    {
-        //GlassWindow *window = getGlassWindow(env, jDialogPtr);
-        // TODO: implement _enterModalWithWindow
-    }
-    GLASS_POOL_EXIT;
-    GLASS_CHECK_EXCEPTION(env);
-}
-
-/*
- * Class:     com_sun_glass_ui_mac_MacWindow
- * Method:    _exitModal
+ * Method:    _performTitleBarDoubleClickAction
  * Signature: (J)V
  */
-JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacWindow__1exitModal
+JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacWindow__1performTitleBarDoubleClickAction
 (JNIEnv *env, jobject jWindow, jlong jPtr)
 {
-    LOG("Java_com_sun_glass_ui_mac_MacWindow__1exitModal");
+    LOG("Java_com_sun_glass_ui_mac_MacWindow__1performTitleBarDoubleClickAction");
     if (!jPtr) return;
 
     GLASS_ASSERT_MAIN_JAVA_THREAD(env);
     GLASS_POOL_ENTER;
     {
         GlassWindow *window = getGlassWindow(env, jPtr);
-        [NSApp stop:window->nsWindow];
+        NSString* action = [NSUserDefaults.standardUserDefaults stringForKey:@"AppleActionOnDoubleClick"];
+
+        if ([action isEqualToString:@"Minimize"]) {
+            [window->nsWindow performMiniaturize:nil];
+        } else if ([action isEqualToString:@"Maximize"]) {
+            [window->nsWindow performZoom:nil];
+        }
     }
     GLASS_POOL_EXIT;
     GLASS_CHECK_EXCEPTION(env);
 }
+
+/*
+ * Class:     com_sun_glass_ui_mac_MacWindow
+ * Method:    _setWindowButtonStyle
+ * Signature: (JIZ)V
+ */
+JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacWindow__1setWindowButtonStyle
+(JNIEnv *env, jobject jWindow, jlong jPtr, jint toolbarStyle, jboolean buttonsVisible)
+{
+    LOG("Java_com_sun_glass_ui_mac_MacWindow__1setWindowButtonStyle");
+    if (!jPtr) return;
+
+    GLASS_ASSERT_MAIN_JAVA_THREAD(env);
+    GLASS_POOL_ENTER;
+    {
+        GlassWindow *window = getGlassWindow(env, jPtr);
+        if (window) {
+            window->isStandardButtonsVisible = buttonsVisible;
+
+            if (window->nsWindow) {
+                [window->nsWindow setToolbarStyle:toolbarStyle];
+                [[window->nsWindow standardWindowButton:NSWindowCloseButton] setHidden:!buttonsVisible];
+                [[window->nsWindow standardWindowButton:NSWindowMiniaturizeButton] setHidden:!buttonsVisible];
+                [[window->nsWindow standardWindowButton:NSWindowZoomButton] setHidden:!buttonsVisible];
+            }
+        }
+    }
+    GLASS_POOL_EXIT;
+    GLASS_CHECK_EXCEPTION(env);
+}
+
+/*
+ * Class:     com_sun_glass_ui_mac_MacWindow
+ * Method:    _isRightToLeftLayoutDirection
+ * Signature: ()Z;
+ */
+JNIEXPORT jboolean JNICALL Java_com_sun_glass_ui_mac_MacWindow__1isRightToLeftLayoutDirection
+(JNIEnv *env, jobject self)
+{
+    LOG("Java_com_sun_glass_ui_mac_MacWindow__1isRightToLeftLayoutDirection");
+    jboolean result = false;
+
+    GLASS_ASSERT_MAIN_JAVA_THREAD(env);
+    GLASS_POOL_ENTER;
+    {
+        NSString* preferredLanguage = [[NSLocale preferredLanguages] objectAtIndex:0];
+        NSLocale* locale = [NSLocale localeWithLocaleIdentifier:preferredLanguage];
+        NSString* languageCode = [locale objectForKey:NSLocaleLanguageCode];
+        result = [NSLocale characterDirectionForLanguage:languageCode] == NSLocaleLanguageDirectionRightToLeft;
+    }
+    GLASS_POOL_EXIT;
+    GLASS_CHECK_EXCEPTION(env);
+
+    return result;
+}
