@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -428,7 +428,7 @@ void ViewContainer::HandleViewKeyEvent(HWND hwnd, UINT msg, WPARAM wParam, LPARA
         // No translation available
         keyCharCount = 0;
         // This includes SHIFT, CONTROL, ALT, etc.
-        // RT-17062: suppress auto-repeated events for modifier keys
+        // JDK-8100645: suppress auto-repeated events for modifier keys
         if (isAutoRepeat) {
             switch (jKeyCode) {
                 case com_sun_glass_events_KeyEvent_VK_SHIFT:
@@ -547,8 +547,8 @@ void ViewContainer::HandleViewDeadKeyEvent(HWND hwnd, UINT msg, WPARAM wParam, L
     }
 
     // Since we handle dead keys ourselves, reset the keyboard dead key status (if any)
-    static BYTE kbState[256];
-    ::GetKeyboardState(kbState);
+    BYTE kbState[256] = {};
+    kbState[VK_SPACE] = 0x80;
     WORD ignored;
     ::ToAsciiEx(VK_SPACE, ::MapVirtualKey(VK_SPACE, 0),
             kbState, &ignored, 0, m_kbLayout);
@@ -669,9 +669,14 @@ void ViewContainer::HandleViewTypedEvent(HWND hwnd, UINT msg, WPARAM wParam, LPA
             wChar = (jchar)out[0];
 
             if (res == 3) {
-                // The character cannot be accented, so we send a TYPED event
-                // for the dead key itself first.
-                SendViewTypedEvent(1, (jchar)m_deadKeyWParam);
+                // The character cannot be accented. If it's a Space
+                // we send out the dead key only. Otherwise we send
+                // out the dead key followed by the character.
+                if (wChar == 0x20) {
+                    wChar = m_deadKeyWParam;
+                } else {
+                    SendViewTypedEvent(1, (jchar)m_deadKeyWParam);
+                }
             }
         } else {
             // Folding failed. Use the untranslated original character then
@@ -685,7 +690,7 @@ void ViewContainer::HandleViewTypedEvent(HWND hwnd, UINT msg, WPARAM wParam, LPA
     SendViewTypedEvent(repCount, wChar);
 }
 
-BOOL ViewContainer::HandleViewMouseEvent(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
+BOOL ViewContainer::HandleViewMouseEvent(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam, BOOL extendedWindow)
 {
     if (!GetGlassView()) {
         return FALSE;
@@ -696,7 +701,54 @@ BOOL ViewContainer::HandleViewMouseEvent(HWND hwnd, UINT msg, WPARAM wParam, LPA
     POINT pt;   // client coords
     jdouble wheelRotation = 0.0;
 
-    if (msg == WM_MOUSELEAVE) {
+    // Windows with the EXTENDED style have an unusual anatomy: the entire window (excluding borders) comprises
+    // the client area with regards to geometry, but not with regards to hit testing. The title bar is classified
+    // as a non-client hit-testing area (by responding to the WM_NCHITTEST message), which enables window manager
+    // interactions (dragging, snap layouts, etc).
+    // When the mouse cursor moves from the client area to the title bar, we technically receive a WM_MOUSELEAVE
+    // message that would normally cause a MouseEvent.EXIT event to be emitted. However, from the point of view
+    // of the JavaFX application, the mouse cursor is still on the client-side title bar and therefore we wouldn't
+    // expect to receive an MouseEvent.EXIT event. The following code detects this situation and prevents the
+    // MouseEvent.EXIT event from being fired.
+    if (msg == WM_MOUSELEAVE && extendedWindow) {
+        DWORD msgPos = ::GetMessagePos(); // screen coordinates
+        pt.x = GET_X_LPARAM(msgPos);
+        pt.y = GET_Y_LPARAM(msgPos);
+        RECT windowRect;
+
+        // We know that the cursor has moved from the client area to the title bar when the following two
+        // conditions are met:
+        //   1. The window under the cursor is our own window. This allows us to disambiguate the situation
+        //      when the cursor was moved to another overlapping window that just happens to be placed over
+        //      our title bar.
+        //   2. The cursor position is still within the client area of our window. This allows us to detect
+        //      when the cursor was moved to the resize border of our window, which isn't part of the client
+        //      area and should therefore emit an EXIT event.
+        if (::ChildWindowFromPointEx(::GetDesktopWindow(), pt, CWP_SKIPINVISIBLE) == hwnd
+                && ::GetClientRect(hwnd, &windowRect)
+                && ::ClientToScreen(hwnd, reinterpret_cast<POINT*>(&windowRect.left))
+                && ::ClientToScreen(hwnd, reinterpret_cast<POINT*>(&windowRect.right))
+                && ::PtInRect(&windowRect, pt)) { // pt is still in screen coordinates here
+            TRACKMOUSEEVENT trackData;
+            trackData.cbSize = sizeof(trackData);
+            trackData.dwFlags = TME_LEAVE | TME_NONCLIENT;
+            trackData.hwndTrack = hwnd;
+            trackData.dwHoverTime = HOVER_DEFAULT;
+
+            // The cursor is now on the non-client hit-testing area of our window, and we need to enable
+            // non-client mouse tracking to get a WM_NCMOUSELEAVE message when the cursor leaves the
+            // non-client hit-testing area.
+            if (::TrackMouseEvent(&trackData)) {
+                m_bTrackingMouse = TRUE;
+            }
+        } else {
+            type = com_sun_glass_events_MouseEvent_EXIT;
+            m_bTrackingMouse = FALSE;
+            m_lastMouseMovePosition = -1;
+        }
+
+        ::ScreenToClient(hwnd, &pt);
+    } else if (msg == WM_MOUSELEAVE) {
         type = com_sun_glass_events_MouseEvent_EXIT;
         // get the coords (the message does not contain them)
         lParam = ::GetMessagePos();
@@ -724,13 +776,13 @@ BOOL ViewContainer::HandleViewMouseEvent(HWND hwnd, UINT msg, WPARAM wParam, LPA
                 } else {
                     m_lastMouseMovePosition = lParam;
                 }
-                // See RT-11305 regarding the GetCapture() check
+                // See JDK-8110944 regarding the GetCapture() check
                 if ((wParam & (MK_LBUTTON | MK_RBUTTON | MK_MBUTTON | MK_XBUTTON1 | MK_XBUTTON2)) != 0 && ::GetCapture() == hwnd) {
                     type = com_sun_glass_events_MouseEvent_DRAG;
                 } else {
                     type = com_sun_glass_events_MouseEvent_MOVE;
                 }
-                // Due to RT-11305 we should report the pressed button for both
+                // Due to JDK-8110944 we should report the pressed button for both
                 // MOVE and DRAG. This also enables one to filter out these
                 // events in client code in case they're undesired.
                 if (wParam & MK_RBUTTON) {
@@ -929,6 +981,160 @@ BOOL ViewContainer::HandleViewMouseEvent(HWND hwnd, UINT msg, WPARAM wParam, LPA
     return TRUE;
 }
 
+void ViewContainer::HandleViewNonClientMouseEvent(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
+{
+    if (!GetGlassView()) {
+        return;
+    }
+
+    int type = 0;
+    int button = com_sun_glass_events_MouseEvent_BUTTON_NONE;
+    POINT pt;   // client coords
+
+    // Windows with the EXTENDED style have an unusual anatomy: the entire window (excluding borders) comprises
+    // the client area with regards to geometry, but not with regards to hit testing. The title bar is classified
+    // as a non-client hit-testing area (by responding to the WM_NCHITTEST message), which enables window manager
+    // interactions (dragging, snap layouts, etc).
+    // When the mouse cursor moves from the title bar to the client area, we technically receive a WM_NCMOUSELEAVE
+    // message that would normally cause a MouseEvent.EXIT event to be emitted. However, from the point of view
+    // of the JavaFX application, the mouse cursor is still on the window's client area and therefore we wouldn't
+    // expect to receive an MouseEvent.EXIT event. The following code detects this situation and prevents the
+    // MouseEvent.EXIT event from being fired.
+    if (msg == WM_NCMOUSELEAVE) {
+        DWORD msgPos = ::GetMessagePos(); // screen coordinates
+        pt.x = GET_X_LPARAM(msgPos);
+        pt.y = GET_Y_LPARAM(msgPos);
+
+        // Skip the MouseEvent.EXIT event when the cursor is now directly over our window. In contrast to
+        // similar code in ViewContainer::HandleViewMouseEvent(), we don't need to test whether the cursor
+        // is within the client area. If the cursor has left the non-client area, but is still directly over
+        // our window, it can't be anywhere else but in the client area.
+        if (::ChildWindowFromPointEx(::GetDesktopWindow(), pt, CWP_SKIPINVISIBLE) == hwnd) {
+            TRACKMOUSEEVENT trackData;
+            trackData.cbSize = sizeof(trackData);
+            trackData.dwFlags = TME_LEAVE;
+            trackData.hwndTrack = hwnd;
+            trackData.dwHoverTime = HOVER_DEFAULT;
+
+            // Since the cursor is now on the client area of our window, we need to enable mouse tracking
+            // to get a WM_MOUSELEAVE message when the cursor leaves the client area.
+            if (::TrackMouseEvent(&trackData)) {
+                m_bTrackingMouse = TRUE;
+            }
+        } else {
+            type = com_sun_glass_events_MouseEvent_EXIT;
+            m_bTrackingMouse = FALSE;
+            m_lastMouseMovePosition = -1;
+        }
+
+        ::ScreenToClient(hwnd, &pt);
+    } else if (msg >= WM_NCMOUSEMOVE
+                   && msg <= WM_NCXBUTTONDBLCLK
+                   && (wParam == HTCAPTION || wParam == HTMINBUTTON || wParam == HTMAXBUTTON || wParam == HTCLOSE)) {
+        pt.x = GET_X_LPARAM(lParam);
+        pt.y = GET_Y_LPARAM(lParam);
+        ::MapWindowPoints(NULL, hwnd, &pt, 1);
+
+        switch (msg) {
+            case WM_NCMOUSEMOVE:
+                if (lParam == m_lastMouseMovePosition) {
+                    // Avoid sending synthetic NC_MOVE events if
+                    // the pointer hasn't moved actually.
+                    // Just consume the messages.
+                    return;
+                }
+
+                m_lastMouseMovePosition = lParam;
+                type = com_sun_glass_events_MouseEvent_MOVE;
+                break;
+            case WM_NCLBUTTONDOWN:
+                type = com_sun_glass_events_MouseEvent_DOWN;
+                button = com_sun_glass_events_MouseEvent_BUTTON_LEFT;
+                break;
+            case WM_NCLBUTTONUP:
+                type = com_sun_glass_events_MouseEvent_UP;
+                button = com_sun_glass_events_MouseEvent_BUTTON_LEFT;
+                break;
+            case WM_NCRBUTTONDOWN:
+                type = com_sun_glass_events_MouseEvent_DOWN;
+                button = com_sun_glass_events_MouseEvent_BUTTON_RIGHT;
+                break;
+            case WM_NCRBUTTONUP:
+                type = com_sun_glass_events_MouseEvent_UP;
+                button = com_sun_glass_events_MouseEvent_BUTTON_RIGHT;
+                break;
+            case WM_NCMBUTTONDOWN:
+                type = com_sun_glass_events_MouseEvent_DOWN;
+                button = com_sun_glass_events_MouseEvent_BUTTON_OTHER;
+                break;
+            case WM_NCMBUTTONUP:
+                type = com_sun_glass_events_MouseEvent_UP;
+                button = com_sun_glass_events_MouseEvent_BUTTON_OTHER;
+                break;
+            case WM_NCXBUTTONDOWN:
+                type = com_sun_glass_events_MouseEvent_DOWN;
+                button = GET_XBUTTON_WPARAM(wParam) == XBUTTON1
+                    ? com_sun_glass_events_MouseEvent_BUTTON_BACK
+                    : com_sun_glass_events_MouseEvent_BUTTON_FORWARD;
+                break;
+            case WM_NCXBUTTONUP:
+                type = com_sun_glass_events_MouseEvent_UP;
+                button = GET_XBUTTON_WPARAM(wParam) == XBUTTON1
+                    ? com_sun_glass_events_MouseEvent_BUTTON_BACK
+                    : com_sun_glass_events_MouseEvent_BUTTON_FORWARD;
+                break;
+        }
+    }
+
+    // Event was not handled
+    if (type == 0) {
+        return;
+    }
+
+    // get screen coords
+    POINT ptAbs = pt;
+    ::ClientToScreen(hwnd, &ptAbs);
+
+    // unmirror the x coordinate
+    LONG style = ::GetWindowLong(hwnd, GWL_EXSTYLE);
+    if (style & WS_EX_LAYOUTRTL) {
+        RECT rect = {0};
+        ::GetClientRect(hwnd, &rect);
+        pt.x = max(0, rect.right - rect.left) - pt.x;
+    }
+
+    jint jModifiers = GetModifiers();
+    jboolean isSynthesized = jboolean(IsTouchEvent());
+    JNIEnv* env = GetEnv();
+
+    if (!m_bTrackingMouse && type != com_sun_glass_events_MouseEvent_EXIT) {
+        TRACKMOUSEEVENT trackData;
+        trackData.cbSize = sizeof(trackData);
+        trackData.dwFlags = TME_LEAVE | TME_NONCLIENT;
+        trackData.hwndTrack = hwnd;
+        trackData.dwHoverTime = HOVER_DEFAULT;
+
+        if (::TrackMouseEvent(&trackData)) {
+            // Mouse tracking will be canceled automatically upon receiving WM_NCMOUSELEAVE
+            m_bTrackingMouse = TRUE;
+        }
+
+        env->CallVoidMethod(GetView(), javaIDs.View.notifyMouse,
+            com_sun_glass_events_MouseEvent_ENTER,
+            com_sun_glass_events_MouseEvent_BUTTON_NONE,
+            pt.x, pt.y, ptAbs.x, ptAbs.y,
+            jModifiers, JNI_FALSE, isSynthesized);
+        CheckAndClearException(env);
+    }
+
+    env->CallVoidMethod(GetView(), javaIDs.View.notifyMouse,
+        type, button, pt.x, pt.y, ptAbs.x, ptAbs.y,
+        jModifiers,
+        type == com_sun_glass_events_MouseEvent_UP && button == com_sun_glass_events_MouseEvent_BUTTON_RIGHT,
+        isSynthesized);
+    CheckAndClearException(env);
+}
+
 void ViewContainer::NotifyCaptureChanged(HWND hwnd, HWND to)
 {
     m_mouseButtonDownCounter = 0;
@@ -943,7 +1149,7 @@ void ViewContainer::ResetMouseTracking(HWND hwnd)
     // We don't expect WM_MOUSELEAVE anymore, so we cancel mouse tracking manually
     TRACKMOUSEEVENT trackData;
     trackData.cbSize = sizeof(trackData);
-    trackData.dwFlags = TME_LEAVE | TME_CANCEL;
+    trackData.dwFlags = TME_LEAVE | TME_NONCLIENT | TME_CANCEL;
     trackData.hwndTrack = hwnd;
     trackData.dwHoverTime = HOVER_DEFAULT;
     ::TrackMouseEvent(&trackData);
@@ -1211,7 +1417,7 @@ void NotifyTouchInput(
 
     // Sets to 'true' if source device is a touch screen
     // and to 'false' if source device is a touch pad/pen.
-    const bool isDirect = IsTouchEvent();
+    const bool isDirect = (ti->dwFlags & TOUCHEVENTF_PEN) == 0;
 
     jint modifiers = GetModifiers();
     env->CallStaticObjectMethod(gestureSupportCls,
