@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -35,11 +35,12 @@ import com.sun.javafx.sg.prism.NGNode;
 import com.sun.javafx.sg.prism.NGNodeShim;
 import com.sun.javafx.sg.prism.NGRectangle;
 import com.sun.javafx.sg.prism.NodePath;
-import org.junit.Before;
-import org.junit.Ignore;
-import org.junit.Test;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 /**
  * Tests for the computation of the render root of a graph
@@ -65,7 +66,7 @@ public class RenderRootTest extends NGTestBase {
     private NGRectangle rect;
     private NGGroup root;
 
-    @Before
+    @BeforeEach
     public void setup() {
         rect = createRectangle(10, 10, 90, 90);
         root = createGroup(rect);
@@ -138,7 +139,7 @@ public class RenderRootTest extends NGTestBase {
      */
     @Test
     public void dirtyRegionWithinOpaqueRegion_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 20, 20, 70, 70);
         assertRenderRoot(null, rootPath);
     }
@@ -159,7 +160,7 @@ public class RenderRootTest extends NGTestBase {
      */
     @Test
     public void dirtyRegionMatchesOpaqueRegion_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 10, 10, 90, 90);
         assertRenderRoot(null, rootPath);
     }
@@ -180,7 +181,7 @@ public class RenderRootTest extends NGTestBase {
      */
     @Test
     public void dirtyRegionWithinOpaqueRegionTouchesTop_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 20, 10, 70, 70);
         assertRenderRoot(null, rootPath);
     }
@@ -200,7 +201,7 @@ public class RenderRootTest extends NGTestBase {
      */
     @Test
     public void dirtyRegionWithinOpaqueRegionTouchesRight_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 20, 20, 80, 70);
         assertRenderRoot(null, rootPath);
     }
@@ -221,7 +222,7 @@ public class RenderRootTest extends NGTestBase {
      */
     @Test
     public void dirtyRegionWithinOpaqueRegionTouchesBottom_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 20, 20, 70, 80);
         assertRenderRoot(null, rootPath);
     }
@@ -242,7 +243,7 @@ public class RenderRootTest extends NGTestBase {
      */
     @Test
     public void dirtyRegionWithinOpaqueRegionTouchesLeft_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 10, 20, 70, 70);
         assertRenderRoot(null, rootPath);
     }
@@ -255,7 +256,7 @@ public class RenderRootTest extends NGTestBase {
 
     @Test
     public void opaqueRegionWithinDirtyRegion_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 0, 0, 110, 110);
         assertRenderRoot(root, rootPath);
     }
@@ -268,7 +269,7 @@ public class RenderRootTest extends NGTestBase {
 
     @Test
     public void dirtyRegionIntersectsOpaqueRegionTop_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 20, 0, 70, 30);
         assertRenderRoot(root, rootPath);
     }
@@ -281,7 +282,7 @@ public class RenderRootTest extends NGTestBase {
 
     @Test
     public void dirtyRegionIntersectsOpaqueRegionRight_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 90, 20, 30, 70);
         assertRenderRoot(root, rootPath);
     }
@@ -294,7 +295,7 @@ public class RenderRootTest extends NGTestBase {
 
     @Test
     public void dirtyRegionIntersectsOpaqueRegionBottom_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 20, 90, 70, 30);
         assertRenderRoot(root, rootPath);
     }
@@ -307,7 +308,7 @@ public class RenderRootTest extends NGTestBase {
 
     @Test
     public void dirtyRegionIntersectsOpaqueRegionLeft_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 0, 20, 30, 70);
         assertRenderRoot(root, rootPath);
     }
@@ -320,7 +321,7 @@ public class RenderRootTest extends NGTestBase {
 
     @Test
     public void dirtyRegionCompletelyOutsideOfOpaqueRegion_Clean() {
-        root.clearDirtyTree();
+        root.clearDirty();
         NodePath rootPath = getRenderRoot(root, 0, 0, 5, 5);
         assertRenderRoot(root, rootPath);
     }
@@ -336,7 +337,7 @@ public class RenderRootTest extends NGTestBase {
     // Changing this behavior may cause rendering glitches for any application that
     // relies on this current behavior to render all root tree.
     // So we need to be extensive in testing before modifying the behavior.
-    @Ignore("JDK-8265510")
+    @Disabled("JDK-8265510")
     @Test
     public void emptyDirtyRegion1() {
         NodePath rootPath = getRenderRoot(root, 0, 0, -1, -1);
@@ -345,7 +346,7 @@ public class RenderRootTest extends NGTestBase {
         // assertRenderRoot(null, rootPath);
     }
 
-    @Ignore("JDK-8265510")
+    @Disabled("JDK-8265510")
     @Test
     public void emptyDirtyRegion2() {
         NodePath rootPath = getRenderRoot(root, -1, -1, -2, -2);
@@ -354,7 +355,7 @@ public class RenderRootTest extends NGTestBase {
         // assertRenderRoot(null, rootPath);
     }
 
-    @Ignore("JDK-8265510")
+    @Disabled("JDK-8265510")
     @Test
     public void invalidDirtyRegionOutsideOpaqueRegion() {
         NodePath rootPath = getRenderRoot(root, -10, -10, 5, 5);
