@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -40,6 +40,7 @@ import com.sun.javafx.css.CascadingStyle;
 import com.sun.javafx.css.ParsedValueImpl;
 import com.sun.javafx.css.PseudoClassState;
 import com.sun.javafx.css.StyleManager;
+import com.sun.javafx.scene.AbstractNode;
 import test.com.sun.javafx.css.TestNode;
 import test.com.sun.javafx.css.TestNodeBase;
 import javafx.beans.value.WritableValue;
@@ -54,7 +55,8 @@ import javafx.scene.text.Text;
 import javafx.stage.Stage;
 import javafx.css.converter.BooleanConverter;
 import com.sun.javafx.scene.NodeHelper;
-import javafx.css.CompoundSelector;
+import com.sun.javafx.css.CompoundSelector;
+import com.sun.javafx.css.SimpleSelector;
 import javafx.css.CssMetaData;
 import javafx.css.CssParser;
 import javafx.css.CssParserShim;
@@ -67,8 +69,6 @@ import javafx.css.Rule;
 import javafx.css.RuleShim;
 import javafx.css.Selector;
 import javafx.css.SelectorShim;
-import javafx.css.SimpleSelector;
-import javafx.css.SimpleSelectorShim;
 import javafx.css.Style;
 import javafx.css.StyleConverter;
 import javafx.css.StyleOrigin;
@@ -77,11 +77,15 @@ import javafx.css.StyleableProperty;
 import javafx.css.Stylesheet;
 import javafx.css.StylesheetShim;
 
-import org.junit.After;
-import org.junit.Test;
-import org.junit.Ignore;
-
-import static org.junit.Assert.*;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Disabled;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 enum TestEnum {
     LEFT,
@@ -111,7 +115,7 @@ public class CssMetaDataTest {
         sm.hasDefaultUserAgentStylesheet = false;
     }
 
-    @After
+    @AfterEach
     public void cleanup() {
         resetStyleManager();
     }
@@ -239,7 +243,7 @@ public class CssMetaDataTest {
     @Test
     public void testEquals() {
         TestNode testNode = new TestNode();
-        Node node = new Node() {
+        Node node = new AbstractNode() {
         };
 
         CssMetaData testNodeOpacity = get(TestNode.getClassCssMetaData(), "-fx-opacity");
@@ -252,16 +256,15 @@ public class CssMetaDataTest {
     static CascadingStyle createCascadingStyle(Selector selector, Declaration declaration) {
 
         Set<PseudoClass> pseudoClasses = null;
-        if (selector instanceof SimpleSelector) {
+        if (selector instanceof SimpleSelector s) {
 
-            pseudoClasses =
-                    SimpleSelectorShim.getPseudoClassStates((SimpleSelector)selector);
+            pseudoClasses = s.getPseudoClassStates();
         } else {
 
             pseudoClasses = new PseudoClassState();
             for (SimpleSelector sel : ((CompoundSelector)selector).getSelectors()) {
 
-                Set<PseudoClass> selectorPseudoClasses = SimpleSelectorShim.getPseudoClassStates(sel);
+                Set<PseudoClass> selectorPseudoClasses = sel.getPseudoClassStates();
                 pseudoClasses.addAll(selectorPseudoClasses);
             }
         }
@@ -274,7 +277,7 @@ public class CssMetaDataTest {
         );
     }
 
-    @Ignore("JDK-8234142")
+    @Disabled("JDK-8234142")
     @Test
     public void testGetMatchingStyles() {
 
@@ -291,7 +294,7 @@ public class CssMetaDataTest {
         List<String> rootStyleClass = new ArrayList<>();
         rootStyleClass.add("root");
 
-        Selector root = SimpleSelectorShim.getSimpleSelector("*", rootStyleClass, null, null);
+        Selector root = new SimpleSelector("*", rootStyleClass, null, null);
 
         ParsedValue fxBaseValue = new CssParserShim().parseExpr("-fx-base", "red");
         Declaration fxBase = DeclarationShim.getDeclaration("-fx-base", fxBaseValue, false);
@@ -314,7 +317,7 @@ public class CssMetaDataTest {
         List<String> rectStyleClass = new ArrayList<>();
         rectStyleClass.add("rect");
 
-        Selector rect = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, null, null);
+        Selector rect = new SimpleSelector("*", rectStyleClass, null, null);
 
         ParsedValue fxFillValue = new CssParserShim().parseExpr("-fx-fill", "-fx-color");
         Declaration fxFill = DeclarationShim.getDeclaration("-fx-fill", fxFillValue, false);
@@ -332,7 +335,7 @@ public class CssMetaDataTest {
         List<String> pseudoclasses = new ArrayList<>();
         pseudoclasses.add("hover");
 
-        Selector rectHover = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, pseudoclasses, null);
+        Selector rectHover = new SimpleSelector("*", rectStyleClass, pseudoclasses, null);
 
         ParsedValueImpl<Color,Color> fxFillHoverValue = new ParsedValueImpl<>(Color.YELLOW, null);
         Declaration fxFillHover = DeclarationShim.getDeclaration("-fx-fill", fxFillHoverValue, false);
@@ -380,7 +383,7 @@ public class CssMetaDataTest {
         assertTrue(actuals.isEmpty());
     }
 
-    @Ignore("JDK-8234142")
+    @Disabled("JDK-8234142")
     @Test
     public void testGetMatchingStylesWithInlineStyleOnParent() {
 
@@ -396,7 +399,7 @@ public class CssMetaDataTest {
         List<String> rootStyleClass = new ArrayList<>();
         rootStyleClass.add("root");
 
-        Selector root = SimpleSelectorShim.getSimpleSelector("*", rootStyleClass, null, null);
+        Selector root = new SimpleSelector("*", rootStyleClass, null, null);
 
         ParsedValue fxBaseValue = new CssParserShim().parseExpr("-fx-base", "red");
         Declaration fxBase = DeclarationShim.getDeclaration("-fx-base", fxBaseValue, false);
@@ -419,7 +422,7 @@ public class CssMetaDataTest {
         List<String> rectStyleClass = new ArrayList<>();
         rectStyleClass.add("rect");
 
-        Selector rect = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, null, null);
+        Selector rect = new SimpleSelector("*", rectStyleClass, null, null);
 
         ParsedValue fxFillValue = new CssParserShim().parseExpr("-fx-fill", "-fx-color");
         Declaration fxFill = DeclarationShim.getDeclaration("-fx-fill", fxFillValue, false);
@@ -437,7 +440,7 @@ public class CssMetaDataTest {
         List<String> pseudoclasses = new ArrayList<>();
         pseudoclasses.add("hover");
 
-        Selector rectHover = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, pseudoclasses, null);
+        Selector rectHover = new SimpleSelector("*", rectStyleClass, pseudoclasses, null);
 
         ParsedValueImpl<Color,Color> fxFillHoverValue = new ParsedValueImpl<>(Color.YELLOW, null);
         Declaration fxFillHover = DeclarationShim.getDeclaration("-fx-fill", fxFillHoverValue, false);
@@ -503,7 +506,7 @@ public class CssMetaDataTest {
         assertTrue(actuals.isEmpty());
     }
 
-    @Ignore("JDK-8234142")
+    @Disabled("JDK-8234142")
     @Test
     public void testGetMatchingStylesWithInlineStyleOnLeaf() {
 
@@ -520,7 +523,7 @@ public class CssMetaDataTest {
         List<String> rootStyleClass = new ArrayList<>();
         rootStyleClass.add("root");
 
-        Selector root = SimpleSelectorShim.getSimpleSelector("*", rootStyleClass, null, null);
+        Selector root = new SimpleSelector("*", rootStyleClass, null, null);
 
         ParsedValue fxBaseValue = new CssParserShim().parseExpr("-fx-base", "red");
         Declaration fxBase = DeclarationShim.getDeclaration("-fx-base", fxBaseValue, false);
@@ -543,7 +546,7 @@ public class CssMetaDataTest {
         List<String> rectStyleClass = new ArrayList<>();
         rectStyleClass.add("rect");
 
-        Selector rect = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, null, null);
+        Selector rect = new SimpleSelector("*", rectStyleClass, null, null);
 
         ParsedValue fxFillValue = new CssParserShim().parseExpr("-fx-fill", "-fx-color");
         Declaration fxFill = DeclarationShim.getDeclaration("-fx-fill", fxFillValue, false);
@@ -561,7 +564,7 @@ public class CssMetaDataTest {
         List<String> pseudoclasses = new ArrayList<>();
         pseudoclasses.add("hover");
 
-        Selector rectHover = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, pseudoclasses, null);
+        Selector rectHover = new SimpleSelector("*", rectStyleClass, pseudoclasses, null);
 
         ParsedValueImpl<Color,Color> fxFillHoverValue = new ParsedValueImpl<>(Color.YELLOW, null);
         Declaration fxFillHover = DeclarationShim.getDeclaration("-fx-fill", fxFillHoverValue, false);
@@ -627,7 +630,7 @@ public class CssMetaDataTest {
         assertTrue(actuals.isEmpty());
     }
 
-    @Ignore("JDK-8234142")
+    @Disabled("JDK-8234142")
     @Test
     public void testGetMatchingStylesWithInlineStyleOnRootAndLeaf() {
 
@@ -644,7 +647,7 @@ public class CssMetaDataTest {
         List<String> rootStyleClass = new ArrayList<>();
         rootStyleClass.add("root");
 
-        Selector root = SimpleSelectorShim.getSimpleSelector("*", rootStyleClass, null, null);
+        Selector root = new SimpleSelector("*", rootStyleClass, null, null);
 
         ParsedValue fxBaseValue = new CssParserShim().parseExpr("-fx-base", "red");
         Declaration fxBase = DeclarationShim.getDeclaration("-fx-base", fxBaseValue, false);
@@ -667,7 +670,7 @@ public class CssMetaDataTest {
         List<String> rectStyleClass = new ArrayList<>();
         rectStyleClass.add("rect");
 
-        Selector rect = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, null, null);
+        Selector rect = new SimpleSelector("*", rectStyleClass, null, null);
 
         ParsedValue fxFillValue = new CssParserShim().parseExpr("-fx-fill", "-fx-color");
         Declaration fxFill = DeclarationShim.getDeclaration("-fx-fill", fxFillValue, false);
@@ -685,7 +688,7 @@ public class CssMetaDataTest {
         List<String> pseudoclasses = new ArrayList<>();
         pseudoclasses.add("hover");
 
-        Selector rectHover = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, pseudoclasses, null);
+        Selector rectHover = new SimpleSelector("*", rectStyleClass, pseudoclasses, null);
 
         ParsedValueImpl<Color,Color> fxFillHoverValue = new ParsedValueImpl<>(Color.YELLOW, null);
         Declaration fxFillHover = DeclarationShim.getDeclaration("-fx-fill", fxFillHoverValue, false);
@@ -755,7 +758,7 @@ public class CssMetaDataTest {
         assertTrue(actuals.isEmpty());
     }
 
-    @Ignore("JDK-8234142")
+    @Disabled("JDK-8234142")
     @Test
     public void testGetMatchingStylesShouldNotReturnAncestorPropertyIfNotInherited() {
 
@@ -772,7 +775,7 @@ public class CssMetaDataTest {
         List<String> rootStyleClass = new ArrayList<>();
         rootStyleClass.add("root");
 
-        Selector root = SimpleSelectorShim.getSimpleSelector("*", rootStyleClass, null, null);
+        Selector root = new SimpleSelector("*", rootStyleClass, null, null);
 
         ParsedValue fxBaseValue = new CssParserShim().parseExpr("-fx-base", "red");
         Declaration fxBase = DeclarationShim.getDeclaration("-fx-base", fxBaseValue, false);
@@ -798,7 +801,7 @@ public class CssMetaDataTest {
         List<String> rectStyleClass = new ArrayList<>();
         rectStyleClass.add("rect");
 
-        Selector rect = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, null, null);
+        Selector rect = new SimpleSelector("*", rectStyleClass, null, null);
 
         ParsedValue fxFillValue = new CssParserShim().parseExpr("-fx-fill", "-fx-color");
         Declaration fxFill = DeclarationShim.getDeclaration("-fx-fill", fxFillValue, false);
@@ -816,7 +819,7 @@ public class CssMetaDataTest {
         List<String> pseudoclasses = new ArrayList<>();
         pseudoclasses.add("hover");
 
-        Selector rectHover = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, pseudoclasses, null);
+        Selector rectHover = new SimpleSelector("*", rectStyleClass, pseudoclasses, null);
 
         ParsedValueImpl<Color,Color> fxFillHoverValue = new ParsedValueImpl<>(Color.YELLOW, null);
         Declaration fxFillHover = DeclarationShim.getDeclaration("-fx-fill", fxFillHoverValue, false);
@@ -864,7 +867,7 @@ public class CssMetaDataTest {
         assertTrue(actuals.isEmpty());
     }
 
-    @Ignore("JDK-8234142")
+    @Disabled("JDK-8234142")
     @Test
     public void testGetMatchingStylesShouldNotReturnInlineAncestorPropertyIfNotInherited() {
 
@@ -883,7 +886,7 @@ public class CssMetaDataTest {
         //
         // .root { -fx-base: red; -fx-color: -fx-base; }
         //
-        Selector root = SimpleSelectorShim.getSimpleSelector("*", rootStyleClass, null, null);
+        Selector root = new SimpleSelector("*", rootStyleClass, null, null);
 
         ParsedValue fxBaseValue = new CssParserShim().parseExpr("-fx-base", "red");
         Declaration fxBase = DeclarationShim.getDeclaration("-fx-base", fxBaseValue, false);
@@ -906,7 +909,7 @@ public class CssMetaDataTest {
         //
         // .rect { -fx-fill: -fx-color; }
         //
-        Selector rect = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, null, null);
+        Selector rect = new SimpleSelector("*", rectStyleClass, null, null);
 
         ParsedValue fxFillValue = new CssParserShim().parseExpr("-fx-fill", "-fx-color");
         Declaration fxFill = DeclarationShim.getDeclaration("-fx-fill", fxFillValue, false);
@@ -924,7 +927,7 @@ public class CssMetaDataTest {
         List<String> pseudoclasses = new ArrayList<>();
         pseudoclasses.add("hover");
 
-        Selector rectHover = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, pseudoclasses, null);
+        Selector rectHover = new SimpleSelector("*", rectStyleClass, pseudoclasses, null);
 
         ParsedValueImpl<Color,Color> fxFillHoverValue = new ParsedValueImpl<>(Color.YELLOW, null);
         Declaration fxFillHover = DeclarationShim.getDeclaration("-fx-fill", fxFillHoverValue, false);
@@ -967,10 +970,10 @@ public class CssMetaDataTest {
         for (Style style : expecteds) {
             actuals.remove(style);
         }
-        assertTrue(actuals.toString(), actuals.isEmpty());
+        assertTrue(actuals.isEmpty(), actuals.toString());
     }
 
-    @Ignore("JDK-8234142")
+    @Disabled("JDK-8234142")
     @Test
     public void testGetMatchingStylesReturnsInheritedProperty() {
 
@@ -986,7 +989,7 @@ public class CssMetaDataTest {
         List<String> rootStyleClass = new ArrayList<>();
         rootStyleClass.add("root");
 
-        Selector root = SimpleSelectorShim.getSimpleSelector("*", rootStyleClass, null, null);
+        Selector root = new SimpleSelector("*", rootStyleClass, null, null);
 
         ParsedValue<Color,Color> fxFontShouldInheritValue = new CssParserShim().parseExpr("-fx-font", "12px system");
         Declaration fxFontShouldInherit = DeclarationShim.getDeclaration("-fx-font", fxFontShouldInheritValue, false);
@@ -1006,7 +1009,7 @@ public class CssMetaDataTest {
         List<String> textStyleClass = new ArrayList<>();
         textStyleClass.add("text");
 
-        Selector textSelector = SimpleSelectorShim.getSimpleSelector("*", textStyleClass, null, null);
+        Selector textSelector = new SimpleSelector("*", textStyleClass, null, null);
 
         ParsedValue fxFillValue = new CssParserShim().parseExpr("-fx-fill", "red");
         Declaration fxFill = DeclarationShim.getDeclaration("-fx-fill", fxFillValue, false);
@@ -1051,7 +1054,7 @@ public class CssMetaDataTest {
         assertTrue(actuals.isEmpty());
     }
 
-    @Ignore("JDK-8234142")
+    @Disabled("JDK-8234142")
     @Test
     public void testGetMatchingStylesReturnsSubProperty() {
 
@@ -1067,7 +1070,7 @@ public class CssMetaDataTest {
         List<String> rootStyleClass = new ArrayList<>();
         rootStyleClass.add("root");
 
-        Selector root = SimpleSelectorShim.getSimpleSelector("*", rootStyleClass, null, null);
+        Selector root = new SimpleSelector("*", rootStyleClass, null, null);
 
         ParsedValue<Color,Color> fxFontShouldInheritValue = new CssParserShim().parseExpr("-fx-font", "12px system");
         Declaration fxFontShouldInherit = DeclarationShim.getDeclaration("-fx-font", fxFontShouldInheritValue, false);
@@ -1087,7 +1090,7 @@ public class CssMetaDataTest {
         List<String> rectStyleClass = new ArrayList<>();
         rectStyleClass.add("text");
 
-        Selector textSelector = SimpleSelectorShim.getSimpleSelector("*", rectStyleClass, null, null);
+        Selector textSelector = new SimpleSelector("*", rectStyleClass, null, null);
 
         ParsedValue fxFillValue = new CssParserShim().parseExpr("-fx-fill", "red");
         Declaration fxFill = DeclarationShim.getDeclaration("-fx-fill", fxFillValue, false);
@@ -1148,7 +1151,7 @@ public class CssMetaDataTest {
                 f = new File(base.toURI());
             }
             //System.err.println(f.getPath());
-            assertTrue("" + f.getCanonicalPath() + " is not a directory", f.isDirectory());
+            assertTrue(f.isDirectory(), "" + f.getCanonicalPath() + " is not a directory");
             recursiveCheck(f, f.getPath().length() - 7);
         } catch (Exception ex) {
             ex.printStackTrace(System.err);
@@ -1173,7 +1176,7 @@ public class CssMetaDataTest {
 
                     what = someClass.getName() + " " + styleable.getProperty();
                     WritableValue writable = styleable.getStyleableProperty(node);
-                    assertNotNull(what, writable);
+                    assertNotNull(writable, what);
 
                     Object defaultValue = writable.getValue();
                     Object initialValue = styleable.getInitialValue((Node) someClass.getDeclaredConstructor().newInstance());
@@ -1184,12 +1187,12 @@ public class CssMetaDataTest {
                         assert(initialValue instanceof Number);
                         double d1 = ((Number)defaultValue).doubleValue();
                         double d2 = ((Number)initialValue).doubleValue();
-                        assertEquals(what, d1, d2, .001);
+                        assertEquals(d1, d2, .001, what);
 
                     } else if (defaultValue != null && defaultValue.getClass().isArray()) {
-                        assertTrue(what, Arrays.equals((Object[])defaultValue, (Object[])initialValue));
+                        assertTrue(Arrays.equals((Object[])defaultValue, (Object[])initialValue), what);
                     } else {
-                        assertEquals(what, defaultValue, initialValue);
+                        assertEquals(defaultValue, initialValue, what);
                     }
 
                 }
@@ -1238,7 +1241,7 @@ public class CssMetaDataTest {
         }
     }
 
-    @Ignore("JDK-8234143") // Tested CssMetaData#set method, which is deprecated.
+    @Disabled("JDK-8234143") // Tested CssMetaData#set method, which is deprecated.
     @Test
     public void testRT_21185() {
 
@@ -1278,7 +1281,7 @@ public class CssMetaDataTest {
 
     }
 
-    @Ignore("JDK-8234142")
+    @Disabled("JDK-8234142")
     @Test
     public void testRT_24606() {
 
