@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -47,12 +47,15 @@ import javafx.scene.SubScene;
 import javafx.scene.SubSceneShim;
 import javafx.scene.transform.NonInvertibleTransformException;
 import javafx.stage.Stage;
-import org.junit.Test;
 
-import static org.junit.Assert.*;
 import test.com.sun.javafx.scene.StubParallelCameraHelper;
 import test.com.sun.javafx.scene.StubPerspectiveCameraHelper;
 
+import org.junit.jupiter.api.Test;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
 public class CameraTest {
 
     static final GeneralTransform3D DEFAULT_PROJVIEW_TX;
