@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -34,8 +34,6 @@ import test.com.sun.javafx.pgstub.StubToolkit;
 import test.com.sun.javafx.test.PropertyInvalidationCounter;
 import com.sun.javafx.tk.Toolkit;
 import javafx.beans.InvalidationListener;
-import org.junit.Before;
-import org.junit.Test;
 
 import java.io.ByteArrayInputStream;
 import java.io.InputStream;
@@ -44,7 +42,14 @@ import java.util.Queue;
 import javafx.scene.image.Image;
 import javafx.scene.image.ImageShim;
 
-import static org.junit.Assert.*;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 public final class ImageTest {
     private final StubToolkit toolkit;
@@ -55,7 +60,7 @@ public final class ImageTest {
         imageLoaderFactory = toolkit.getImageLoaderFactory();
     }
 
-    @Before
+    @BeforeEach
     public void setUp() {
         imageLoaderFactory.reset();
     }
@@ -513,48 +518,66 @@ public final class ImageTest {
         verifyLoadedImage(image, 0, 0, false, false, 100, 200);
     }
 
-    @Test(expected=NullPointerException.class)
+    @Test
     public void createImageFromNullUrlTest() {
-        new Image((String) null);
+        assertThrows(NullPointerException.class, () -> {
+            new Image((String) null);
+        });
     }
 
-    @Test(expected=NullPointerException.class)
+    @Test
     public void createImageAsyncFromNullUrlTest() {
-        new Image(null, true);
+        assertThrows(NullPointerException.class, () -> {
+            new Image(null, true);
+        });
     }
 
-    @Test(expected=NullPointerException.class)
+    @Test
     public void createImageFromNullInputStreamTest() {
-        new Image((InputStream) null);
+        assertThrows(NullPointerException.class, () -> {
+            new Image((InputStream) null);
+        });
     }
 
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void createImageFromEmptyUrlTest() {
-        new Image("");
+        assertThrows(IllegalArgumentException.class, () -> {
+            new Image("");
+        });
     }
 
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void createImageAsyncFromEmptyUrlTest() {
-        new Image("", true);
+        assertThrows(IllegalArgumentException.class, () -> {
+            new Image("", true);
+        });
     }
 
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void createImageFromInvalidUrlTest() {
-        new Image(":");
+        assertThrows(IllegalArgumentException.class, () -> {
+            new Image(":");
+        });
     }
 
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void createImageAsyncFromInvalidUrlTest() {
-        new Image(":", true);
+        assertThrows(IllegalArgumentException.class, () -> {
+            new Image(":", true);
+        });
     }
 
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void createImageFromUnsupportedUrlTest() {
-        new Image("unsupported:image.png");
+        assertThrows(IllegalArgumentException.class, () -> {
+            new Image("unsupported:image.png");
+        });
     }
 
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void createImageAsyncFromUnsupportedUrlTest() {
-        new Image("unsupported:image.png", true);
+        assertThrows(IllegalArgumentException.class, () -> {
+            new Image("unsupported:image.png", true);
+        });
     }
 }
