@@ -311,7 +311,7 @@ combine (gunichar  a,
 
   index_b = COMPOSE_INDEX(b);
 
-  if (index_b >= COMPOSE_SECOND_SINGLE_START)
+  if (index_b >= COMPOSE_SECOND_SINGLE_START && index_b < COMPOSE_EITHER_START)
     {
       if (a == compose_second_single[index_b - COMPOSE_SECOND_SINGLE_START][0])
   {
@@ -334,6 +334,18 @@ combine (gunichar  a,
   }
     }
 
+  if (index_a >= COMPOSE_EITHER_START &&
+      index_b >= COMPOSE_EITHER_START)
+    {
+      gunichar res = compose_either_array[index_a - COMPOSE_EITHER_START][index_b - COMPOSE_EITHER_START];
+
+      if (res)
+        {
+          *result = res;
+          return TRUE;
+        }
+    }
+
   return FALSE;
 }
 
@@ -351,6 +363,8 @@ _g_utf8_normalize_wc (const gchar    *str,
   gboolean do_compose = (mode == G_NORMALIZE_NFC ||
        mode == G_NORMALIZE_NFKC);
 
+  /* Do a first pass to work out the length of the normalised string so we can
+   * allocate a buffer. */
   n_wc = 0;
   p = str;
   while ((max_len < 0 || p < str + max_len) && *p)
@@ -401,8 +415,10 @@ _g_utf8_normalize_wc (const gchar    *str,
       p = next;
     }
 
+  /* Allocate the buffer for the result. */
   wc_buffer = g_new (gunichar, n_wc + 1);
 
+  /* Do another pass to fill the buffer with the normalised string. */
   last_start = 0;
   n_wc = 0;
   p = str;
@@ -593,10 +609,10 @@ decompose_hangul_step (gunichar  ch,
  * decompositions. It does, however, include algorithmic
  * Hangul Jamo decomposition, as well as 'singleton'
  * decompositions which replace a character by a single
- * other character. In the case of singletons *@b will
+ * other character. In the case of singletons `*b` will
  * be set to zero.
  *
- * If @ch is not decomposable, *@a is set to @ch and *@b
+ * If @ch is not decomposable, `*a` is set to @ch and `*b`
  * is set to zero.
  *
  * Note that the way Unicode decomposition pairs are
