@@ -22,7 +22,7 @@
 
 #include "config.h"
 
-#include "gvarianttype.h"
+#include "gvarianttype-private.h"
 
 #include <glib/gtestutils.h>
 #include <glib/gstrfuncs.h>
@@ -36,6 +36,19 @@
  *
  * A type in the [type@GLib.Variant] type system.
  *
+ * [type@GLib.Variant] types are represented as strings, but have a strict
+ * syntax described below. All [type@GLib.VariantType]s passed to GLib must be
+ * valid, and they are typically expected to be static (i.e. not provided by
+ * user input) as they determine how binary [type@GLib.Variant] data is
+ * interpreted.
+ *
+ * To convert a static string to a [type@GLib.VariantType] in C, use the
+ * [func@GLib.VARIANT_TYPE] casting macro. When GLib is compiled with checks
+ * enabled, it will validate the type. To check if an arbitrary string is a
+ * valid [type@GLib.VariantType], use [func@GLib.VariantType.string_is_valid].
+ *
+ * ## GVariant Type System
+ *
  * This section introduces the [type@GLib.Variant] type system. It is based, in
  * large part, on the D-Bus type system, with two major changes and
  * some minor lifting of restrictions. The
@@ -276,10 +289,11 @@ variant_type_string_scan_internal (const gchar  *string,
 /**
  * g_variant_type_string_scan:
  * @string: a pointer to any string
- * @limit: (nullable): the end of @string, or %NULL
- * @endptr: (out) (optional): location to store the end pointer, or %NULL
+ * @limit: (nullable): the end of @string
+ * @endptr: (out) (optional): location to store the end pointer
  *
  * Scan for a single complete and valid GVariant type string in @string.
+ *
  * The memory pointed to by @limit (or bytes beyond it) is never
  * accessed.
  *
@@ -291,10 +305,9 @@ variant_type_string_scan_internal (const gchar  *string,
  * string does not end before @limit then %FALSE is returned.
  *
  * For the simple case of checking if a string is a valid type string,
- * see g_variant_type_string_is_valid().
- *
- * Returns: %TRUE if a valid type string was found
+ * see [func@GLib.VariantType.string_is_valid].
  *
+ * Returns: true if a valid type string was found
  * Since: 2.24
  **/
 gboolean
@@ -314,9 +327,9 @@ g_variant_type_string_scan (const gchar  *string,
  * return depth 1, and a container type will return a greater value. The depth
  * of a tuple is 1 plus the depth of its deepest child type.
  *
- * If @type_string is not a valid #GVariant type string, 0 will be returned.
+ * If @type_string is not a valid [type@GLib.Variant] type string, `0` will be returned.
  *
- * Returns: depth of @type_string, or 0 on error
+ * Returns: depth of @type_string, or `0` on error
  * Since: 2.60
  */
 gsize
@@ -339,12 +352,13 @@ g_variant_type_string_get_depth_ (const gchar *type_string)
  * g_variant_type_string_is_valid:
  * @type_string: a pointer to any string
  *
- * Checks if @type_string is a valid GVariant type string.  This call is
- * equivalent to calling g_variant_type_string_scan() and confirming
- * that the following character is a nul terminator.
+ * Checks if @type_string is a valid
+ * [GVariant type string](./struct.VariantType.html#gvariant-type-strings).
  *
- * Returns: %TRUE if @type_string is exactly one valid type string
+ * This call is equivalent to calling [func@GLib.VariantType.string_scan] and
+ * confirming that the following character is a nul terminator.
  *
+ * Returns: true if @type_string is exactly one valid type string
  * Since 2.24
  **/
 gboolean
@@ -362,13 +376,13 @@ g_variant_type_string_is_valid (const gchar *type_string)
 
 /**
  * g_variant_type_free:
- * @type: (nullable): a #GVariantType, or %NULL
+ * @type: (nullable): type to free
  *
- * Frees a #GVariantType that was allocated with
- * g_variant_type_copy(), g_variant_type_new() or one of the container
- * type constructor functions.
+ * Frees a [type@GLib.VariantType] that was allocated with
+ * [method@GLib.VariantType.copy], [ctor@GLib.VariantType.new] or one of the
+ * container type constructor functions.
  *
- * In the case that @type is %NULL, this function does nothing.
+ * In the case that @type is `NULL`, this function does nothing.
  *
  * Since 2.24
  **/
@@ -382,13 +396,14 @@ g_variant_type_free (GVariantType *type)
 
 /**
  * g_variant_type_copy:
- * @type: a #GVariantType
+ * @type: (not nullable): type to copy
  *
- * Makes a copy of a #GVariantType.  It is appropriate to call
- * g_variant_type_free() on the return value.  @type may not be %NULL.
+ * Makes a copy of a [type@GLib.VariantType].
  *
- * Returns: (transfer full): a new #GVariantType
+ * It is appropriate to call [method@GLib.VariantType.free] on the return value.
+ * @type may not be `NULL`.
  *
+ * Returns: (transfer full): a new [type@GLib.VariantType]
  * Since 2.24
  **/
 GVariantType *
@@ -414,17 +429,17 @@ g_variant_type_copy (const GVariantType *type)
 
 /**
  * g_variant_type_new:
- * @type_string: a valid GVariant type string
+ * @type_string: a valid [GVariant type string](./struct.VariantType.html#gvariant-type-strings)
  *
- * Creates a new #GVariantType corresponding to the type string given
- * by @type_string.  It is appropriate to call g_variant_type_free() on
- * the return value.
+ * Creates a new [type@GLib.VariantType] corresponding to the type string given
+ * by @type_string.
+ *
+ * It is appropriate to call [method@GLib.VariantType.free] on the return value.
  *
  * It is a programmer error to call this function with an invalid type
- * string.  Use g_variant_type_string_is_valid() if you are unsure.
- *
- * Returns: (transfer full): a new #GVariantType
+ * string.  Use [func@GLib.VariantType.string_is_valid] if you are unsure.
  *
+ * Returns: (transfer full): a new [type@GLib.VariantType]
  * Since: 2.24
  */
 GVariantType *
@@ -437,14 +452,14 @@ g_variant_type_new (const gchar *type_string)
 
 /**
  * g_variant_type_get_string_length:
- * @type: a #GVariantType
+ * @type: type to measure
  *
- * Returns the length of the type string corresponding to the given
- * @type.  This function must be used to determine the valid extent of
- * the memory region returned by g_variant_type_peek_string().
+ * Returns the length of the type string corresponding to the given @type.
+ *
+ * This function must be used to determine the valid extent of
+ * the memory region returned by [method@GLib.VariantType.peek_string].
  *
  * Returns: the length of the corresponding type string
- *
  * Since 2.24
  **/
 gsize
@@ -480,16 +495,16 @@ g_variant_type_get_string_length (const GVariantType *type)
 */
 /**
  * g_variant_type_peek_string: (skip)
- * @type: a #GVariantType
+ * @type: type to peek at
  *
- * Returns the type string corresponding to the given @type.  The
- * result is not nul-terminated; in order to determine its length you
- * must call g_variant_type_get_string_length().
+ * Returns the type string corresponding to the given @type.
  *
- * To get a nul-terminated string, see g_variant_type_dup_string().
+ * The result is not nul-terminated; in order to determine its length you
+ * must call [method@GLib.VariantType.get_string_length].
+ *
+ * To get a nul-terminated string, see [method@GLib.VariantType.dup_string].
  *
  * Returns: the corresponding type string (not nul-terminated)
- *
  * Since 2.24
  **/
 const gchar *
@@ -502,14 +517,14 @@ g_variant_type_peek_string (const GVariantType *type)
 
 /**
  * g_variant_type_dup_string:
- * @type: a #GVariantType
+ * @type: type to copy
  *
- * Returns a newly-allocated copy of the type string corresponding to
- * @type.  The returned string is nul-terminated.  It is appropriate to
- * call g_free() on the return value.
+ * Returns a newly-allocated copy of the type string corresponding to @type.
+ *
+ * The returned string is nul-terminated.  It is appropriate to call
+ * [func@GLib.free] on the return value.
  *
  * Returns: (transfer full): the corresponding type string
- *
  * Since 2.24
  **/
 gchar *
@@ -523,21 +538,20 @@ g_variant_type_dup_string (const GVariantType *type)
 
 /**
  * g_variant_type_is_definite:
- * @type: a #GVariantType
+ * @type: type to check
  *
  * Determines if the given @type is definite (ie: not indefinite).
  *
  * A type is definite if its type string does not contain any indefinite
- * type characters ('*', '?', or 'r').
+ * type characters (`*`, `?`, or `r`).
  *
- * A #GVariant instance may not have an indefinite type, so calling
- * this function on the result of g_variant_get_type() will always
- * result in %TRUE being returned.  Calling this function on an
- * indefinite type like %G_VARIANT_TYPE_ARRAY, however, will result in
- * %FALSE being returned.
- *
- * Returns: %TRUE if @type is definite
+ * A [type@GLib.Variant] instance may not have an indefinite type, so calling
+ * this function on the result of [method@GLib.Variant.get_type] will always
+ * result in true being returned.  Calling this function on an
+ * indefinite type like `G_VARIANT_TYPE_ARRAY`, however, will result in
+ * `FALSE` being returned.
  *
+ * Returns: true if @type is definite
  * Since 2.24
  **/
 gboolean
@@ -563,19 +577,18 @@ g_variant_type_is_definite (const GVariantType *type)
 
 /**
  * g_variant_type_is_container:
- * @type: a #GVariantType
+ * @type: type to check
  *
  * Determines if the given @type is a container type.
  *
  * Container types are any array, maybe, tuple, or dictionary
  * entry types plus the variant type.
  *
- * This function returns %TRUE for any indefinite type for which every
- * definite subtype is a container -- %G_VARIANT_TYPE_ARRAY, for
+ * This function returns true for any indefinite type for which every
+ * definite subtype is a container — `G_VARIANT_TYPE_ARRAY`, for
  * example.
  *
- * Returns: %TRUE if @type is a container type
- *
+ * Returns: true if @type is a container type
  * Since 2.24
  **/
 gboolean
@@ -603,7 +616,7 @@ g_variant_type_is_container (const GVariantType *type)
 
 /**
  * g_variant_type_is_basic:
- * @type: a #GVariantType
+ * @type: type to check
  *
  * Determines if the given @type is a basic type.
  *
@@ -612,11 +625,10 @@ g_variant_type_is_container (const GVariantType *type)
  *
  * Only a basic type may be used as the key of a dictionary entry.
  *
- * This function returns %FALSE for all indefinite types except
- * %G_VARIANT_TYPE_BASIC.
- *
- * Returns: %TRUE if @type is a basic type
+ * This function returns `FALSE` for all indefinite types except
+ * `G_VARIANT_TYPE_BASIC`.
  *
+ * Returns: true if @type is a basic type
  * Since 2.24
  **/
 gboolean
@@ -652,17 +664,17 @@ g_variant_type_is_basic (const GVariantType *type)
 
 /**
  * g_variant_type_is_maybe:
- * @type: a #GVariantType
+ * @type: type to check
  *
- * Determines if the given @type is a maybe type.  This is true if the
- * type string for @type starts with an 'm'.
+ * Determines if the given @type is a ‘maybe’ type.
  *
- * This function returns %TRUE for any indefinite type for which every
- * definite subtype is a maybe type -- %G_VARIANT_TYPE_MAYBE, for
+ * This is true if the type string for @type starts with an `m`.
+ *
+ * This function returns true for any indefinite type for which every
+ * definite subtype is a ‘maybe’ type — `G_VARIANT_TYPE_MAYBE`, for
  * example.
  *
- * Returns: %TRUE if @type is a maybe type
- *
+ * Returns: true if @type is a ‘maybe’ type
  * Since 2.24
  **/
 gboolean
@@ -675,17 +687,17 @@ g_variant_type_is_maybe (const GVariantType *type)
 
 /**
  * g_variant_type_is_array:
- * @type: a #GVariantType
+ * @type: type to check
  *
- * Determines if the given @type is an array type.  This is true if the
- * type string for @type starts with an 'a'.
+ * Determines if the given @type is an array type.
  *
- * This function returns %TRUE for any indefinite type for which every
- * definite subtype is an array type -- %G_VARIANT_TYPE_ARRAY, for
+ * This is true if the type string for @type starts with an `a`.
+ *
+ * This function returns true for any indefinite type for which every
+ * definite subtype is an array type — `G_VARIANT_TYPE_ARRAY`, for
  * example.
  *
- * Returns: %TRUE if @type is an array type
- *
+ * Returns: true if @type is an array type
  * Since 2.24
  **/
 gboolean
@@ -698,18 +710,18 @@ g_variant_type_is_array (const GVariantType *type)
 
 /**
  * g_variant_type_is_tuple:
- * @type: a #GVariantType
+ * @type: type to check
  *
- * Determines if the given @type is a tuple type.  This is true if the
- * type string for @type starts with a '(' or if @type is
- * %G_VARIANT_TYPE_TUPLE.
+ * Determines if the given @type is a tuple type.
  *
- * This function returns %TRUE for any indefinite type for which every
- * definite subtype is a tuple type -- %G_VARIANT_TYPE_TUPLE, for
+ * This is true if the type string for @type starts with a `(` or if @type is
+ * `G_VARIANT_TYPE_TUPLE`.
+ *
+ * This function returns true for any indefinite type for which every
+ * definite subtype is a tuple type — `G_VARIANT_TYPE_TUPLE`, for
  * example.
  *
- * Returns: %TRUE if @type is a tuple type
- *
+ * Returns: true if @type is a tuple type
  * Since 2.24
  **/
 gboolean
@@ -725,17 +737,17 @@ g_variant_type_is_tuple (const GVariantType *type)
 
 /**
  * g_variant_type_is_dict_entry:
- * @type: a #GVariantType
+ * @type: type to check
  *
- * Determines if the given @type is a dictionary entry type.  This is
- * true if the type string for @type starts with a '{'.
+ * Determines if the given @type is a dictionary entry type.
  *
- * This function returns %TRUE for any indefinite type for which every
- * definite subtype is a dictionary entry type --
- * %G_VARIANT_TYPE_DICT_ENTRY, for example.
+ * This is true if the type string for @type starts with a `{`.
  *
- * Returns: %TRUE if @type is a dictionary entry type
+ * This function returns true for any indefinite type for which every
+ * definite subtype is a dictionary entry type —
+ * `G_VARIANT_TYPE_DICT_ENTRY`, for example.
  *
+ * Returns: true if @type is a dictionary entry type
  * Since 2.24
  **/
 gboolean
@@ -748,12 +760,11 @@ g_variant_type_is_dict_entry (const GVariantType *type)
 
 /**
  * g_variant_type_is_variant:
- * @type: a #GVariantType
+ * @type: type to check
  *
  * Determines if the given @type is the variant type.
  *
- * Returns: %TRUE if @type is the variant type
- *
+ * Returns: true if @type is the variant type
  * Since 2.24
  **/
 gboolean
@@ -766,95 +777,66 @@ g_variant_type_is_variant (const GVariantType *type)
 
 /**
  * g_variant_type_hash:
- * @type: (type GVariantType): a #GVariantType
+ * @type: (type GVariantType): type to hash
  *
  * Hashes @type.
  *
- * The argument type of @type is only #gconstpointer to allow use with
- * #GHashTable without function pointer casting.  A valid
- * #GVariantType must be provided.
+ * The argument type of @type is only `gconstpointer` to allow use with
+ * [type@GLib.HashTable] without function pointer casting.  A valid
+ * [type@GLib.VariantType] must be provided.
  *
  * Returns: the hash value
- *
  * Since 2.24
  **/
 guint
 g_variant_type_hash (gconstpointer type)
 {
-  const gchar *type_string;
-  guint value = 0;
-  gsize length;
-  gsize i;
-
   g_return_val_if_fail (g_variant_type_check (type), 0);
 
-  type_string = g_variant_type_peek_string (type);
-  length = g_variant_type_get_string_length (type);
-
-  for (i = 0; i < length; i++)
-    value = (value << 5) - value + type_string[i];
-
-  return value;
+  return _g_variant_type_hash (type);
 }
 
 /**
  * g_variant_type_equal:
- * @type1: (type GVariantType): a #GVariantType
- * @type2: (type GVariantType): a #GVariantType
+ * @type1: (type GVariantType): type to compare
+ * @type2: (type GVariantType): another type to compare
  *
  * Compares @type1 and @type2 for equality.
  *
- * Only returns %TRUE if the types are exactly equal.  Even if one type
- * is an indefinite type and the other is a subtype of it, %FALSE will
+ * Only returns true if the types are exactly equal.  Even if one type
+ * is an indefinite type and the other is a subtype of it, false will
  * be returned if they are not exactly equal.  If you want to check for
- * subtypes, use g_variant_type_is_subtype_of().
+ * subtypes, use [method@GLib.VariantType.is_subtype_of].
  *
- * The argument types of @type1 and @type2 are only #gconstpointer to
- * allow use with #GHashTable without function pointer casting.  For
- * both arguments, a valid #GVariantType must be provided.
- *
- * Returns: %TRUE if @type1 and @type2 are exactly equal
+ * The argument types of @type1 and @type2 are only `gconstpointer` to
+ * allow use with [type@GLib.HashTable] without function pointer casting.  For
+ * both arguments, a valid [type@GLib.VariantType] must be provided.
  *
+ * Returns: true if @type1 and @type2 are exactly equal
  * Since 2.24
  **/
 gboolean
 g_variant_type_equal (gconstpointer type1,
                       gconstpointer type2)
 {
-  const gchar *string1, *string2;
-  gsize size1, size2;
-
   g_return_val_if_fail (g_variant_type_check (type1), FALSE);
   g_return_val_if_fail (g_variant_type_check (type2), FALSE);
 
-  if (type1 == type2)
-    return TRUE;
-
-  size1 = g_variant_type_get_string_length (type1);
-  size2 = g_variant_type_get_string_length (type2);
-
-  if (size1 != size2)
-    return FALSE;
-
-  string1 = g_variant_type_peek_string (type1);
-  string2 = g_variant_type_peek_string (type2);
-
-  return memcmp (string1, string2, size1) == 0;
+  return _g_variant_type_equal (type1, type2);
 }
 
 /**
  * g_variant_type_is_subtype_of:
- * @type: a #GVariantType
- * @supertype: a #GVariantType
+ * @type: type to check
+ * @supertype: type of potential supertype
  *
  * Checks if @type is a subtype of @supertype.
  *
- * This function returns %TRUE if @type is a subtype of @supertype.  All
+ * This function returns true if @type is a subtype of @supertype.  All
  * types are considered to be subtypes of themselves.  Aside from that,
  * only indefinite types can have subtypes.
  *
- * Returns: %TRUE if @type is a subtype of @supertype
- *
+ * Returns: true if @type is a subtype of @supertype
  * Since 2.24
  **/
 gboolean
@@ -871,6 +853,24 @@ g_variant_type_is_subtype_of (const GVariantType *type,
   supertype_string = g_variant_type_peek_string (supertype);
   type_string = g_variant_type_peek_string (type);
 
+  /* fast path for the basic determinate types */
+  if (type_string[0] == supertype_string[0])
+    {
+      switch (type_string[0])
+        {
+        case 'b': case 'y':
+        case 'n': case 'q':
+        case 'i': case 'h': case 'u':
+        case 't': case 'x':
+        case 's': case 'o': case 'g':
+        case 'd':
+          return TRUE;
+
+        default:
+          break;
+        }
+    }
+
   supertype_end = supertype_string +
                   g_variant_type_get_string_length (supertype);
 
@@ -919,14 +919,13 @@ g_variant_type_is_subtype_of (const GVariantType *type,
 
 /**
  * g_variant_type_element:
- * @type: an array or maybe #GVariantType
+ * @type: an array or ‘maybe’ type
  *
- * Determines the element type of an array or maybe type.
+ * Determines the element type of an array or ‘maybe’ type.
  *
- * This function may only be used with array or maybe types.
+ * This function may only be used with array or ‘maybe’ types.
  *
  * Returns: (transfer none): the element type of @type
- *
  * Since 2.24
  **/
 const GVariantType *
@@ -945,25 +944,25 @@ g_variant_type_element (const GVariantType *type)
 
 /**
  * g_variant_type_first:
- * @type: a tuple or dictionary entry #GVariantType
+ * @type: a tuple or dictionary entry type
  *
  * Determines the first item type of a tuple or dictionary entry
  * type.
  *
  * This function may only be used with tuple or dictionary entry types,
  * but must not be used with the generic tuple type
- * %G_VARIANT_TYPE_TUPLE.
+ * `G_VARIANT_TYPE_TUPLE`.
  *
  * In the case of a dictionary entry type, this returns the type of
  * the key.
  *
- * %NULL is returned in case of @type being %G_VARIANT_TYPE_UNIT.
+ * `NULL` is returned in case of @type being `G_VARIANT_TYPE_UNIT`.
  *
- * This call, together with g_variant_type_next() provides an iterator
+ * This call, together with [method@GLib.VariantType.next] provides an iterator
  * interface over tuple and dictionary entry types.
  *
- * Returns: (transfer none): the first item type of @type, or %NULL
- *
+ * Returns: (transfer none) (nullable): the first item type of @type, or `NULL`
+ *   if the type has no item types
  * Since 2.24
  **/
 const GVariantType *
@@ -984,22 +983,22 @@ g_variant_type_first (const GVariantType *type)
 
 /**
  * g_variant_type_next:
- * @type: a #GVariantType from a previous call
+ * @type: a type from a previous call
  *
  * Determines the next item type of a tuple or dictionary entry
  * type.
  *
  * @type must be the result of a previous call to
- * g_variant_type_first() or g_variant_type_next().
+ * [method@GLib.VariantType.first] or [method@GLib.VariantType.next].
  *
  * If called on the key type of a dictionary entry then this call
  * returns the value type.  If called on the value type of a dictionary
- * entry then this call returns %NULL.
+ * entry then this call returns `NULL`.
  *
- * For tuples, %NULL is returned when @type is the last item in a tuple.
- *
- * Returns: (transfer none): the next #GVariantType after @type, or %NULL
+ * For tuples, `NULL` is returned when @type is the last item in the tuple.
  *
+ * Returns: (transfer none) (nullable): the next type after @type, or `NULL` if
+ *   there are no further types
  * Since 2.24
  **/
 const GVariantType *
@@ -1020,20 +1019,19 @@ g_variant_type_next (const GVariantType *type)
 
 /**
  * g_variant_type_n_items:
- * @type: a tuple or dictionary entry #GVariantType
+ * @type: a tuple or dictionary entry type
  *
  * Determines the number of items contained in a tuple or
  * dictionary entry type.
  *
  * This function may only be used with tuple or dictionary entry types,
  * but must not be used with the generic tuple type
- * %G_VARIANT_TYPE_TUPLE.
+ * `G_VARIANT_TYPE_TUPLE`.
  *
  * In the case of a dictionary entry type, this function will always
- * return 2.
+ * return `2`.
  *
  * Returns: the number of items in @type
- *
  * Since 2.24
  **/
 gsize
@@ -1053,16 +1051,15 @@ g_variant_type_n_items (const GVariantType *type)
 
 /**
  * g_variant_type_key:
- * @type: a dictionary entry #GVariantType
+ * @type: a dictionary entry type
  *
  * Determines the key type of a dictionary entry type.
  *
  * This function may only be used with a dictionary entry type.  Other
  * than the additional restriction, this call is equivalent to
- * g_variant_type_first().
+ * [method@GLib.VariantType.first].
  *
  * Returns: (transfer none): the key type of the dictionary entry
- *
  * Since 2.24
  **/
 const GVariantType *
@@ -1080,14 +1077,13 @@ g_variant_type_key (const GVariantType *type)
 
 /**
  * g_variant_type_value:
- * @type: a dictionary entry #GVariantType
+ * @type: a dictionary entry type
  *
  * Determines the value type of a dictionary entry type.
  *
  * This function may only be used with a dictionary entry type.
  *
  * Returns: (transfer none): the value type of the dictionary entry
- *
  * Since 2.24
  **/
 const GVariantType *
@@ -1109,18 +1105,17 @@ g_variant_type_value (const GVariantType *type)
 
 /**
  * g_variant_type_new_tuple:
- * @items: (array length=length): an array of #GVariantTypes, one for each item
- * @length: the length of @items, or -1
+ * @items: (array length=length): an array of types, one for each item
+ * @length: the length of @items, or `-1`
  *
  * Constructs a new tuple type, from @items.
  *
- * @length is the number of items in @items, or -1 to indicate that
- * @items is %NULL-terminated.
+ * @length is the number of items in @items, or `-1` to indicate that
+ * @items is `NULL`-terminated.
  *
- * It is appropriate to call g_variant_type_free() on the return value.
- *
- * Returns: (transfer full): a new tuple #GVariantType
+ * It is appropriate to call [method@GLib.VariantType.free] on the return value.
  *
+ * Returns: (transfer full): a new tuple type
  * Since 2.24
  **/
 static GVariantType *
@@ -1195,15 +1190,14 @@ g_variant_type_new_tuple (const GVariantType * const *items,
 
 /**
  * g_variant_type_new_array: (constructor)
- * @element: a #GVariantType
+ * @element: an element type
  *
  * Constructs the type corresponding to an array of elements of the
  * type @type.
  *
- * It is appropriate to call g_variant_type_free() on the return value.
- *
- * Returns: (transfer full): a new array #GVariantType
+ * It is appropriate to call [method@GLib.VariantType.first] on the return value.
  *
+ * Returns: (transfer full): a new array type
  * Since 2.24
  **/
 GVariantType *
@@ -1229,15 +1223,14 @@ g_variant_type_new_array (const GVariantType *element)
 
 /**
  * g_variant_type_new_maybe: (constructor)
- * @element: a #GVariantType
+ * @element: an element type
  *
- * Constructs the type corresponding to a maybe instance containing
- * type @type or Nothing.
+ * Constructs the type corresponding to a ‘maybe’ instance containing
+ * type @type or `Nothing`.
  *
- * It is appropriate to call g_variant_type_free() on the return value.
- *
- * Returns: (transfer full): a new maybe #GVariantType
+ * It is appropriate to call [method@GLib.VariantType.free] on the return value.
  *
+ * Returns: (transfer full): a new ‘maybe’ type
  * Since 2.24
  **/
 GVariantType *
@@ -1263,16 +1256,15 @@ g_variant_type_new_maybe (const GVariantType *element)
 
 /**
  * g_variant_type_new_dict_entry: (constructor)
- * @key: a basic #GVariantType
- * @value: a #GVariantType
+ * @key: a basic type to use for the key
+ * @value: a type to use for the value
  *
  * Constructs the type corresponding to a dictionary entry with a key
  * of type @key and a value of type @value.
  *
- * It is appropriate to call g_variant_type_free() on the return value.
- *
- * Returns: (transfer full): a new dictionary entry #GVariantType
+ * It is appropriate to call [method@GLib.VariantType.free] on the return value.
  *
+ * Returns: (transfer full): a new dictionary entry type
  * Since 2.24
  **/
 GVariantType *
