@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -327,7 +327,9 @@ JNIEXPORT void JNICALL Java_com_sun_media_jfxmediaimpl_platform_osx_OSXMediaPlay
     if ([scheme caseInsensitiveCompare:@"jar"] == NSOrderedSame ||
         [scheme caseInsensitiveCompare:@"jrt"] == NSOrderedSame) {
         CJavaInputStreamCallbacks *callbacks = new (nothrow) CJavaInputStreamCallbacks();
-        if (callbacks == NULL) {
+        jobject jConnectionHolder = CLocator::CreateConnectionHolder(env, jLocator);
+        if (callbacks == NULL || jConnectionHolder == NULL) {
+            if (callbacks) delete callbacks;
             [mediaURL release];
             LOGGER_WARNMSG("OSXMediaPlayer: Unable to create CJavaInputStreamCallbacks\n");
             ThrowJavaException(env, "com/sun/media/jfxmedia/MediaException",
@@ -335,7 +337,7 @@ JNIEXPORT void JNICALL Java_com_sun_media_jfxmediaimpl_platform_osx_OSXMediaPlay
             return;
         }
 
-        if (!callbacks->Init(env, jLocator)) {
+        if (!callbacks->Init(env, jConnectionHolder)) {
             [mediaURL release];
             delete callbacks;
             LOGGER_WARNMSG("OSXMediaPlayer: callbacks->Init() failed\n");
