@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -27,8 +27,6 @@ package javafx.embed.swt;
 
 import java.nio.ByteBuffer;
 import java.nio.IntBuffer;
-import java.security.AccessController;
-import java.security.PrivilegedExceptionAction;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.ImageData;
@@ -191,19 +189,21 @@ public class SWTFXUtils {
         return msbFirst;
     }
 
-    @SuppressWarnings("removal")
     private static int readValue(final String name) throws Exception {
         final Class<?> clazz = ImageData.class;
-        return AccessController.doPrivileged(
-                (PrivilegedExceptionAction<Integer>) () -> {
-                    Field field = clazz.getDeclaredField(name);
-                    field.setAccessible(true);
-                    return field.getInt(clazz);
-                });
+        Field field = clazz.getDeclaredField(name);
+        field.setAccessible(true);
+        return field.getInt(clazz);
+    }
+
+    private static Method getMethod(Class<?> clazz, String name, Class<?> ... argClasses) throws Exception {
+        Method method = clazz.getDeclaredMethod(name, argClasses);
+        method.setAccessible(true);
+        return method;
     }
 
     private static Method blitDirect;
-    @SuppressWarnings("removal")
+
     private static void blit(int op,
             byte[] srcData, int srcDepth, int srcStride, int srcOrder,
             int srcX, int srcY, int srcWidth, int srcHeight,
@@ -225,13 +225,7 @@ public class SWTFXUtils {
                     BA, I, I, I,
                     I, I, I, I,
                     I, I, I, B, B};
-            blitDirect = AccessController.doPrivileged(
-                    (PrivilegedExceptionAction<Method>) () -> {
-                        Method method = clazz.
-                            getDeclaredMethod("blit", argClasses);
-                        method.setAccessible(true);
-                        return method;
-                    });
+            blitDirect = getMethod(clazz, "blit", argClasses);
         }
         if (blitDirect != null) {
             blitDirect.invoke(clazz, op,
@@ -247,7 +241,7 @@ public class SWTFXUtils {
     }
 
     private static Method blitPalette;
-    @SuppressWarnings("removal")
+
     private static void blit(int op,
         byte[] srcData, int srcDepth, int srcStride, int srcOrder,
         int srcX, int srcY, int srcWidth, int srcHeight,
@@ -269,13 +263,7 @@ public class SWTFXUtils {
                     BA, I, I, I,
                     I, I, I, I,
                     I, I, I, B, B};
-            blitPalette = AccessController.doPrivileged(
-                    (PrivilegedExceptionAction<Method>) () -> {
-                        Method method = clazz.
-                            getDeclaredMethod("blit", argClasses);
-                        method.setAccessible(true);
-                        return method;
-                    });
+            blitPalette = getMethod(clazz, "blit", argClasses);
         }
         if (blitPalette != null) {
             blitPalette.invoke(clazz, op,
@@ -291,16 +279,11 @@ public class SWTFXUtils {
     }
 
     private static Method getByteOrderMethod;
-    @SuppressWarnings("removal")
+
     private static int getByteOrder(ImageData image) throws Exception {
         final Class<?> clazz = ImageData.class;
         if (getByteOrderMethod != null) {
-            getByteOrderMethod = AccessController.doPrivileged(
-                    (PrivilegedExceptionAction<Method>) () -> {
-                        Method method = clazz.getDeclaredMethod("getByteOrder");
-                        method.setAccessible(true);
-                        return method;
-                    });
+            getByteOrderMethod = getMethod(clazz, "getByteOrder");
         }
         if (getByteOrderMethod != null) {
             return (Integer)getByteOrderMethod.invoke(image);
