@@ -12,7 +12,7 @@
 
 #include "unicode/reldatefmt.h"
 
-#if !UCONFIG_NO_FORMATTING && !UCONFIG_NO_BREAK_ITERATION
+#if !UCONFIG_NO_FORMATTING
 
 #include <cmath>
 #include <functional>
@@ -761,6 +761,7 @@ RelativeDateTimeFormatter::RelativeDateTimeFormatter(UErrorCode& status) :
         fStyle(UDAT_STYLE_LONG),
         fContext(UDISPCTX_CAPITALIZATION_NONE),
         fOptBreakIterator(nullptr) {
+    (void)fOptBreakIterator; // suppress unused field warning
     init(nullptr, nullptr, status);
 }
 
@@ -804,16 +805,25 @@ RelativeDateTimeFormatter::RelativeDateTimeFormatter(
     if (U_FAILURE(status)) {
         return;
     }
+    if (styl < 0 || UDAT_STYLE_COUNT <= styl) {
+        status = U_ILLEGAL_ARGUMENT_ERROR;
+        return;
+    }
     if ((capitalizationContext >> 8) != UDISPCTX_TYPE_CAPITALIZATION) {
         status = U_ILLEGAL_ARGUMENT_ERROR;
         return;
     }
     if (capitalizationContext == UDISPCTX_CAPITALIZATION_FOR_BEGINNING_OF_SENTENCE) {
+#if !UCONFIG_NO_BREAK_ITERATION
         BreakIterator *bi = BreakIterator::createSentenceInstance(locale, status);
         if (U_FAILURE(status)) {
             return;
         }
         init(nfToAdopt, bi, status);
+#else
+        status = U_UNSUPPORTED_ERROR;
+        return;
+#endif // !UCONFIG_NO_BREAK_ITERATION
     } else {
         init(nfToAdopt, nullptr, status);
     }
@@ -832,9 +842,11 @@ RelativeDateTimeFormatter::RelativeDateTimeFormatter(
     fCache->addRef();
     fNumberFormat->addRef();
     fPluralRules->addRef();
+#if !UCONFIG_NO_BREAK_ITERATION
     if (fOptBreakIterator != nullptr) {
       fOptBreakIterator->addRef();
     }
+#endif // !UCONFIG_NO_BREAK_ITERATION
 }
 
 RelativeDateTimeFormatter& RelativeDateTimeFormatter::operator=(
@@ -843,7 +855,9 @@ RelativeDateTimeFormatter& RelativeDateTimeFormatter::operator=(
         SharedObject::copyPtr(other.fCache, fCache);
         SharedObject::copyPtr(other.fNumberFormat, fNumberFormat);
         SharedObject::copyPtr(other.fPluralRules, fPluralRules);
+#if !UCONFIG_NO_BREAK_ITERATION
         SharedObject::copyPtr(other.fOptBreakIterator, fOptBreakIterator);
+#endif // !UCONFIG_NO_BREAK_ITERATION
         fStyle = other.fStyle;
         fContext = other.fContext;
         fLocale = other.fLocale;
@@ -861,9 +875,11 @@ RelativeDateTimeFormatter::~RelativeDateTimeFormatter() {
     if (fPluralRules != nullptr) {
         fPluralRules->removeRef();
     }
+#if !UCONFIG_NO_BREAK_ITERATION
     if (fOptBreakIterator != nullptr) {
         fOptBreakIterator->removeRef();
     }
+#endif // !UCONFIG_NO_BREAK_ITERATION
 }
 
 const NumberFormat& RelativeDateTimeFormatter::getNumberFormat() const {
@@ -1015,6 +1031,10 @@ void RelativeDateTimeFormatter::formatNumericImpl(
     if (U_FAILURE(status)) {
         return;
     }
+    if (unit < 0 || UDAT_REL_UNIT_COUNT <= unit) {
+        status = U_ILLEGAL_ARGUMENT_ERROR;
+        return;
+    }
     UDateDirection direction = UDAT_DIRECTION_NEXT;
     if (std::signbit(offset)) { // needed to handle -0.0
         direction = UDAT_DIRECTION_LAST;
@@ -1083,7 +1103,9 @@ void RelativeDateTimeFormatter::formatAbsoluteImpl(
     if (U_FAILURE(status)) {
         return;
     }
-    if (unit == UDAT_ABSOLUTE_NOW && direction != UDAT_DIRECTION_PLAIN) {
+    if ((unit < 0 || UDAT_ABSOLUTE_UNIT_COUNT <= unit) ||
+        (direction < 0 || UDAT_DIRECTION_COUNT <= direction) ||
+        (unit == UDAT_ABSOLUTE_NOW && direction != UDAT_DIRECTION_PLAIN)) {
         status = U_ILLEGAL_ARGUMENT_ERROR;
         return;
     }
@@ -1191,6 +1213,7 @@ UnicodeString& RelativeDateTimeFormatter::combineDateAndTime(
 }
 
 UnicodeString& RelativeDateTimeFormatter::adjustForContext(UnicodeString &str) const {
+#if !UCONFIG_NO_BREAK_ITERATION
     if (fOptBreakIterator == nullptr
         || str.length() == 0 || !u_islower(str.char32At(0))) {
         return str;
@@ -1204,25 +1227,36 @@ UnicodeString& RelativeDateTimeFormatter::adjustForContext(UnicodeString &str) c
             fOptBreakIterator->get(),
             fLocale,
             U_TITLECASE_NO_LOWERCASE | U_TITLECASE_NO_BREAK_ADJUSTMENT);
+#endif // !UCONFIG_NO_BREAK_ITERATION
     return str;
 }
 
 UBool RelativeDateTimeFormatter::checkNoAdjustForContext(UErrorCode& status) const {
+#if !UCONFIG_NO_BREAK_ITERATION
     // This is unsupported because it's hard to keep fields in sync with title
     // casing. The code could be written and tested if there is demand.
     if (fOptBreakIterator != nullptr) {
         status = U_UNSUPPORTED_ERROR;
         return false;
     }
+#else
+    (void)status; // suppress unused argument warning
+#endif // !UCONFIG_NO_BREAK_ITERATION
     return true;
 }
 
 void RelativeDateTimeFormatter::init(
         NumberFormat *nfToAdopt,
+#if !UCONFIG_NO_BREAK_ITERATION
         BreakIterator *biToAdopt,
+#else
+        std::nullptr_t,
+#endif // !UCONFIG_NO_BREAK_ITERATION
         UErrorCode &status) {
     LocalPointer<NumberFormat> nf(nfToAdopt);
+#if !UCONFIG_NO_BREAK_ITERATION
     LocalPointer<BreakIterator> bi(biToAdopt);
+#endif // !UCONFIG_NO_BREAK_ITERATION
     UnifiedCache::getByLocale(fLocale, fCache, status);
     if (U_FAILURE(status)) {
         return;
@@ -1251,6 +1285,7 @@ void RelativeDateTimeFormatter::init(
         nf.orphan();
         SharedObject::copyPtr(shared, fNumberFormat);
     }
+#if !UCONFIG_NO_BREAK_ITERATION
     if (bi.isNull()) {
         SharedObject::clearPtr(fOptBreakIterator);
     } else {
@@ -1262,6 +1297,7 @@ void RelativeDateTimeFormatter::init(
         bi.orphan();
         SharedObject::copyPtr(shared, fOptBreakIterator);
     }
+#endif // !UCONFIG_NO_BREAK_ITERATION
 }
 
 U_NAMESPACE_END
