@@ -536,14 +536,6 @@ public:
     virtual int32_t monthLength(int32_t month, int32_t year) const;
 
 #ifndef U_HIDE_INTERNAL_API
-    /**
-     * return the length of the given year.
-     * @param year    the given year.
-     * @return        the length of the given year.
-     * @internal
-     */
-    int32_t yearLength(int32_t year) const;
-
     /**
      * return the length of the year field.
      * @return    the length of the year field
@@ -551,14 +543,6 @@ public:
      */
     int32_t yearLength(void) const;
 
-    /**
-     * After adjustments such as add(MONTH), add(YEAR), we don't want the
-     * month to jump around.  E.g., we don't want Jan 31 + 1 month to go to Mar
-     * 3, we want it to go to Feb 28.  Adjustments which might run into this
-     * problem call this method to retain the proper month.
-     * @internal
-     */
-    void pinDayOfMonth(void);
 #endif  /* U_HIDE_INTERNAL_API */
 
     /**
