@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,12 +25,10 @@
 package test.robot.javafx.scene;
 
 import static javafx.scene.paint.Color.MAGENTA;
-
 import java.util.HashSet;
 import java.util.Set;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.atomic.AtomicReference;
-
 import javafx.application.Application;
 import javafx.application.Platform;
 import javafx.beans.InvalidationListener;
@@ -56,19 +54,15 @@ import javafx.stage.Screen;
 import javafx.stage.Stage;
 import javafx.stage.StageStyle;
 import javafx.stage.WindowEvent;
-
-import org.junit.After;
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Test;
-
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Assumptions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import com.sun.javafx.PlatformUtil;
-
-import junit.framework.AssertionFailedError;
 import test.util.Util;
 
 /**
@@ -140,7 +134,7 @@ public class RobotTest {
         TYPED
     }
 
-    @Before
+    @BeforeEach
     public void before() {
         Util.parkCursor(robot);
     }
@@ -196,51 +190,38 @@ public class RobotTest {
         });
         Util.waitForLatch(keyActionLatch, 5, "Timeout while waiting for textField.onKey" +
                 capFirst(keyAction.name()) + "().");
-        Assert.assertEquals("letter 'a' should be " + keyAction.name().toLowerCase() +
-                " by Robot", "a", textField.getText());
+        Assertions.assertEquals(
+            "a", textField.getText(),
+            "letter 'a' should be " + keyAction.name().toLowerCase() + " by Robot");
     }
 
     @Test
     public void testKeyPressThrowsISEOnWrongThread() {
-        try {
+        Assertions.assertThrows(IllegalStateException.class, () -> {
             robot.keyPress(KeyCode.A);
-        } catch (IllegalStateException e) {
-            return;
-        }
-        Assert.fail("Expected IllegalStateException");
+        });
     }
 
     @Test
     public void testKeyPressThrowsNPEForNullArgument() {
-        Util.runAndWait(() -> {
-            try {
-                robot.keyPress(null);
-            } catch (NullPointerException e) {
-                return;
-            }
-            Assert.fail("Expected NullPointerException");
+        Assertions.assertThrows(NullPointerException.class, () -> {
+            robot.keyPress(null);
         });
     }
 
     @Test
     public void testKeyReleaseThrowsISEOnWrongThread() {
-        try {
+        Assertions.assertThrows(IllegalStateException.class, () -> {
             robot.keyRelease(KeyCode.A);
-        } catch (IllegalStateException e) {
-            return;
-        }
-        Assert.fail("Expected IllegalStateException");
+        });
     }
 
     @Test
     public void testKeyReleaseThrowsNPEForNullArgument() {
         Util.runAndWait(() -> {
-            try {
+            Assertions.assertThrows(NullPointerException.class, () -> {
                 robot.keyRelease(null);
-            } catch (NullPointerException e) {
-                return;
-            }
-            Assert.fail("Expected NullPointerException");
+            });
         });
     }
 
@@ -275,29 +256,23 @@ public class RobotTest {
             }
             mousePosition.set(robot.getMousePosition());
         });
-        Assert.assertEquals(x, (int) mousePosition.get().getX());
-        Assert.assertEquals(y, (int) mousePosition.get().getY());
+        Assertions.assertEquals(x, (int) mousePosition.get().getX());
+        Assertions.assertEquals(y, (int) mousePosition.get().getY());
     }
 
     @Test
     public void testMouseMoveThrowsISEOnWrongThread() {
-        try {
+        Assertions.assertThrows(IllegalStateException.class, () -> {
             robot.mouseMove(0, 0);
-        } catch (IllegalStateException e) {
-            return;
-        }
-        Assert.fail("Expected IllegalStateException");
+        });
     }
 
     @Test
     public void testMouseMoveThrowsNPEForNullArgument() {
         Util.runAndWait(() -> {
-            try {
+            Assertions.assertThrows(NullPointerException.class, () -> {
                 robot.mouseMove(null);
-            } catch (NullPointerException e) {
-                return;
-            }
-            Assert.fail("Expected NullPointerException");
+            });
         });
     }
 
@@ -426,106 +401,89 @@ public class RobotTest {
         });
         Util.waitForLatch(onClickLatch, 5, "Timeout while waiting for button.onMouse" +
                 capFirst(mouseAction.name()) + "().");
-        Assert.assertEquals(mouseButton + " mouse button should be " + mouseAction.name().toLowerCase() + " by Robot",
-                expectedText, button.getText());
+        Assertions.assertEquals(
+            expectedText, button.getText(),
+            mouseButton + " mouse button should be " + mouseAction.name().toLowerCase() + " by Robot");
     }
 
     @Test
     public void testMousePressThrowsISEOnWrongThread() {
-        try {
+        Assertions.assertThrows(IllegalStateException.class, () -> {
             robot.mousePress(MouseButton.PRIMARY);
-        } catch (IllegalStateException e) {
-            return;
-        }
-        Assert.fail("Expected IllegalStateException");
+        });
     }
 
     @Test
     public void testMousePressThrowsNPEForNullArgument() {
         Util.runAndWait(() -> {
-            try {
-                robot.mousePress(null);
-            } catch (NullPointerException e) {
-                return;
-            }
-            Assert.fail("Expected NullPointerException");
+            Assertions.assertThrows(NullPointerException.class, () -> {
+                robot.mousePress((MouseButton[])null);
+            });
         });
     }
 
     @Test
     public void testMouseReleaseThrowsISEOnWrongThread() {
-        try {
+        Assertions.assertThrows(IllegalStateException.class, () -> {
             robot.mouseRelease(MouseButton.PRIMARY);
-        } catch (IllegalStateException e) {
-            return;
-        }
-        Assert.fail("Expected IllegalStateException");
+        });
     }
 
     @Test
     public void testMouseReleaseThrowsNPEForNullArgument() {
         Util.runAndWait(() -> {
-            try {
-                robot.mouseRelease(null);
-            } catch (NullPointerException e) {
-                return;
-            }
-            Assert.fail("Expected NullPointerException");
+            Assertions.assertThrows(NullPointerException.class, () -> {
+                robot.mouseRelease((MouseButton[])null);
+            });
         });
     }
 
     @Test
     public void testMouseClickThrowsISEOnWrongThread() {
-        try {
+        Assertions.assertThrows(IllegalStateException.class, () -> {
             robot.mouseClick(MouseButton.PRIMARY);
-        } catch (IllegalStateException e) {
-            return;
-        }
-        Assert.fail("Expected IllegalStateException");
+        });
     }
 
     @Test
     public void testMouseClickThrowsNPEForNullArgument() {
         Util.runAndWait(() -> {
-            try {
-                robot.mouseClick(null);
-            } catch (NullPointerException e) {
-                return;
-            }
-            Assert.fail("Expected NullPointerException");
+            Assertions.assertThrows(NullPointerException.class, () -> {
+                robot.mouseClick((MouseButton[])null);
+            });
         });
     }
 
     @Test
-    @Ignore("Flaky - see JDK-8215376")
+    @Disabled("Flaky - see JDK-8215376")
     public void testMouseDragPrimary() {
         testMouseDrag(MouseButton.PRIMARY);
     }
 
     @Test
-    @Ignore("Flaky - see JDK-8215376")
+    @Disabled("Flaky - see JDK-8215376")
     public void testMouseDragSecondary() {
         testMouseDrag(MouseButton.SECONDARY);
     }
 
     @Test
-    @Ignore("Flaky - see JDK-8215376")
+    @Disabled("Flaky - see JDK-8215376")
     public void testMouseDragMiddle() {
-        Assume.assumeTrue(!PlatformUtil.isMac() ); // See JDK-8215376
+        Assumptions.assumeTrue(!PlatformUtil.isMac() ); // See JDK-8215376
         testMouseDrag(MouseButton.MIDDLE);
     }
 
     @Test
-    @Ignore("Flaky - see JDK-8215376")
+    @Disabled("Flaky - see JDK-8215376")
     public void testMouseDragForward() {
-        Assume.assumeTrue(!PlatformUtil.isMac()); // See JDK-8215376
+        Assumptions.assumeTrue(!PlatformUtil.isMac()); // See JDK-8215376
         testMouseDrag(MouseButton.FORWARD);
     }
 
     @Test
-    @Ignore("Flaky - see JDK-8215376")
+    @Disabled("Flaky - see JDK-8215376")
     public void testMouseDragBack() {
-        Assume.assumeTrue(!PlatformUtil.isMac()); // See JDK-8215376
+        Assumptions.assumeTrue(!PlatformUtil.isMac()); // See JDK-8215376
         testMouseDrag(MouseButton.BACK);
     }
 
@@ -574,7 +532,7 @@ public class RobotTest {
     }
 
     private static void testMouseWheel(int amount) {
-        Assume.assumeTrue(!PlatformUtil.isMac()); // See JDK-8214580
+        Assumptions.assumeTrue(!PlatformUtil.isMac()); // See JDK-8214580
         CountDownLatch onScrollLatch = new CountDownLatch(1);
         CountDownLatch setSceneLatch = new CountDownLatch(1);
         Button button = new Button("Scroll me");
@@ -618,18 +576,16 @@ public class RobotTest {
             robot.mouseWheel(amount);
         });
         Util.waitForLatch(onScrollLatch, 5, "Timeout while waiting for button.onScroll().");
-        Assert.assertEquals("mouse wheel should be scrolled " + amount + " vertical units by Robot",
-                "Scrolled " + amount, button.getText());
+        Assertions.assertEquals(
+            "Scrolled " + amount, button.getText(),
+            "mouse wheel should be scrolled " + amount + " vertical units by Robot");
     }
 
     @Test
     public void testMouseWheelThrowsISEOnWrongThread() {
-        try {
+        Assertions.assertThrows(IllegalStateException.class, () -> {
             robot.mouseWheel(1);
-        } catch (IllegalStateException e) {
-            return;
-        }
-        Assert.fail("Expected IllegalStateException");
+        });
     }
 
     @Test
@@ -673,10 +629,6 @@ public class RobotTest {
 
     @Test
     public void testPixelCaptureAverage() throws Exception {
-        if (PlatformUtil.isWindows() && Screen.getPrimary().getOutputScaleX() > 1) {
-            // Mark this test as unstable on Windows when HiDPI scale is more than 100%
-            Assume.assumeTrue(Boolean.getBoolean("unstable.test")); // JDK-8255079
-        }
         CountDownLatch setSceneLatch = new CountDownLatch(1);
         Pane pane = new StackPane();
         InvalidationListener invalidationListener = observable -> setSceneLatch.countDown();
@@ -694,8 +646,8 @@ public class RobotTest {
         AtomicReference<Color> captureColor = new AtomicReference<>();
         Thread.sleep(1000);
         Util.runAndWait(() -> {
-            int x = (int) stage.getX();
-            int y = (int) stage.getY();
+            int x = (int)(Math.round(stage.getX()));
+            int y = (int)(Math.round(stage.getY()));
             // Subtracting one pixel from x makes the result RED, so we are on the border.
             // If the implementation of getPixelColor is ever chaged to interpolate the
             // colors on HiDPI screens, this test will fail and the resulting color will
@@ -707,32 +659,22 @@ public class RobotTest {
 
     @Test
     public void testPixelCaptureThrowsISEOnWrongThread() {
-        try {
+        Assertions.assertThrows(IllegalStateException.class, () -> {
             robot.getPixelColor(20, 20);
-        } catch (IllegalStateException e) {
-            return;
-        }
-        Assert.fail("Expected IllegalStateException");
+        });
     }
 
     @Test
     public void testPixelCaptureThrowsNPEForNullArgument() {
         Util.runAndWait(() -> {
-            try {
+            Assertions.assertThrows(NullPointerException.class, () -> {
                 robot.getPixelColor(null);
-            } catch (NullPointerException e) {
-                return;
-            }
-            Assert.fail("Expected NullPointerException");
+            });
         });
     }
 
     @Test
     public void testScreenCapture() throws Exception {
-        if (PlatformUtil.isWindows() && Screen.getPrimary().getOutputScaleX() > 1) {
-            // Mark this test as unstable on Windows when HiDPI scale is more than 100%
-            Assume.assumeTrue(Boolean.getBoolean("unstable.test")); // JDK-8207379
-        }
         CountDownLatch setSceneLatch = new CountDownLatch(1);
         Pane pane = new StackPane();
         InvalidationListener invalidationListener = observable -> setSceneLatch.countDown();
@@ -761,19 +703,34 @@ public class RobotTest {
         // Should be scaled to the primary screen x and y scales. Note that screenCaptureScaledToFit and
         // screenCaptureNotScaledToFit will be the same if screenScaleX = screenScaleY = 1.0 and in that case
         // this is redundant.
-        Assert.assertEquals((double) WIDTH * screenScaleX, screenCaptureNotScaledToFit.get().getWidth(), 0.0001);
-        Assert.assertEquals((double) HEIGHT * screenScaleY, screenCaptureNotScaledToFit.get().getHeight(), 0.0001);
-        for (int x = 0; x < WIDTH * screenScaleX; x++) {
-            for (int y = 0; y < HEIGHT * screenScaleY; y++) {
+        // Below calculations follow how getScreenCapture should calculate screen capture dimensions. This
+        // is to make this code consistent and stable on HiDPI systems.
+        int stageX = (int) stage.getX();
+        int stageY = (int) stage.getY();
+        int shouldBeMinX = (int) Math.floor(stageX * screenScaleX);
+        int shouldBeMinY = (int) Math.floor(stageY * screenScaleY);
+        int shouldBeMaxX = (int) Math.ceil((stageX + WIDTH) * screenScaleX);
+        int shouldBeMaxY = (int) Math.ceil((stageY + HEIGHT) * screenScaleY);
+        int shouldBeWidth = shouldBeMaxX - shouldBeMinX;
+        int shouldBeHeight = shouldBeMaxY - shouldBeMinY;
+        Assertions.assertEquals((double) shouldBeWidth, screenCaptureNotScaledToFit.get().getWidth(), 0.0001);
+        Assertions.assertEquals((double) shouldBeHeight, screenCaptureNotScaledToFit.get().getHeight(), 0.0001);
+
+        // To verify the color we're going to skip the "1-pixel outside border" of the capture. On HiDPI systems
+        // (especially on Windows) stage's position might have fractional element, which will mean the capture will
+        // average those values with whatever is behind the stage. This will make their values invalid.
+        for (int x = 1; x < shouldBeWidth - 1; x++) {
+            for (int y = 1; y < shouldBeHeight - 1; y++) {
                 assertColorEquals(MAGENTA, screenCaptureNotScaledToFit.get().getPixelReader().getColor(x, y), TOLERANCE);
             }
         }
 
         // Should have been shrunk to fit the requested size, but still contain the same thing (all magenta pixels).
-        Assert.assertEquals((double) WIDTH, screenCaptureScaledToFit.get().getWidth(), 0.0001);
-        Assert.assertEquals((double) HEIGHT, screenCaptureScaledToFit.get().getHeight(), 0.0001);
-        for (int x = 0; x < WIDTH; x++) {
-            for (int y = 0; y < HEIGHT; y++) {
+        Assertions.assertEquals((double) WIDTH, screenCaptureScaledToFit.get().getWidth(), 0.0001);
+        Assertions.assertEquals((double) HEIGHT, screenCaptureScaledToFit.get().getHeight(), 0.0001);
+        // Because of scaling, similar estimate has to be done like above.
+        for (int x = 1; x < WIDTH - 1; x++) {
+            for (int y = 1; y < HEIGHT - 1; y++) {
                 assertColorEquals(MAGENTA, screenCaptureScaledToFit.get().getPixelReader().getColor(x, y), TOLERANCE);
             }
         }
@@ -781,23 +738,17 @@ public class RobotTest {
 
     @Test
     public void testScreenCaptureThrowsISEOnWrongThread() {
-        try {
+        Assertions.assertThrows(IllegalStateException.class, () -> {
             robot.getScreenCapture(null, 0, 0, 10, 10);
-        } catch (IllegalStateException e) {
-            return;
-        }
-        Assert.fail("Expected IllegalStateException");
+        });
     }
 
     @Test
     public void testScreenCaptureThrowsNPEForNullArgument() {
         Util.runAndWait(() -> {
-            try {
+            Assertions.assertThrows(NullPointerException.class, () -> {
                 robot.getScreenCapture(null, null);
-            } catch (NullPointerException e) {
-                return;
-            }
-            Assert.fail("Expected NullPointerException");
+            });
         });
     }
 
@@ -814,17 +765,17 @@ public class RobotTest {
         }
     }
 
-    @BeforeClass
+    @BeforeAll
     public static void initFX() {
         Util.launch(startupLatch, TestApp.class);
     }
 
-    @AfterClass
+    @AfterAll
     public static void exit() {
-        Util.shutdown(stage);
+        Util.shutdown();
     }
 
-    @After
+    @AfterEach
     public void cleanup() {
         Util.runAndWait(() -> {
             if (!pressedButtons.isEmpty()) {
@@ -837,7 +788,7 @@ public class RobotTest {
 
     private static void assertColorEquals(Color expected, Color actual, double delta) {
         if (!testColorEquals(expected, actual, delta)) {
-            throw new AssertionFailedError("expected: " + colorToString(expected)
+            Assertions.fail("expected: " + colorToString(expected)
                     + " but was: " + colorToString(actual));
         }
     }
